@@ -146,29 +146,29 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="153"/>
+        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="154"/>
         <source>Save changes ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="154"/>
+        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="155"/>
         <source>You make changes into the bank account details.
 Do you want to save them ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="158"/>
-        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="187"/>
+        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="159"/>
+        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="188"/>
         <source>bank account details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="188"/>
+        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="189"/>
         <source>Can not submit bank account details to your personnal database.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="189"/>
+        <location filename="../../plugins/accountplugin/preferences/availablemovementpage.cpp" line="190"/>
         <source>An error occured during bank account details saving. Datas are corrupted.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -236,29 +236,29 @@ Do you want to save them ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="156"/>
+        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="157"/>
         <source>Save changes ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="157"/>
+        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="158"/>
         <source>You make changes into the bank account details.
 Do you want to save them ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="161"/>
-        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="190"/>
+        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="162"/>
+        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="191"/>
         <source>bank account details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="191"/>
+        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="192"/>
         <source>Can not submit bank account details to your personnal database.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="192"/>
+        <location filename="../../plugins/accountplugin/preferences/bankdetailspage.cpp" line="193"/>
         <source>An error occured during bank account details saving. Datas are corrupted.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -266,75 +266,163 @@ Do you want to save them ?</source>
 <context>
     <name>Account::Internal::MedicalProcedureWidget</name>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="14"/>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="20"/>
         <source>Form</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="32"/>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="38"/>
         <source>Available personnal medical procedures</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="42"/>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="48"/>
         <source>Account details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="48"/>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="54"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="58"/>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="67"/>
         <source>Abstract</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="68"/>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="80"/>
         <source>Owner</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="78"/>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="90"/>
         <source>Type</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="88"/>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="103"/>
         <source>Amount</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="137"/>
-        <source>Medical Procedure</source>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="132"/>
+        <source>User UUID</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="153"/>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="139"/>
+        <source>Reinbursment rate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="152"/>
+        <source>Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="173"/>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.ui" line="208"/>
+        <source>Medical 
+Procedure</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="178"/>
         <source>Save changes ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="154"/>
-        <source>You make changes into the bank account details.
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="179"/>
+        <source>You make changes into the medical procedures table.
 Do you want to save them ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="158"/>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="187"/>
-        <source>bank account details</source>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="184"/>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="238"/>
+        <source>medical_procedures</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="188"/>
-        <source>Can not submit bank account details to your personnal database.</source>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="239"/>
+        <source>Can not submit medical procedure to your personnal database.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="189"/>
-        <source>An error occured during bank account details saving. Datas are corrupted.</source>
+        <location filename="../../plugins/accountplugin/preferences/medicalprocedurepage.cpp" line="240"/>
+        <source>An error occured during medical procedures saving. Datas are corrupted.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Account::Internal::VirtualDatabaseCreator</name>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="14"/>
+        <source>Form</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="32"/>
+        <source>Virtual database creator</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="95"/>
+        <source>This widget will create a fake database and populate it with virtual datas.
+This feature is usefull for testers and should not be used by current users.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="108"/>
+        <source>Delete actual database (datas will be definitively lost)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="115"/>
+        <source>Number of bank accounts to create</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="125"/>
+        <source>Number of movements to create</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="135"/>
+        <source>Number of medical procedures to create</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="145"/>
+        <source>Number of accounts to create</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.ui" line="211"/>
+        <source>Create virtual database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.cpp" line="239"/>
+        <source>Creating virtual database (%1 items to create)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.cpp" line="239"/>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Account::VirtualDatabaseCreatorPage</name>
+    <message>
+        <location filename="../../plugins/accountplugin/preferences/virtualdatabasecreator.cpp" line="173"/>
+        <source>Virtual database creator</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
