@@ -4,13 +4,25 @@
 <context>
     <name>DatabaseUpdater</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/versionupdater.cpp" line="57"/>
+        <location filename="../../plugins/drugsbaseplugin/versionupdater.cpp" line="77"/>
+        <source>Your dosage database needs to be updated from version 0.5.0 to version 0.5.4.
+This will be automatically done.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/versionupdater.cpp" line="187"/>
+        <source>Your dosage database needs to be updated from version 0.4.0 to version 0.5.0.
+This will be automatically done.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/versionupdater.cpp" line="297"/>
         <source>Your dosage database needs to be updated from version 0.2.0 to version 0.4.0.
 This will be automatically done.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/versionupdater.cpp" line="161"/>
+        <location filename="../../plugins/drugsbaseplugin/versionupdater.cpp" line="401"/>
         <source>Your dosage database needs to be updated from version 0.0.8 to version 0.2.0.
 This will be automatically done.
 Please verify your daily scheme prescriptions and relations to meal.</source>
@@ -20,215 +32,310 @@ Please verify your daily scheme prescriptions and relations to meal.</source>
 <context>
     <name>DrugsBase</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="925"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="963"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="999"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="1049"/>
         <source>ERROR : will retreiving %1. Wrong number of fields</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/interactionsbase.cpp" line="441"/>
-        <source>This INN is present more than one time in this prescrition.</source>
+        <location filename="../../plugins/drugsbaseplugin/interactionsbase.cpp" line="326"/>
+        <source>FreeDiams Interactions Engine</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DrugsDB::AtcTreeModel</name>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/atctreemodel.cpp" line="329"/>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/atctreemodel.cpp" line="331"/>
+        <source>Code</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>DrugsDB::DrugsIO</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="265"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="253"/>
         <source>Dosages transmitted.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="268"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="256"/>
         <source>Dosage not correctly transmitted</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="305"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="330"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="290"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="323"/>
+        <source>You are trying to read a corrupted XML file.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="291"/>
+        <source>Error: %1
+Line: %2, Column: %3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="321"/>
         <source>Unable to load XML prescription : tag %1 is missing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="313"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="308"/>
         <source>Prescription specifies a different drugs database than the actual one.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="314"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="309"/>
         <source>You are trying to load prescription that uses a different drugs database than the actual one. You can not read this prescription unless you change the current database in the Preferences.
 Actual: %1
 Prescription: %2.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="351"/>
-        <source>Unable to read xml prescription</source>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="324"/>
+        <source>Missing tag: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="383"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="351"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="361"/>
+        <source>  * %1 was added as a textual drug.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="370"/>
+        <source>  * %1 (%2) is already in the prescription. Drug is ignored.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="378"/>
+        <source>  * %1 (%2) was added as a textual drug.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="410"/>
+        <source>Interaction checking will not take these drugs into account.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="411"/>
+        <source>FreeDiams encountered errors while reading the XML prescription.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="419"/>
         <source>Xml prescription correctly read.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="416"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="452"/>
         <source>No file name passed to load prescription</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="584"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="626"/>
         <source>Save test only drugs too ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="585"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="627"/>
         <source>Drugs added for testing only are actually hidden in this prescription.
 Do you want to add them to the file ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="587"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="629"/>
         <source>Answering &apos;no&apos; will cause definitive lost of test only drugs when reloading this file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="767"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="781"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="822"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsio.cpp" line="836"/>
         <source>Drugs Prescription</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>DrugsDB::DrugsModel</name>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="498"/>
+        <source>KNOWN ALLERGY</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DrugsDB::GlobalDrugsModel</name>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="742"/>
+        <source>KNOWN ALLERGY</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="746"/>
+        <source>KNOWN INTOLERANCE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="784"/>
+        <source>Identifier(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="782"/>
+        <source>Form(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/globaldrugsmodel.cpp" line="783"/>
+        <source>Route(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DrugsDB::InteractionsManager</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="327"/>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="361"/>
+        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="334"/>
+        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="368"/>
         <source>Nature of the risk: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="332"/>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="366"/>
+        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="339"/>
         <source>What to do: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="341"/>
-        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="375"/>
+        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="348"/>
+        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="382"/>
         <source>Interaction(s) Found : </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="373"/>
+        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="428"/>
+        <source>Management: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/interactionsmanager.cpp" line="421"/>
+        <source>Nature of the risk</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DrugsDB::Internal::DosageModel</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="144"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="135"/>
         <source>complet tab.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="145"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="136"/>
         <source>half tab.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="146"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="137"/>
         <source>quater tab.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="150"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="141"/>
         <source>dose per kilograms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="151"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="142"/>
         <source>reference spoon</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="152"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="143"/>
         <source>2.5 ml spoon</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="153"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="144"/>
         <source>5 ml spoon</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="154"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="145"/>
         <source>puffs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="155"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="146"/>
         <source>dose</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="156"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="147"/>
         <source>mouthwash</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="157"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="148"/>
         <source>inhalation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="158"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="149"/>
         <source>application</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="159"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="150"/>
         <source>washing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="160"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="151"/>
         <source>shampooing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="161"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="152"/>
         <source>eyewash</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="162"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="153"/>
         <source>instillation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="163"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="154"/>
         <source>pulverization</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="309"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="314"/>
         <source>Model Error : unable to insert a row</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="461"/>
-        <source>The protocol must be labelled.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="464"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="476"/>
         <source>The intakes&apos; scheme must be defined.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="466"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="478"/>
         <source>The period&apos;s scheme must be defined.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="469"/>
+        <location filename="../../plugins/drugsbaseplugin/dosagemodel.cpp" line="481"/>
         <source>The duration&apos;s scheme must be defined.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -236,26 +343,32 @@ Do you want to add them to the file ?</source>
 <context>
     <name>DrugsDB::Internal::DrugsBase</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="281"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="307"/>
         <source>Searching databases into dir %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="543"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="549"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="554"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="357"/>
+        <source>WARNING : can not open database %1 : %2 
+ %3 </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="599"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="605"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="610"/>
         <source>Unable to create the Protocol database.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="543"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="549"/>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="554"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="599"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="605"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="610"/>
         <source>Please contact dev team.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="668"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsbase.cpp" line="722"/>
         <source>Unable to update the protocol&apos;s transmission date.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -263,22 +376,48 @@ Do you want to add them to the file ?</source>
 <context>
     <name>DrugsDB::Internal::DrugsTemplatePrinter</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="63"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="65"/>
+        <source>Warning : </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="67"/>
+        <source>Interactions found. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="69"/>
+        <source>Allergies found. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="74"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="79"/>
+        <source>What do you want to do ?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="87"/>
+        <source>Synthetic interactions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="100"/>
         <source>Print separately or merge printing.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="64"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="101"/>
         <source>You have selected multiple templates, would you print them separately or merge templates for printing on a single order ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="67"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="104"/>
         <source>Print separately</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="67"/>
+        <location filename="../../plugins/drugsbaseplugin/drugstemplateprinter.cpp" line="104"/>
         <source>Merge and print</source>
         <translation type="unfinished"></translation>
     </message>
@@ -286,25 +425,40 @@ Do you want to add them to the file ?</source>
 <context>
     <name>DrugsData</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="486"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="586"/>
         <source>No INN found.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="491"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="591"/>
         <source>No interaction class found.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="626"/>
+        <source>Form(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="627"/>
+        <source>Route(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/drugsbaseplugin/drugsdata.cpp" line="628"/>
+        <source>Identifier(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DrugsModel</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="209"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="202"/>
         <source>x %1 of %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="224"/>
+        <location filename="../../plugins/drugsbaseplugin/drugsmodel.cpp" line="212"/>
         <source>Available Dosages</source>
         <translation type="unfinished"></translation>
     </message>
@@ -312,15 +466,17 @@ Do you want to add them to the file ?</source>
 <context>
     <name>mfDrugsConstants</name>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/constants.h" line="90"/>
-        <source>&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;[[DRUG]]&lt;/span&gt;&lt;span style=&quot;font-style:italic;&quot;&gt;[&lt;br /&gt;[Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][&lt;br /&gt;Daily Distribution: [DISTRIBUTED_DAILY_SCHEME]][&lt;br /&gt;[NOTE]]&lt;/span&gt;&lt;/p&gt;</source>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="76"/>
+        <source>&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;[[DRUG]]&lt;/span&gt;&lt;span style=&quot;font-style:italic;&quot;&gt;[&lt;br /&gt;Take [Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][&lt;br /&gt;Route: [ROUTE]][&lt;br /&gt;Daily Distribution: [DISTRIBUTED_DAILY_SCHEME]][&lt;br /&gt;Minimum interval between intakes: [MIN_INTERVAL]][&lt;br /&gt;[NOTE] ]&lt;/span&gt;&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/drugsbaseplugin/constants.h" line="91"/>
+        <location filename="../../plugins/drugsbaseplugin/constants.h" line="84"/>
         <source>[[DRUG]][
-[Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][
+Take [Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][
+Route: [ROUTE]][
 Daily Distribution: [DISTRIBUTED_DAILY_SCHEME]][
+Minimum interval between intakes: [MIN_INTERVAL]][
 [NOTE] ]</source>
         <translation type="unfinished"></translation>
     </message>
