@@ -4,7 +4,7 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../../plugins/fdcoreplugin/appaboutpage.cpp" line="60"/>
+        <location filename="../../plugins/fdcoreplugin/appaboutpage.cpp" line="45"/>
         <source>&lt;p align=center&gt;&lt;b&gt;Welcome to FreeDiams&lt;/b&gt;&lt;br /&gt;(C) 2008-2010 by Eric MAEKER, MD&lt;/p&gt;&lt;p align=left&gt;This application is a stable release but can still contains some bugs.&lt;br /&gt;This software is release without any warranty and only for test purposal.&lt;br /&gt;Please refer to web site for more informations.&lt;br /&gt;&lt;a href=&quot;%1&quot;&gt;Web site&lt;/a&gt;&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
@@ -12,12 +12,27 @@
 <context>
     <name>CommandLine</name>
     <message>
-        <location filename="../../plugins/fdcoreplugin/commandlineparser.cpp" line="164"/>
+        <location filename="../../plugins/fdcoreplugin/commandlineparser.cpp" line="186"/>
+        <source>Passing exchange in file : %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/fdcoreplugin/commandlineparser.cpp" line="194"/>
+        <source>Passing %1 as exchange in file, but file does not exists.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/fdcoreplugin/commandlineparser.cpp" line="202"/>
+        <source>Reading exchange in file : %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/fdcoreplugin/commandlineparser.cpp" line="207"/>
         <source>In File %1 is empty.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdcoreplugin/commandlineparser.cpp" line="179"/>
+        <location filename="../../plugins/fdcoreplugin/commandlineparser.cpp" line="223"/>
         <source>Wrong root tag %1 %2.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -25,16 +40,31 @@
 <context>
     <name>Core</name>
     <message>
-        <location filename="../../plugins/fdcoreplugin/coreimpl.cpp" line="170"/>
-        <location filename="../../plugins/fdcoreplugin/coreimpl.cpp" line="172"/>
+        <location filename="../../plugins/fdcoreplugin/coreimpl.cpp" line="156"/>
+        <location filename="../../plugins/fdcoreplugin/coreimpl.cpp" line="158"/>
         <source>Core intialization finished...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdcoreplugin/coreimpl.cpp" line="267"/>
+        <location filename="../../plugins/fdcoreplugin/coreimpl.cpp" line="246"/>
+        <source>You are running FreeDiams for the first time. You need to approve the licence terms.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/fdcoreplugin/coreimpl.cpp" line="250"/>
         <source>You are running a new version of FreeDiams, you need to renew the licence agreement.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../plugins/fdcoreplugin/coreimpl.cpp" line="260"/>
+        <source>You are updating FreeDiams, do you want to update your personnal preferences ?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/fdcoreplugin/coreimpl.cpp" line="261"/>
+        <source>With the new version some preferences should be outdated. Answering yes will allow FreeDiams to update your personnal preferences.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Core::Internal::AboutDialog</name>
@@ -52,12 +82,12 @@
 <context>
     <name>Core::Internal::AppAboutPage</name>
     <message>
-        <location filename="../../plugins/fdcoreplugin/appaboutpage.h" line="56"/>
+        <location filename="../../plugins/fdcoreplugin/appaboutpage.h" line="42"/>
         <source>1. General</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdcoreplugin/appaboutpage.h" line="57"/>
+        <location filename="../../plugins/fdcoreplugin/appaboutpage.h" line="43"/>
         <source>Application</source>
         <translation type="unfinished"></translation>
     </message>
@@ -156,26 +186,26 @@
     </message>
     <message>
         <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="218"/>
-        <source>Automatically save datas without prompting users</source>
+        <source>Automatically save data without prompting users</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.ui" line="225"/>
-        <source>Use external server for my personnal databases</source>
+        <source>Use external server for my personal databases</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.cpp" line="135"/>
+        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.cpp" line="121"/>
         <source>Test in progress...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.cpp" line="144"/>
+        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.cpp" line="130"/>
         <source>Connection error: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.cpp" line="148"/>
+        <location filename="../../plugins/coreplugin/dialogs/applicationgeneralpreferences.cpp" line="134"/>
         <source>Connected</source>
         <translation type="unfinished"></translation>
     </message>
@@ -183,20 +213,30 @@
 <context>
     <name>Core::Internal::BuildAboutPage</name>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.cpp" line="105"/>
+        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.cpp" line="90"/>
         <source>Actual Qt version : %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="43"/>
+        <source>4. Build informations</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="44"/>
+        <source>Application</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Core::Internal::CommandLineAboutPage</name>
     <message>
-        <location filename="../../plugins/fdcoreplugin/appaboutpage.h" line="70"/>
+        <location filename="../../plugins/fdcoreplugin/appaboutpage.h" line="56"/>
         <source>5. Command line</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/fdcoreplugin/appaboutpage.h" line="71"/>
+        <location filename="../../plugins/fdcoreplugin/appaboutpage.h" line="57"/>
         <source>Application</source>
         <translation type="unfinished"></translation>
     </message>
@@ -234,30 +274,52 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="175"/>
+        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="159"/>
         <source>Sending debugging informations to dev team</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="176"/>
+        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="160"/>
         <source>Trying to send informations to dev team.
 Using Url : %1 
 Please wait...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="197"/>
+        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="181"/>
         <source>Debugging informations correctly sent.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="200"/>
+        <location filename="../../plugins/coreplugin/dialogs/debugdialog.cpp" line="184"/>
         <source>Debugging informations correctly send to dev team.
 Using Url : %1 
 %2</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>Core::Internal::LicenseAboutPage</name>
+    <message>
+        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="57"/>
+        <source>3. License</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="58"/>
+        <source>Application</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Core::Internal::SettingDebugPage</name>
+    <message>
+        <location filename="../../plugins/coreplugin/dialogs/commondebugpages.h" line="78"/>
+        <location filename="../../plugins/coreplugin/dialogs/commondebugpages.h" line="79"/>
+        <source>Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Core::Internal::SettingsDialog</name>
     <message>
@@ -274,336 +336,393 @@ Using Url : %1
 <context>
     <name>Core::Internal::SettingsPrivate</name>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="480"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="581"/>
         <source>Passing command line ini file : %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="489"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="590"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="620"/>
         <source>Using ini file %1.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="493"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="594"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="624"/>
         <source>Ini file %1 is not writable. Can not use it.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="498"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="541"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="600"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="630"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="674"/>
         <source>Using ini file %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="502"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="604"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="634"/>
         <source>WARNING : Ini file %1 can not be used.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="530"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="662"/>
         <source>Trying ini file %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="536"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="668"/>
         <source>Unable to create dir : %1, no Ini File can be used.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="619"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="760"/>
         <source>System informations</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="621"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="762"/>
         <source>Operating System</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="623"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="764"/>
         <source>uname output</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="629"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="770"/>
         <source>Compilation Date</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="630"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="771"/>
         <source>Compile Qt version</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="631"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="772"/>
         <source>Actual Qt version</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="634"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="636"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="775"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="777"/>
         <source>Compile mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="638"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="640"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="779"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="781"/>
         <source>Application source</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="646"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="756"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="787"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="901"/>
         <source>Binary</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="647"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="757"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="788"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="902"/>
         <source>Resources</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="648"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="758"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="789"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="903"/>
         <source>Read only Databases</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="649"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="759"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="790"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="904"/>
         <source>Writable databases</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="650"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="760"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="791"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="905"/>
         <source>Bundle root path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="651"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="761"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="792"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="906"/>
+        <source>Bundle resources path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="793"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="907"/>
         <source>Translations path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="652"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="762"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="794"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="908"/>
         <source>Qt Plugins path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="653"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="763"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="795"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="909"/>
         <source>Qt FrameWorks path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="654"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="764"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="796"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="910"/>
         <source>FreeMedForms PlugIns path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="655"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="765"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="797"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="911"/>
         <source>SmallPixmapPath</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="656"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="766"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="798"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="912"/>
         <source>MediumPixmapPath</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="657"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="767"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="799"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="913"/>
         <source>BigPixmapPath</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="658"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="768"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="800"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="914"/>
         <source>SystemTempPath</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="659"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="769"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="801"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="915"/>
         <source>ApplicationTempPath</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="660"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="770"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="802"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="916"/>
         <source>FormsPath</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="661"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="771"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="803"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="917"/>
         <source>SampleFormsPath</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="662"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="772"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="804"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="918"/>
         <source>DocumentationPath</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="664"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="806"/>
         <source>Absolute Paths</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="666"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="670"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="740"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="808"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="812"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="885"/>
         <source>Using Ini File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="668"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="810"/>
         <source>Relative Paths</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="677"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="678"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="773"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="819"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="820"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="919"/>
         <source>WebSiteUrl</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="684"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="826"/>
         <source>Settings values</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="687"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="829"/>
         <source>Orphan settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="725"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="870"/>
         <source>Running version : %1
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="726"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="871"/>
         <source>Build date : %1 %2
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="727"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="872"/>
         <source>Qt Build version : %1
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="728"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="873"/>
         <source>Qt running version : %1
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="729"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="874"/>
         <source>Application Version : %1
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="731"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="876"/>
         <source>Actual build : Debug
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="733"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="878"/>
         <source>Actual build : Release
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="735"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="737"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="880"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="882"/>
         <source>Actual build</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="735"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="880"/>
         <source>Full Application Build
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="737"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="882"/>
         <source>Svn Build
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="738"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="883"/>
         <source>Application path : %1
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="742"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="887"/>
         <source>Running on Linux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="743"/>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="747"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="888"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="892"/>
         <source>   uname returns : %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="746"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="891"/>
         <source>Running on MacOs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/settings.cpp" line="750"/>
+        <location filename="../../plugins/coreplugin/settings.cpp" line="895"/>
         <source>Running on Windows</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>Core::Internal::SimpleTextDialog</name>
+    <message>
+        <location filename="../../plugins/coreplugin/dialogs/simpletextdialog.ui" line="14"/>
+        <source>Dialog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/coreplugin/dialogs/simpletextdialog.ui" line="34"/>
+        <source>title</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Core::Internal::TeamAboutPage</name>
+    <message>
+        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="71"/>
+        <source>2. Team</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/coreplugin/dialogs/commonaboutpages.h" line="72"/>
+        <source>Application</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Core::Patient</name>
+    <message>
+        <location filename="../../plugins/fdcoreplugin/patient.cpp" line="207"/>
+        <location filename="../../plugins/fdcoreplugin/patient.cpp" line="222"/>
+        <source>Drugs(%1), </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/fdcoreplugin/patient.cpp" line="210"/>
+        <location filename="../../plugins/fdcoreplugin/patient.cpp" line="225"/>
+        <source>INN(%1), </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../plugins/fdcoreplugin/patient.cpp" line="213"/>
+        <location filename="../../plugins/fdcoreplugin/patient.cpp" line="228"/>
+        <source>ATC(%1), </source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Core::PluginDialog</name>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="59"/>
+        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="56"/>
         <source>Details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="60"/>
+        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="57"/>
         <source>Error Details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="61"/>
+        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="58"/>
         <source>Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="75"/>
+        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="72"/>
         <source>Installed Plugins</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="114"/>
+        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="111"/>
         <source>Plugin Details of %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="134"/>
+        <location filename="../../plugins/coreplugin/dialogs/plugindialog.cpp" line="131"/>
         <source>Plugin Errors of %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -611,17 +730,17 @@ Using Url : %1
 <context>
     <name>Core::Translators</name>
     <message>
-        <location filename="../../plugins/coreplugin/translators.cpp" line="155"/>
+        <location filename="../../plugins/coreplugin/translators.cpp" line="138"/>
         <source>Can not load %1, path : %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/translators.cpp" line="192"/>
+        <location filename="../../plugins/coreplugin/translators.cpp" line="176"/>
         <source>Add Translator %1.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/translators.cpp" line="199"/>
+        <location filename="../../plugins/coreplugin/translators.cpp" line="183"/>
         <source>WARNING : Can not be loaded %1 or already loaded.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -629,7 +748,7 @@ Using Url : %1
 <context>
     <name>ThemePrivate</name>
     <message>
-        <location filename="../../plugins/coreplugin/theme.cpp" line="184"/>
+        <location filename="../../plugins/coreplugin/theme.cpp" line="172"/>
         <source>ERROR - Theme : Unable to load icon file %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -637,12 +756,12 @@ Using Url : %1
 <context>
     <name>tkConstants</name>
     <message>
-        <location filename="../../plugins/coreplugin/constants.h" line="51"/>
+        <location filename="../../plugins/coreplugin/constants.h" line="44"/>
         <source>FreeDiams Prescriptions (*.di)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../plugins/coreplugin/constants.h" line="52"/>
+        <location filename="../../plugins/coreplugin/constants.h" line="45"/>
         <source>FreeMedForms Forms File (*.xml)</source>
         <translation type="unfinished"></translation>
     </message>
