@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -80,6 +66,7 @@ namespace Constants {
     const char* const  GLOSSARY_INS             = "Champs d'insertions";
 
     const char* const  DEFAULTLIST_RUB          = "MenuContextuel";
+    const char* const  MENULIST_PATH            = "PathLib";
     const char* const  DEFAULTLIST_OBS          = "ListObserv";
     const char* const  DEFAULTLIST_PRE          = "ListPrescr";
     const char* const  DEFAULTLIST_DOC          = "ListDocuments";
@@ -294,7 +281,6 @@ QString Configuration::medintuxPluginInformation( PluginsParameters info ) const
     return QApplication::arguments().at(info);
 }
 
-
 QString Configuration::findManagerBinaryPath() const
 {
     if (Utils::isRunningOnMac())
@@ -332,7 +318,7 @@ QString Configuration::managerIniFileName() const
     return Utils::isFileExists(d->m_ManagerPath + QDir::separator() + MANAGER_INI);
 }
 
-QVariant Configuration::managerIni( const QString &rubrik, const QString &key ) const
+QVariant Configuration::managerIni(const QString &rubrik, const QString &key) const
 {
     if (d->m_ManagerPath.isEmpty()) {
         findManagerBinaryPath();
@@ -369,6 +355,7 @@ QVariant Configuration::drtuxIni( const QString &rubrik, const QString &key ) co
 
 QString Configuration::glossaryPath() const
 {
+    /** \todo manage settings absolute path */
     if (d->m_ManagerPath.isEmpty()) {
         findManagerBinaryPath();
         if (d->m_ManagerPath.isEmpty())
@@ -392,7 +379,18 @@ QString Configuration::glossaryPath(GlossaryFor rubrik) const
     return QString();
 }
 
-QString Configuration::defaultListsPath(DefaultList rubrik) const
+QString Configuration::menuLibraryPath() const
+{
+    /** \todo manage settings absolute path */
+    if (d->m_ManagerPath.isEmpty()) {
+        findManagerBinaryPath();
+        if (d->m_ManagerPath.isEmpty())
+            return QString();
+    }
+    return Utils::isDirExists(d->m_ManagerPath + QDir::separator() + managerIni(DEFAULTLIST_RUB, MENULIST_PATH).toString());
+}
+
+QString Configuration::menuListsPath(DefaultList rubrik) const
 {
     QString tmp;
     switch (rubrik) {
@@ -402,16 +400,16 @@ QString Configuration::defaultListsPath(DefaultList rubrik) const
         case ImageDefaultList        : tmp = managerIni(DEFAULTLIST_RUB, DEFAULTLIST_IMA).toString(); break;
     }
     if (!tmp.isEmpty())
-        tmp.prepend(glossaryPath(ChampsInsertionGlossary) + QDir::separator());
+        tmp.prepend(menuLibraryPath() + QDir::separator());
     return Utils::isDirExists(tmp);
 }
 
 bool Configuration::deleteListCache() const
 {
     // 4. delete MedinTux cache
-    QDir cacheDir( QString("%1/%2").arg( glossaryPath(), GLOSSARY_CACHELIST_PATH) );
-    if (cacheDir.exists() ) {
-        QStringList list = cacheDir.entryList( QStringList() << "*" , QDir::Files);
+    QDir cacheDir(QString("%1/%2").arg(glossaryPath(), GLOSSARY_CACHELIST_PATH));
+    if (cacheDir.exists()) {
+        QStringList list = cacheDir.entryList(QStringList() << "*" , QDir::Files);
         int n = 0;
         for (int i = 0; i < list.size(); ++i) {
             if (QFile(cacheDir.path() + QDir::separator() + list.at(i)).remove())
@@ -446,8 +444,8 @@ QString Configuration::drtuxResourcesPath() const
     return Utils::isDirExists(tmp);
 }
 
-bool Configuration::addUserMenu( const QString &shortTitle, const QString &title,
-                                           const QString &script, const QString &iconAbsPath, const QString &keySequence )
+bool Configuration::addUserMenu(const QString &shortTitle, const QString &title,
+                                const QString &script, const QString &iconAbsPath, const QString &keySequence)
 {
     bool toReturn = true;
     QDir binDir(drtuxBinaryPath());
@@ -455,7 +453,8 @@ bool Configuration::addUserMenu( const QString &shortTitle, const QString &title
     // test drtux' users' menu path
     if (!binDir.exists(DRTUX_USERMENU_PATH)) {
         if (!binDir.mkdir(DRTUX_USERMENU_PATH) ) {
-            Utils::Log::addError( this, tr( "Unable to configure MedinTux : Menus path does not exists and can not be created. Path to DrTux binary : %1").arg(binDir.path() ) );
+            Utils::Log::addError( this, tr( "Unable to configure MedinTux : Menus path does not exists and can not be created. Path to DrTux binary : %1").arg(binDir.path()),
+                                  __FILE__, __LINE__);
             toReturn = false;
         } else {
             Utils::Log::addMessage( this, tr( "MedinTux Configuration : resources user menus path correctly created  %1.")
@@ -468,7 +467,8 @@ bool Configuration::addUserMenu( const QString &shortTitle, const QString &title
     if (!binDir.cd(shortTitle)) {
         if (!binDir.mkdir(shortTitle)) {
             Utils::Log::addError( this, tr( "Unable to configure MedinTux : %1 menu does not exists and can not be created. Path to DrTux binary : %2")
-                             .arg(shortTitle).arg(binDir.path() ) );
+                             .arg(shortTitle).arg(binDir.path() ),
+                             __FILE__, __LINE__ );
             toReturn = false;
         } else
             Utils::Log::addMessage( this, tr( "MedinTux Configuration : users' menu path correctly created %1.")
@@ -494,10 +494,12 @@ bool Configuration::addUserMenu( const QString &shortTitle, const QString &title
                                .arg(iconAbsPath) );
         else
             Utils::Log::addError( this, tr( "Unable to configure MedinTux : icon %1 can not be copied to %2.")
-                             .arg(iconAbsPath,to) );
+                             .arg(iconAbsPath,to),
+                             __FILE__, __LINE__ );
     } else {
         Utils::Log::addError( this, tr( "Unable to configure MedinTux : icon %1 does not exists.")
-                         .arg(iconAbsPath) );
+                         .arg(iconAbsPath),
+                         __FILE__, __LINE__ );
         toReturn = false;
     }
 
