@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                      *
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -105,7 +91,11 @@ namespace Time {
         DuringMeal,
         BeforeMeal,
         AfterMeal,
-        OutsideMeal
+        OutsideMeal,
+        OnlyIfMeal,
+        SeparatedFromFood,
+        SuggestedWithFood,
+        WithOrWithoutFood
     };
 
 
@@ -198,7 +188,7 @@ enum TitleInterpret {
         const char * const  PREVIOUS_TEXT         = QT_TRANSLATE_NOOP("tkConstants", "Previous");   /*!< \brief Default action text  \ingroup constants_actionmanager */
         const char * const  HOME_TEXT             = QT_TRANSLATE_NOOP("tkConstants", "Home");       /*!< \brief Default action text  \ingroup constants_actionmanager */
         const char * const  LISTADD_TEXT          = QT_TRANSLATE_NOOP("tkConstants", "Add to list");    /*!< \brief Default action text  \ingroup constants_actionmanager */
-        const char * const  LISTREMOVE_TEXT       = QT_TRANSLATE_NOOP("tkConstants", "Remove of list"); /*!< \brief Default action text  \ingroup constants_actionmanager */
+        const char * const  LISTREMOVE_TEXT       = QT_TRANSLATE_NOOP("tkConstants", "Remove from list"); /*!< \brief Default action text  \ingroup constants_actionmanager */
         const char * const  LISTMOVEUP_TEXT       = QT_TRANSLATE_NOOP("tkConstants", "Move item up");   /*!< \brief Default action text  \ingroup constants_actionmanager */
         const char * const  LISTMOVEDOWN_TEXT     = QT_TRANSLATE_NOOP("tkConstants", "Move item down"); /*!< \brief Default action text  \ingroup constants_actionmanager */
         const char * const  LISTCLEAR_TEXT        = QT_TRANSLATE_NOOP("tkConstants", "Clear");          /*!< \brief Default action text  \ingroup constants_actionmanager */
@@ -273,6 +263,7 @@ enum TitleInterpret {
         const char* const DRUGS                         = QT_TRANSLATE_NOOP("tkConstants", "Drugs");
         const char* const PROTOCOLS                     = QT_TRANSLATE_NOOP("tkConstants", "Protocols");
         const char* const INN                           = QT_TRANSLATE_NOOP("tkConstants", "INN");
+        const char* const ATC                           = QT_TRANSLATE_NOOP("tkConstants", "ATC");
         const char* const INTAKES                       = QT_TRANSLATE_NOOP("tkConstants", "intake(s)");
         const char* const VIEWINTERACTIONS_TEXT         = QT_TRANSLATE_NOOP("tkConstants", "View synthetic interactions");
         const char* const FROM                          = QT_TRANSLATE_NOOP("tkConstants", "from");
@@ -280,18 +271,28 @@ enum TitleInterpret {
         const char* const DURING                        = QT_TRANSLATE_NOOP("tkConstants", "during");
         const char* const EACH                          = QT_TRANSLATE_NOOP("tkConstants", "each");
         const char* const AND                           = QT_TRANSLATE_NOOP("tkConstants", "and");
+        const char* const ALLERGY_TO_1                  = QT_TRANSLATE_NOOP("tkConstants", "Allergy to %1");
+        const char* const INTOLERANCE_TO_1              = QT_TRANSLATE_NOOP("tkConstants", "Intolerance to %1");
+        const char* const NO_ALLERGIES_INTOLERANCES     = QT_TRANSLATE_NOOP("tkConstants", "No known allergies / intolerances");
+        const char* const KNOWN_ALLERGIES               = QT_TRANSLATE_NOOP("tkConstants", "Known allergies");
+        const char* const KNOWN_INTOLERANCES            = QT_TRANSLATE_NOOP("tkConstants", "Known intolerances");
+
         // Drugs Interactions
-        const char* const INTERACTION  = QT_TRANSLATE_NOOP("tkConstants", "Interaction");
-        const char* const TAKE_INTO_ACCOUNT  = QT_TRANSLATE_NOOP("tkConstants", "Take into account");
-        const char* const DISCOURAGED  = QT_TRANSLATE_NOOP("tkConstants", "Discouraged");
-        const char* const CONTRAINDICATION  = QT_TRANSLATE_NOOP("tkConstants", "Contraindication");
-        const char* const PRECAUTION_FOR_USE  = QT_TRANSLATE_NOOP("tkConstants", "Precaution for use");
-        const char* const INFORMATION  = QT_TRANSLATE_NOOP("tkConstants", "Information");
+        const char* const INTERACTION                   = QT_TRANSLATE_NOOP("tkConstants", "Interaction");
+        const char* const TAKE_INTO_ACCOUNT             = QT_TRANSLATE_NOOP("tkConstants", "Take into account");
+        const char* const DISCOURAGED                   = QT_TRANSLATE_NOOP("tkConstants", "Discouraged");
+        const char* const CONTRAINDICATION              = QT_TRANSLATE_NOOP("tkConstants", "Contraindication");
+        const char* const P450_IAM                      = QT_TRANSLATE_NOOP("tkConstants", "Cytochrome P450 interaction");
+        const char* const GPG_IAM                       = QT_TRANSLATE_NOOP("tkConstants", "Glycoprotein-P interaction");
+        const char* const PRECAUTION_FOR_USE            = QT_TRANSLATE_NOOP("tkConstants", "Precaution for use");
+        const char* const INFORMATION                   = QT_TRANSLATE_NOOP("tkConstants", "Information");
+        const char* const INN_DUPLICATION               = QT_TRANSLATE_NOOP("tkConstants", "Molecule is duplicated");
 
         // Account
         const char* const ACCOUNTANCY  = QT_TRANSLATE_NOOP("tkConstants", "Accountancy");
         const char* const BANK_DETAILS = QT_TRANSLATE_NOOP("tkConstants", "Bank details");
         const char* const AVAILABLE_MOVEMENTS = QT_TRANSLATE_NOOP("tkConstants", "Available movements");
+        const char* const MEDICAL_PROCEDURES = QT_TRANSLATE_NOOP("tkConstants", "Medical procedures");
 
         // Database related
         const char *const SQLITE_DRIVER_NOT_AVAILABLE = QT_TRANSLATE_NOOP("tkConstants", "SQLite driver is not available.");
@@ -299,26 +300,46 @@ enum TitleInterpret {
 
         // Time and periods
         const char* const DURATION   = QT_TRANSLATE_NOOP("tkConstants", "Duration");
-        const char* const SECONDS    = QT_TRANSLATE_NOOP("tkConstants", "second(s)");
-        const char* const MINUTES    = QT_TRANSLATE_NOOP("tkConstants", "minute(s)");
-        const char* const HOURS      = QT_TRANSLATE_NOOP("tkConstants", "hour(s)");
-        const char* const DAYS       = QT_TRANSLATE_NOOP("tkConstants", "day(s)");
-        const char* const WEEKS      = QT_TRANSLATE_NOOP("tkConstants", "week(s)");
-        const char* const MONTHS     = QT_TRANSLATE_NOOP("tkConstants", "month(s)");
-        const char* const QUARTERS   = QT_TRANSLATE_NOOP("tkConstants", "quarter(s)");
-        const char* const YEARS      = QT_TRANSLATE_NOOP("tkConstants", "year(s)");
-        const char* const DECADES    = QT_TRANSLATE_NOOP("tkConstants", "decade(s)");
+        const char* const SECOND_S    = QT_TRANSLATE_NOOP("tkConstants", "second(s)");
+        const char* const MINUTE_S    = QT_TRANSLATE_NOOP("tkConstants", "minute(s)");
+        const char* const HOUR_S      = QT_TRANSLATE_NOOP("tkConstants", "hour(s)");
+        const char* const DAY_S       = QT_TRANSLATE_NOOP("tkConstants", "day(s)");
+        const char* const WEEK_S      = QT_TRANSLATE_NOOP("tkConstants", "week(s)");
+        const char* const MONTH_S     = QT_TRANSLATE_NOOP("tkConstants", "month(s)");
+        const char* const QUARTER_S   = QT_TRANSLATE_NOOP("tkConstants", "quarter(s)");
+        const char* const YEAR_S      = QT_TRANSLATE_NOOP("tkConstants", "year(s)");
+        const char* const DECADE_S    = QT_TRANSLATE_NOOP("tkConstants", "decade(s)");
+
+        const char* const SECOND    = QT_TRANSLATE_NOOP("tkConstants", "second");
+        const char* const MINUTE    = QT_TRANSLATE_NOOP("tkConstants", "minute");
+        const char* const HOUR      = QT_TRANSLATE_NOOP("tkConstants", "hour");
+        const char* const DAY       = QT_TRANSLATE_NOOP("tkConstants", "day");
+        const char* const WEEK      = QT_TRANSLATE_NOOP("tkConstants", "week");
+        const char* const MONTH     = QT_TRANSLATE_NOOP("tkConstants", "month");
+        const char* const QUARTER   = QT_TRANSLATE_NOOP("tkConstants", "quarter");
+        const char* const YEAR      = QT_TRANSLATE_NOOP("tkConstants", "year");
+        const char* const DECADE    = QT_TRANSLATE_NOOP("tkConstants", "decade");
+
+        const char* const SECONDS    = QT_TRANSLATE_NOOP("tkConstants", "seconds");
+        const char* const MINUTES    = QT_TRANSLATE_NOOP("tkConstants", "minutes");
+        const char* const HOURS      = QT_TRANSLATE_NOOP("tkConstants", "hours");
+        const char* const DAYS       = QT_TRANSLATE_NOOP("tkConstants", "days");
+        const char* const WEEKS      = QT_TRANSLATE_NOOP("tkConstants", "weeks");
+        const char* const MONTHS     = QT_TRANSLATE_NOOP("tkConstants", "months");
+        const char* const QUARTERS   = QT_TRANSLATE_NOOP("tkConstants", "quarters");
+        const char* const YEARS      = QT_TRANSLATE_NOOP("tkConstants", "years");
+        const char* const DECADES    = QT_TRANSLATE_NOOP("tkConstants", "decades");
 
         // Day
         const char* const WAKEUPTIME           = QT_TRANSLATE_NOOP("tkConstants", "wake up");
         const char* const BREAKFAST            = QT_TRANSLATE_NOOP("tkConstants", "breakfast");
-        const char* const TENOCLOCKBRUNCH      = QT_TRANSLATE_NOOP("tkConstants", "ten o'clock brunch");
+        const char* const TENOCLOCKBRUNCH      = QT_TRANSLATE_NOOP("tkConstants", "mid-morning");
         const char* const MORNING              = QT_TRANSLATE_NOOP("tkConstants", "morning");
         const char* const MIDDAY               = QT_TRANSLATE_NOOP("tkConstants", "midday");
         const char* const LUNCH                = QT_TRANSLATE_NOOP("tkConstants", "lunch");
         const char* const AFTERNOON            = QT_TRANSLATE_NOOP("tkConstants", "afternoon");
-        const char* const TEATIME              = QT_TRANSLATE_NOOP("tkConstants", "tea time");
-        const char* const DINER                = QT_TRANSLATE_NOOP("tkConstants", "diner");
+        const char* const TEATIME              = QT_TRANSLATE_NOOP("tkConstants", "mid-afternoon");
+        const char* const DINER                = QT_TRANSLATE_NOOP("tkConstants", "dinner");
         const char* const EVENING              = QT_TRANSLATE_NOOP("tkConstants", "evening");
         const char* const BEDTIME              = QT_TRANSLATE_NOOP("tkConstants", "bedtime");
 
@@ -328,6 +349,10 @@ enum TitleInterpret {
         const char* const AFTERMEAL           = QT_TRANSLATE_NOOP("tkConstants", "after meal");
         const char* const BEFOREMEAL          = QT_TRANSLATE_NOOP("tkConstants", "before meal");
         const char* const NOTDURINGMEAL       = QT_TRANSLATE_NOOP("tkConstants", "not during meal");
+        const char* const ONLYIFMEAL          = QT_TRANSLATE_NOOP("tkConstants", "only if meal");
+        const char* const SEPARATEDFROMFOOD   = QT_TRANSLATE_NOOP("tkConstants", "separated from food (1-2 hours)");
+        const char* const SUGGESTEDWITHFOOD   = QT_TRANSLATE_NOOP("tkConstants", "suggested with food");
+        const char* const WITHORWITHOUTFOOD   = QT_TRANSLATE_NOOP("tkConstants", "with or without food");
 
         // Splashscreen messages
         const char* const USING_LIBRARY_1                   = QT_TRANSLATE_NOOP("tkConstants", "Using library : %1");
@@ -362,10 +387,12 @@ enum TitleInterpret {
         const char* const SAVE_AND_RESTORE                  = QT_TRANSLATE_NOOP("tkConstants", "Save and restore");
 
         // Files and Paths
+        const char* const PATH                               = QT_TRANSLATE_NOOP("tkConstants", "Path");
         const char* const PATH_1_DOESNOT_EXISTS              = QT_TRANSLATE_NOOP("tkConstants", "Path %1 does not exist");
         const char* const PATH_1_ISNOT_EMPTY                 = QT_TRANSLATE_NOOP("tkConstants", "Path %1 is not empty");
         const char* const PATH_1_CONTAINS_DIRS               = QT_TRANSLATE_NOOP("tkConstants", "Path %1 contains dirs");
         const char* const PATH_1_CANNOT_BE_REMOVED           = QT_TRANSLATE_NOOP("tkConstants", "Path %1 can not be removed");
+        const char* const PATH_1_CANNOT_BE_CREATED           = QT_TRANSLATE_NOOP("tkConstants", "Path %1 can not be created");
         const char* const CREATE_DIR_1                       = QT_TRANSLATE_NOOP("tkConstants", "Creating dir %1");
         const char* const FILE_1_DOESNOT_EXISTS              = QT_TRANSLATE_NOOP("tkConstants", "File %1 does not exist");
         const char* const FILE_1_ISNOT_READABLE              = QT_TRANSLATE_NOOP("tkConstants", "File %1 is not readable");
@@ -477,6 +504,8 @@ enum TitleInterpret {
         const char* const PATIENTS     = QT_TRANSLATE_NOOP("tkConstants", "Patients");
         const char* const PATIENT_INFORMATION  = QT_TRANSLATE_NOOP("tkConstants", "Patient informations");
         const char* const PATIENT_DATABASE  = QT_TRANSLATE_NOOP("tkConstants", "Patient database");
+        const char* const CLEAR_PATIENT_INFOS = QT_TRANSLATE_NOOP("tkConstants", "Clear patient's information");
+        const char* const TOGGLE_PATIENT_INFORMATIONS = QT_TRANSLATE_NOOP("tkConstants", "Toggle patient's information");
 
         // Genders
         const char* const MALE          = QT_TRANSLATE_NOOP("tkConstants", "Male");
@@ -545,6 +574,7 @@ namespace ConstantTranslations {
 TRUTILS_EXPORT QString tkTr(const char* toTr, const int plurials=1);
 TRUTILS_EXPORT QStringList periods();
 TRUTILS_EXPORT QString period(int id);
+TRUTILS_EXPORT QString periodPlurialForm(int id, int nb = 1, const QString &defaultValue = QString::null);
 TRUTILS_EXPORT QStringList dailySchemeList();
 TRUTILS_EXPORT QStringList dailySchemeXmlTagList();
 TRUTILS_EXPORT QString dailyScheme(const int dailySchemeFlag);
