@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -38,7 +24,7 @@
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
 /**
-  \class Database
+  \class Utils::Database
  \brief this class is a base class for databases. It manages scheme and creates SQL queries.
     The idea is to create a database scheme dynamically. Your superbase must hold the enums
     corresponding to the tables and the fields of each tables.\n
@@ -71,12 +57,11 @@
     // If you want to create database if it doesn't exist define the member createDatabase() in your superclass.
 
     \endcode
-  \ingroup toolkit
-  \ingroup database_toolkit
 */
 
 #include "database.h"
 #include "log.h"
+#include "global.h"
 
 #include <translationutils/constanttranslations.h>
 
@@ -89,8 +74,9 @@
 #include <QMap>
 #include <QTreeWidgetItem>
 #include <QTreeWidget>
+#include <QProgressDialog>
 
-enum {WarnSqlCommands=false};
+enum { WarnSqlCommands=false , WarnLogMessages = false };
 
 using namespace Utils;
 using namespace Utils::Internal;
@@ -174,7 +160,7 @@ void Database::logAvailableDrivers()
         }
     }
     tmp.chop(3);
-    Utils::Log::addMessage("Database", QString("Available drivers : %1").arg(tmp));
+    Utils::Log::addMessage("Database", QString("Available drivers: %1").arg(QSqlDatabase::drivers().join(" ; ")));
 }
 
 
@@ -231,7 +217,16 @@ bool Database::createConnection(const QString & connectionName, const QString &
                                    const int port,
                                    CreationOption createOption
                                    )
-{
+{   
+    if (WarnLogMessages)
+        qDebug() << __FILE__ << QString::number(__LINE__) << connectionName
+                << dbName
+                <<pathOrHostName
+                << access
+                << driver
+                << login
+                << password
+                << QString::number(port) ;
     bool toReturn = true;
     d->m_ConnectionName = "";
 
@@ -239,39 +234,42 @@ bool Database::createConnection(const QString & connectionName, const QString &
     switch (driver) {
     case SQLite :
         {
-            Utils::Log::addMessage("Database", QString("Trying to connect database %1 with %2 driver")
+            if (WarnLogMessages)
+                Utils::Log::addMessage("Database", QString("Trying to connect database %1 with %2 driver")
                                    .arg(dbName)
                                    .arg("SQLite"));
             if (!QSqlDatabase::isDriverAvailable("QSQLITE")) {
                 Log::addError("Database", QCoreApplication::translate("Database",
                                                                       "ERROR : %1 driver is not available")
-                              .arg("SQLite"));
+                              .arg("SQLite"), __FILE__, __LINE__);
                 return false;
             }
             break;
         }
     case MySQL:
         {
-            Utils::Log::addMessage("Database", QString("Trying to connect database %1 with %2 driver")
+            if (WarnLogMessages)
+                Utils::Log::addMessage("Database", QString("Trying to connect database %1 with %2 driver")
                                    .arg(dbName)
                                    .arg("MySQL"));
             if (!QSqlDatabase::isDriverAvailable("QMYSQL")) {
                 Log::addError("Database", QCoreApplication::translate("Database",
                                                                       "ERROR : %1 driver is not available")
-                              .arg("MySQL"));
+                              .arg("MySQL"), __FILE__, __LINE__);
                 return false;
             }
             break;
         }
     case PostSQL :
         {
-            Utils::Log::addMessage("Database", QString("Trying to connect database %1 with %2 driver")
+            if (WarnLogMessages)
+                Utils::Log::addMessage("Database", QString("Trying to connect database %1 with %2 driver")
                                    .arg(dbName)
                                    .arg("PostGre SQL"));
             if (!QSqlDatabase::isDriverAvailable("QPSQL")) {
                 Log::addError("Database", QCoreApplication::translate("Database",
                                                                       "ERROR : %1 driver is not available")
-                              .arg("PostGreSQL"));
+                              .arg("PostGreSQL"), __FILE__, __LINE__);
                 return false;
             }
         }
@@ -279,7 +277,8 @@ bool Database::createConnection(const QString & connectionName, const QString &
 
     // does connection already exists ?
     if (QSqlDatabase::contains(connectionName)) {
-        Log::addMessage("Database", QCoreApplication::translate("Database",
+        if (WarnLogMessages)
+            Log::addMessage("Database", QCoreApplication::translate("Database",
                                                                 "WARNING : %1 database already in use")
                         .arg(connectionName));
         d->m_ConnectionName = connectionName;
@@ -302,10 +301,12 @@ bool Database::createConnection(const QString & connectionName, const QString &
             bool ok = DB.open();
             if (!ok) {
                 Utils::Log::addError("Database", QString("Unable to connect to the server %1 - %2")
-                                     .arg(pathOrHostName).arg(DB.lastError().text()));
+                                     .arg(pathOrHostName).arg(DB.lastError().text()),
+                                     __FILE__, __LINE__);
                 return false;
             }
-            Utils::Log::addMessage("Database", QString("Connected to host %1").arg(pathOrHostName));
+            if (WarnLogMessages)
+                Utils::Log::addMessage("Database", QString("Connected to host %1").arg(pathOrHostName));
             break;
         }
     case PostSQL:
@@ -324,11 +325,12 @@ bool Database::createConnection(const QString & connectionName, const QString &
                 if (createOption == CreateDatabase) {
                     if (!createDatabase(connectionName, dbName, pathOrHostName, access, driver, login, password, port, createOption)) {
                         Log::addError("Database", QCoreApplication::translate("Database",
-                                                                              "ERROR : %1 database does not exist and can not be created. Path = %2").arg(dbName, pathOrHostName));
+                                                                              "ERROR : %1 database does not exist and can not be created. Path = %2").arg(dbName, pathOrHostName), __FILE__, __LINE__);
                         return false;
                     }
                 } else { // Warn Only
-                    Log::addMessage("Database", QCoreApplication::translate("Database",
+                    if (WarnLogMessages)
+                        Log::addMessage("Database", QCoreApplication::translate("Database",
                                                                             "ERROR : %1 database does not exist and can not be created. Path = %2").arg(dbName, pathOrHostName));
                     return false;
                 }
@@ -342,22 +344,25 @@ bool Database::createConnection(const QString & connectionName, const QString &
             bool ok = DB.open();
             if (!ok) {
                 Utils::Log::addError("Database", QString("Unable to connect to the database %1 - %2")
-                                     .arg(dbName).arg(DB.lastError().text()));
+                                     .arg(dbName).arg(DB.lastError().text()),
+                                     __FILE__, __LINE__);
                 if (createOption == CreateDatabase) {
                     if (!createDatabase(connectionName, dbName, pathOrHostName, access, driver, login, password, port, createOption)) {
                         Log::addError("Database", QCoreApplication::translate("Database",
                                       "ERROR : %1 database does not exist and can not be created. Path = %2")
-                                      .arg(dbName, pathOrHostName));
+                                      .arg(dbName, pathOrHostName), __FILE__, __LINE__);
                         return false;
                     }
                 } else { // Warn Only
+                    if (WarnLogMessages)
                         Log::addMessage("Database", QCoreApplication::translate("Database",
                                         "ERROR : %1 database does not exist and can not be created. Path = %2")
                                         .arg(dbName, pathOrHostName));
-                        return false;
+                    return false;
                 }
             }
-            Utils::Log::addMessage("Database", QString("Connected to database %1").arg(dbName));
+            if (WarnLogMessages)
+                Utils::Log::addMessage("Database", QString("Connected to database %1").arg(dbName));
             break;
         }
     case PostSQL:
@@ -373,7 +378,7 @@ bool Database::createConnection(const QString & connectionName, const QString &
         {
             if (!QFileInfo(fileName).isReadable()) {
                 Log::addError("Database", QCoreApplication::translate("Database", "ERROR : Database %1 is not readable. Path : %2")
-                              .arg(dbName, pathOrHostName));
+                              .arg(dbName, pathOrHostName), __FILE__, __LINE__);
                 toReturn = false;
             }
             break;
@@ -383,14 +388,14 @@ bool Database::createConnection(const QString & connectionName, const QString &
             if (!DB.open()) {
                 Log::addError("Database", QCoreApplication::translate("Database",
                               "ERROR : Database %1 is not readable. Path : %2")
-                              .arg(dbName, pathOrHostName));
+                              .arg(dbName, pathOrHostName), __FILE__, __LINE__);
                 return false;
             }
             QSqlQuery query("SHOW GRANTS FOR CURRENT_USER;", DB);
             if (!query.isActive()) {
                 Log::addError("Database", QCoreApplication::translate("Database",
                               "ERROR : Database %1 is not readable. Path : %2")
-                              .arg(dbName, pathOrHostName));
+                              .arg(dbName, pathOrHostName), __FILE__, __LINE__);
                 Log::addQueryError("Database", query);
                 return false;
             } else {
@@ -418,7 +423,7 @@ bool Database::createConnection(const QString & connectionName, const QString &
                 if (!QFileInfo(fileName).isWritable()) {
                     Log::addError("Database", QCoreApplication::translate("Database",
                                   "ERROR : Database %1 is not writable. Path : %2.")
-                                  .arg(dbName, pathOrHostName));
+                                  .arg(dbName, pathOrHostName), __FILE__, __LINE__);
                     toReturn = false;
                 }
                 break;
@@ -455,18 +460,21 @@ bool Database::createConnection(const QString & connectionName, const QString &
              break;
     }
 
-    Log::addMessage("Database", QCoreApplication::translate("Database",  "INFO : database %1 connection = %2")
-                       .arg(connectionName).arg(DB.open()));
+    DB.open();
+    if (WarnLogMessages)
+        Log::addMessage("Database", QCoreApplication::translate("Database",  "INFO : database %1 connection = %2")
+                       .arg(connectionName).arg(DB.isOpen()));
 
     // test connection
     if (!DB.isOpen()) {
         Log::addError("Database", QCoreApplication::translate("Database",
                                                                     "WARNING : can not open database %1 : %2 \n %3 ")
-                         .arg(connectionName, DB.lastError().driverText(), DB.lastError().databaseText()));
+                         .arg(connectionName, DB.lastError().driverText(), DB.lastError().databaseText()), __FILE__, __LINE__);
         toReturn = false;
     }
     else {
-        Log::addMessage("Database", QCoreApplication::translate("Database", "INFO : database %1 installed. Path : %2")
+        if (WarnLogMessages)
+            Log::addMessage("Database", QCoreApplication::translate("Database", "INFO : database %1 installed. Path : %2")
                            .arg(connectionName, pathOrHostName));
     }
     // return boolean
@@ -514,7 +522,7 @@ int Database::addField(const int & tableref, const int & fieldref, const QString
     d->m_Fields.insert(ref , name);
     d->m_TypeOfField.insert(ref , type);
     d->m_DefaultFieldValue.insert(ref, defaultValue);
-    return d->m_Fields.key(name)- (tableref * 1000);
+    return d->m_Fields.key(name) - (tableref * 1000);
 }
 
 /** \brief Verify that the dynamically scheme passed is corresponding to the real database scheme. */
@@ -536,17 +544,16 @@ bool Database::checkDatabaseScheme()
         QSqlRecord rec = DB.record(d->m_Tables.value(i));
         if (rec.count() != d->m_Tables_Fields.values(i).count()) {
             Log::addError("Database", QCoreApplication::translate("Database", "Database Scheme Error : wrong number of fields for table %1")
-                                   .arg(d->m_Tables.value(i)));
+                                   .arg(d->m_Tables.value(i)), __FILE__, __LINE__);
             return false;
         }
         QList<int> fields = d->m_Tables_Fields.values(i);
         qSort(fields);
         int id = 0;
         foreach(int f, fields) {
-            if (d->m_Fields.value(f)!= rec.field(id).name())
-            {
-                Log::addError("Database", QCoreApplication::translate("Database", "Database Scheme Error : field number %1 differs : %2 instead of %3")
-                                   .arg(id).arg(d->m_Fields.value(f), rec.field(id).name()));
+            if (d->m_Fields.value(f)!= rec.field(id).name()) {
+                Log::addError("Database", QCoreApplication::translate("Database", "Database Scheme Error : field number %1 differs : %2 instead of %3 in table %4")
+                                   .arg(id).arg(d->m_Fields.value(f), rec.field(id).name(), d->m_Tables.value(i)), __FILE__, __LINE__);
                 return false;
             }
             id++;
@@ -556,23 +563,23 @@ bool Database::checkDatabaseScheme()
 }
 
 
-QString Database::field(const int & tableref, const int & fieldref)const
+QString Database::field(const int &tableref, const int &fieldref)const
 {
-    if (! d->m_Tables.contains(tableref))
+    if (!d->m_Tables.contains(tableref))
         return QString::null;
-    if (! d->m_Tables_Fields.keys().contains(tableref))
+    if (!d->m_Tables_Fields.keys().contains(tableref))
         return QString::null;
-    if (! d->m_Fields.keys().contains(fieldref + (tableref * 1000)))
+    if (!d->m_Fields.keys().contains(fieldref + (tableref * 1000)))
         return QString::null;
 
     return d->m_Fields.value(fieldref + (tableref * 1000));
 }
 
-QStringList Database::fields(const int & tableref)const
+QStringList Database::fields(const int &tableref)const
 {
-    if (! d->m_Tables.contains(tableref))
+    if (!d->m_Tables.contains(tableref))
         return QStringList();
-    if (! d->m_Tables_Fields.keys().contains(tableref))
+    if (!d->m_Tables_Fields.keys().contains(tableref))
         return QStringList();
 
     QList<int> list = d->m_Tables_Fields.values(tableref);
@@ -615,10 +622,10 @@ QString Database::getWhereClause(const int & tableref, const QHash<int, QString>
     return where;
 }
 
-QString Database::select(const int & tableref, const int & fieldref, const QHash<int, QString> & conditions) const
+QString Database::select(const int &tableref, const int &fieldref, const QHash<int, QString> &conditions) const
 {
     QString toReturn;
-    toReturn = QString("SELECT %1 FROM `%2` WHERE %3")
+    toReturn = QString("SELECT `%2`.`%1` FROM `%2` WHERE %3")
             .arg(field(tableref, fieldref))
             .arg(table(tableref))
             .arg(getWhereClause(tableref, conditions));
@@ -630,7 +637,7 @@ QString Database::select(const int & tableref, const int & fieldref, const QHash
 QString Database::select(const int & tableref, const int & fieldref) const
 {
     QString toReturn;
-    toReturn = QString("SELECT %1 FROM `%2`")
+    toReturn = QString("SELECT `%2`.`%1` FROM `%2`")
             .arg(field(tableref, fieldref))
             .arg(table(tableref));
     if (WarnSqlCommands)
@@ -648,9 +655,16 @@ QString Database::selectDistinct(const int & tableref, const int & fieldref) con
     return select(tableref, fieldref).replace("SELECT", "SELECT DISTINCT");
 }
 
+QString Database::fieldEquality(const int tableRef1, const int fieldRef1, const int tableRef2, const int fieldRef2) const
+{
+    return QString("`%1`.`%2`=`%3`.`%4`")
+            .arg(table(tableRef1), field(tableRef1, fieldRef1))
+            .arg(table(tableRef2), field(tableRef2, fieldRef2));
+}
+
 int Database::count(const int & tableref, const int & fieldref, const QString &filter) const
 {
-    QString req = QString("SELECT count(%1) FROM %2").arg(d->m_Fields.value(1000 * tableref + fieldref)).arg(d->m_Tables[tableref]);
+    QString req = QString("SELECT count(`%1`) FROM `%2`").arg(d->m_Fields.value(1000 * tableref + fieldref)).arg(d->m_Tables[tableref]);
     if (!filter.isEmpty())
         req += " WHERE " + filter;
     if (WarnSqlCommands)
@@ -668,15 +682,14 @@ int Database::count(const int & tableref, const int & fieldref, const QString &f
     return -1;
 }
 
-double Database::max(const int &tableref, const int &fieldref, const int &groupBy, const QString &filter) const
+double Database::max(const int &tableref, const int &fieldref, const QString &filter) const
 {
-    QString req = QString("SELECT max(%1) FROM %2 GROUP BY %3")
+    QString req = QString("SELECT max(%1) FROM %2")
                   .arg(d->m_Fields.value(1000 * tableref + fieldref))
-                  .arg(d->m_Tables[tableref])
-                  .arg(d->m_Fields.value(1000 * tableref + groupBy));
+                  .arg(d->m_Tables[tableref]);
     if (!filter.isEmpty())
         req += " WHERE " + filter;
-//    if (WarnSqlCommands)
+    if (WarnSqlCommands)
         qWarning() << req;
     QSqlQuery q(req, database());
     if (q.isActive()) {
@@ -691,12 +704,35 @@ double Database::max(const int &tableref, const int &fieldref, const int &groupB
     return 0;
 }
 
-QString Database::select(const int & tableref, const QList<int> &fieldsref, const QHash<int, QString> & conditions)const
+double Database::max(const int &tableref, const int &fieldref, const int &groupBy, const QString &filter) const
+{
+    QString req = QString("SELECT max(%1) FROM %2 GROUP BY %3")
+                  .arg(d->m_Fields.value(1000 * tableref + fieldref))
+                  .arg(d->m_Tables[tableref])
+                  .arg(d->m_Fields.value(1000 * tableref + groupBy));
+    if (!filter.isEmpty())
+        req += " WHERE " + filter;
+    if (WarnSqlCommands)
+        qWarning() << req;
+    QSqlQuery q(req, database());
+    if (q.isActive()) {
+        if (q.next()) {
+            return q.value(0).toDouble();
+        } else {
+            Utils::Log::addQueryError("Database", q);
+        }
+    } else {
+        Utils::Log::addQueryError("Database", q);
+    }
+    return 0;
+}
+
+QString Database::select(const int &tableref, const QList<int> &fieldsref, const QHash<int, QString> & conditions)const
 {
     QString toReturn;
     QString tmp;
     foreach(const int & i, fieldsref)
-        tmp += "`" + field(tableref, i)+ "`, ";
+        tmp += "`" + table(tableref) + "`.`" + field(tableref, i)+ "`, ";
     if (tmp.isEmpty())
         return QString::null;
     tmp.chop(2);
@@ -713,8 +749,8 @@ QString Database::select(const int & tableref,const  QList<int> &fieldsref)const
 {
     QString toReturn;
     QString tmp;
-    foreach(const int & i, fieldsref)
-        tmp += "`" + field(tableref, i)+ "`, ";
+    foreach(const int &i, fieldsref)
+        tmp += "`" + table(tableref) + "`.`" + field(tableref, i)+ "`, ";
     if (tmp.isEmpty())
         return QString::null;
     tmp.chop(2);
@@ -726,14 +762,15 @@ QString Database::select(const int & tableref,const  QList<int> &fieldsref)const
     return toReturn;
 }
 
-QString Database::select(const int & tableref, const QHash<int, QString> & conditions)const
+QString Database::select(const int &tableref, const QHash<int, QString> &conditions)const
 {
     QString toReturn;
     QString tmp;
     QList<int> list = d->m_Tables_Fields.values(tableref);
     qSort(list);
-    foreach(const int & i, list)
-        tmp += "`" + d->m_Fields.value(i)+ "`, ";
+    foreach(const int &i, list)
+        tmp += "`" + table(tableref) + "`.`" + d->m_Fields.value(i) + "`, ";
+//        tmp += "`" + d->m_Fields.value(i)+ "`, ";
     if (tmp.isEmpty())
         return QString::null;
     tmp.chop(2);
@@ -746,14 +783,14 @@ QString Database::select(const int & tableref, const QHash<int, QString> & condi
     return toReturn;
 }
 
-QString Database::select(const int & tableref) const
+QString Database::select(const int &tableref) const
 {
     QString toReturn;
     QString tmp;
     QList<int> list = d->m_Tables_Fields.values(tableref);
     qSort(list);
     foreach(const int & i, list)
-        tmp += "`" + d->m_Fields.value(i)+ "`, ";
+        tmp += "`" + table(tableref) + "`.`" + d->m_Fields.value(i) + "`, ";
     if (tmp.isEmpty())
         return QString::null;
     tmp.chop(2);
@@ -765,7 +802,7 @@ QString Database::select(const int & tableref) const
     return toReturn;
 }
 
-QString Database::prepareInsertQuery(const int & tableref) const
+QString Database::prepareInsertQuery(const int tableref) const
 {
     QString toReturn;
     QString fields;
@@ -788,7 +825,7 @@ QString Database::prepareInsertQuery(const int & tableref) const
     return toReturn;
 }
 
-QString Database::prepareUpdateQuery(const int & tableref, int fieldref, const QHash<int, QString> &conditions)
+QString Database::prepareUpdateQuery(const int tableref, const int fieldref, const QHash<int, QString> &conditions)
 {
     QString toReturn;
     toReturn = QString("UPDATE `%1` SET `%2` = ? WHERE %4")
@@ -803,7 +840,27 @@ QString Database::prepareUpdateQuery(const int & tableref, int fieldref, const Q
     return toReturn;
 }
 
-QString Database::prepareUpdateQuery(const int & tableref, int fieldref)
+QString Database::prepareUpdateQuery(const int tableref, const QList<int> &fieldref, const QHash<int, QString> &conditions)
+{
+    QString toReturn;
+    QString tmp;
+    foreach(const int &i, fieldref) {
+        tmp += "`" + field(tableref, i) + "`= ?, ";
+    }
+    tmp.chop(2);
+    toReturn = QString("UPDATE `%1` SET %2 WHERE %4")
+               .arg(table(tableref))
+               .arg(tmp)
+               .arg(getWhereClause(tableref, conditions));
+    // UPDATE tbl_name [, tbl_name ...]
+    // SET col_name1=expr1 [, col_name2=expr2 ...]
+    // WHERE where_definition
+    if (WarnSqlCommands)
+        qWarning() << toReturn;
+    return toReturn;
+}
+
+QString Database::prepareUpdateQuery(const int tableref, const int fieldref)
 {
     QString toReturn;
     toReturn = QString("UPDATE `%1` SET `%2` = ?")
@@ -817,14 +874,14 @@ QString Database::prepareUpdateQuery(const int & tableref, int fieldref)
     return toReturn;
 }
 
-QString Database::prepareUpdateQuery(const int & tableref, const QHash<int, QString> &conditions)
+QString Database::prepareUpdateQuery(const int tableref, const QHash<int, QString> &conditions)
 {
     QString toReturn;
     QString tmp;
     foreach(const QString &f, fields(tableref))
         tmp += QString ("`%1`=? , ").arg(f);
     tmp.chop(2);
-    toReturn = QString("UPDATE `%1` SET \n%2 \nWHERE %4")
+    toReturn = QString("UPDATE `%1` SET \n%2 \nWHERE %3")
                .arg(table(tableref))
                .arg(tmp)
                .arg(getWhereClause(tableref, conditions));
@@ -836,7 +893,7 @@ QString Database::prepareUpdateQuery(const int & tableref, const QHash<int, QStr
     return toReturn;
 }
 
-QString Database::prepareUpdateQuery(const int & tableref)
+QString Database::prepareUpdateQuery(const int tableref)
 {
     QString toReturn;
     QString tmp;
@@ -854,7 +911,7 @@ QString Database::prepareUpdateQuery(const int & tableref)
     return toReturn;
 }
 
-bool Database::executeSQL(const QStringList & list, const QSqlDatabase & DB) const
+bool Database::executeSQL(const QStringList &list, const QSqlDatabase &DB)
 {
     if (!DB.isOpen())
         return false;
@@ -874,7 +931,7 @@ bool Database::executeSQL(const QStringList & list, const QSqlDatabase & DB) con
     return true;
 }
 
-bool Database::executeSQL(const QString &req, const QSqlDatabase & DB) const
+bool Database::executeSQL(const QString &req, const QSqlDatabase & DB)
 {
     if (req.isEmpty())
         return false;
@@ -883,6 +940,152 @@ bool Database::executeSQL(const QString &req, const QSqlDatabase & DB) const
     return executeSQL(list, DB);
 }
 
+bool Database::executeSqlFile(const QString &connectionName, const QString &fileName, QProgressDialog *dlg)
+{
+    if (!QFile::exists(fileName)) {
+        Utils::Log::addError("Database", tkTr(Trans::Constants::FILE_1_DOESNOT_EXISTS).arg(fileName),
+                             __FILE__, __LINE__);
+        return false;
+    }
+
+    QFile file(fileName);
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        Utils::Log::addError("Database", tkTr(Trans::Constants::FILE_1_ISNOT_READABLE).arg(fileName), __FILE__, __LINE__);
+        return false;
+    }
+
+    // execute all sql queries
+    QString req = QString::fromUtf8(file.readAll());
+    req.replace("\n\n", "\n");
+    req.replace("\n\n", "\n");
+    req.replace("\n\n", "\n");
+    req.replace("\n\n", "\n");
+    req.replace("\n\n", "\n");
+
+    QStringList list = req.split("\n");
+    QSqlDatabase DB = QSqlDatabase::database(connectionName);
+    if (!DB.open())
+        return false;
+//    if (!DB.transaction()) {
+//        Utils::Log::addError("Tools", "Can not create transaction. Tools::executeSqlFile()", __FILE__, __LINE__);
+//        return false;
+//    }
+
+    req.clear();
+    QStringList queries;
+    // Reconstruct req : removes comments
+    foreach(const QString &s, list) {
+        if (s.startsWith("--")) {
+            continue;
+        }
+        req += s + " \n";
+        if (s.endsWith(";")) {
+            queries.append(req);
+            req.clear();
+        }
+    }
+
+    // Execute queries
+    if (dlg)
+        dlg->setRange(0, queries.count());
+
+    foreach(const QString &sql, queries) {
+        QString q = sql.simplified();
+        // Do not processed empty strings
+        if (q.isEmpty())
+            continue;
+
+        // No SQLite extra commands
+        if (q.startsWith("."))
+            continue;
+
+        // No BEGIN, No COMMIT
+        if (q.startsWith("BEGIN", Qt::CaseInsensitive) || q.startsWith("COMMIT", Qt::CaseInsensitive))
+            continue;
+
+        QSqlQuery query(sql, DB);
+        if (!query.isActive()) {
+            Utils::Log::addQueryError("Database", query, __FILE__, __LINE__);
+//            DB.rollback();
+            return false;
+        }
+
+        if (dlg)
+            dlg->setValue(dlg->value()+1);
+    }
+//    DB.commit();
+    return true;
+}
+
+bool Database::importCsvToDatabase(const QString &connectionName, const QString &fileName, const QString &table, const QString &separator, bool ignoreFirstLine)
+{
+    QString content = Utils::readTextFile(fileName, Utils::DontWarnUser);
+    if (content.isEmpty())
+        return false;
+    QStringList lines = content.split("\n", QString::SkipEmptyParts);
+    content.clear();
+    int start = 0;
+    if (ignoreFirstLine)
+        start = 1;
+
+    // get database
+    QSqlDatabase db = QSqlDatabase::database(connectionName);
+    if (!db.isOpen()) {
+        if (!db.open()) {
+            Utils::Log::addError("Database", tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
+                                 .arg(db.connectionName(), db.lastError().text()));
+            return false;
+        }
+    }
+
+    // get table field's name
+    if (!db.tables().contains(table)) {
+        Utils::Log::addError("Database", "No table found");
+        return false;
+    }
+    // prepare the sql query
+    QSqlRecord record = db.record(table);
+    QString req = "INSERT INTO " + table + " (\n";
+    for(int i = 0; i < record.count(); ++i) {
+        req += record.fieldName(i) + ", \n";
+    }
+    req.chop(3);
+    req += "\n) VALUES (";
+
+    db.transaction();
+
+    for(int i = start; i < lines.count(); ++i) {
+        QStringList values = lines.at(i).split(separator, QString::KeepEmptyParts);
+//        qWarning() << lines.at(i) << separator << values;
+        QString reqValues;
+        foreach(const QString &val, values) {
+            if (val.isEmpty()) {
+                reqValues += "NULL, ";
+            } else {
+                if (val.startsWith("'") && val.endsWith("'")) {
+                    reqValues += val + ", ";
+                } else if (val.contains(QRegExp("\\D", Qt::CaseInsensitive))) {
+                    QString tmp = val;
+                    reqValues += "\"" + tmp.replace("\"", "“") + "\", ";
+                } else {
+                    reqValues += val + ", ";
+                }
+            }
+        }
+        reqValues.chop(2);
+        reqValues += ");\n";
+        QSqlQuery query(req + reqValues, db);
+        if (!query.isActive()) {
+            Utils::Log::addQueryError("Database", query, __FILE__, __LINE__);
+        }
+//        qWarning() << lines.at(i) << req + reqValues << values;
+    }
+
+    db.commit();
+
+    return true;
+}
+
 bool Database::createTable(const int & tableref) const
 {
     if (!d->m_Tables.contains(tableref))
@@ -912,7 +1115,8 @@ bool Database::createTables() const
     foreach(const int & i, list)
         if(!createTable(i)) {
             toReturn = false;
-            Utils::Log::addError("Database", QCoreApplication::translate("Database", "Can not create table %1").arg(table(i)));
+            Utils::Log::addError("Database", QCoreApplication::translate("Database", "Can not create table %1").arg(table(i)),
+                                 __FILE__, __LINE__);
         }
     return toReturn;
 }
@@ -1082,18 +1286,21 @@ QString Database::prepareDeleteQuery(const int tableref, const QHash<int,QString
 void Database::warn() const
 {
     QSqlDatabase DB = QSqlDatabase::database(d->m_ConnectionName);
-    Log::addMessage("Database", QString("Connection name : %1, Database Name : %2, Driver : %3, Opened : %4, Can open : %5 ")
+    if (WarnLogMessages)
+        Log::addMessage("Database", QString("Connection name : %1, Database Name : %2, Driver : %3, Opened : %4, Can open : %5 ")
                        .arg(d->m_ConnectionName, DB.databaseName(), DB.driverName())
                        .arg(DB.isOpen())
                        .arg(DB.open()));
 
     foreach(int i, d->m_Tables.keys())
     {
-        Log::addMessage("Database", QString("Tables = %1 : %2").arg(i).arg(d->m_Tables[i]));
+        if (WarnLogMessages)
+            Log::addMessage("Database", QString("Tables = %1 : %2").arg(i).arg(d->m_Tables[i]));
         QList<int> list = d->m_Tables_Fields.values(i);
         qSort(list);
         foreach(int f, list)
-            Log::addMessage("Database", QString("    Fields = %1 : %2 %3 %4")
+            if (WarnLogMessages)
+                Log::addMessage("Database", QString("    Fields = %1 : %2 %3 %4")
                                .arg(f)
                                .arg(d->m_Fields[f], d->getTypeOfField(f), d->m_DefaultFieldValue[i]));
 
