@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -61,11 +47,13 @@
 #include <coreplugin/isettings.h>
 #include <coreplugin/constants_icons.h>
 #include <coreplugin/constants_menus.h>
+#include <coreplugin/constants_tokensandsettings.h>
 #include <coreplugin/translators.h>
 #include <coreplugin/dialogs/debugdialog.h>
 #include <coreplugin/dialogs/aboutdialog.h>
 #include <coreplugin/dialogs/plugindialog.h>
 #include <coreplugin/dialogs/helpdialog.h>
+#include <coreplugin/dialogs/settingsdialog.h>
 
 #include <QAction>
 #include <QToolBar>
@@ -131,6 +119,8 @@ MainWindowActionHandler::MainWindowActionHandler(QWidget *parent) :
 
 MainWindowActionHandler::~MainWindowActionHandler()
 {
+    // Save last used language
+    settings()->setValue(Constants::S_PREFEREDLANGUAGE, QLocale().name().left(2));
 }
 
 void MainWindowActionHandler::createGeneralMenu()
@@ -509,17 +499,24 @@ void MainWindowActionHandler::connectGeneralActions()
         connect(aGeneralCheckUpdate, SIGNAL(triggered()), this, SLOT(checkUpdate()));
 }
 
-/** \brief Menu is created in the global context \sa Constants::C_GLOBAL_ID. Menu bar is automaticcaly created if necessary. */
-void MainWindowActionHandler::createFileMenu()
+Core::ActionContainer *MainWindowActionHandler::menubarContainer(bool createIfNotExist)
 {
     // creates menu bar
     ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
-    if (!menubar) {
+    if (createIfNotExist && !menubar) {
         menubar = actionManager()->createMenuBar(Constants::MENUBAR);
 #ifndef Q_WS_MAC
         setMenuBar(menubar->menuBar());
 #endif
     }
+    return menubar;
+}
+
+/** \brief Menu is created in the global context \sa Constants::C_GLOBAL_ID. Menu bar is automaticcaly created if necessary. */
+void MainWindowActionHandler::createFileMenu()
+{
+    // creates menu bar
+    ActionContainer *menubar = menubarContainer(true);
     menubar->appendGroup(Constants::G_FILE);
 
     // Create menu
@@ -542,7 +539,7 @@ void MainWindowActionHandler::createFileMenu()
 
 void MainWindowActionHandler::createTemplatesMenu()
 {
-    ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
+    ActionContainer *menubar = menubarContainer();
     Q_ASSERT(menubar);
     menubar->appendGroup(Constants::G_TEMPLATES);
 
@@ -560,7 +557,7 @@ void MainWindowActionHandler::createTemplatesMenu()
 /** \brief Menu is created in the global context \sa Constants::C_GLOBAL_ID.*/
 void MainWindowActionHandler::createEditMenu()
 {
-    ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
+    ActionContainer *menubar = menubarContainer();
     Q_ASSERT(menubar);
     menubar->appendGroup(Constants::G_EDIT);
 
@@ -582,7 +579,7 @@ void MainWindowActionHandler::createEditMenu()
 /** \brief Menu is created in the global context \sa Constants::C_GLOBAL_ID.*/
 void MainWindowActionHandler::createPatientMenu()
 {
-    ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
+    ActionContainer *menubar = menubarContainer();
     Q_ASSERT(menubar);
     menubar->appendGroup(Constants::G_PATIENTS);
 
@@ -602,7 +599,7 @@ void MainWindowActionHandler::createPatientMenu()
 /** \brief Menu is created in the global context \sa Constants::C_GLOBAL_ID.*/
 void MainWindowActionHandler::createFormatMenu()
 {
-    ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
+    ActionContainer *menubar = menubarContainer();
     Q_ASSERT(menubar);
     menubar->appendGroup(Constants::G_FORMAT);
     ActionContainer *formatmenu = actionManager()->createMenu(Constants::M_FORMAT);
@@ -617,7 +614,7 @@ void MainWindowActionHandler::createFormatMenu()
 
 void MainWindowActionHandler::createPluginsMenu()
 {
-    ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
+    ActionContainer *menubar = menubarContainer(true);
     Q_ASSERT(menubar);
     menubar->appendGroup(Constants::G_PLUGINS);
 
@@ -634,7 +631,7 @@ void MainWindowActionHandler::createPluginsMenu()
 /** \brief Menu is created in the global context \sa Constants::C_GLOBAL_ID.*/
 void MainWindowActionHandler::createConfigurationMenu()
 {
-    ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
+    ActionContainer *menubar = menubarContainer(true);
     Q_ASSERT(menubar);
     menubar->appendGroup(Constants::G_CONFIGURATION);
 
@@ -651,7 +648,7 @@ void MainWindowActionHandler::createConfigurationMenu()
 /** \brief Menu is created in the global context \sa Constants::C_GLOBAL_ID.*/
 void MainWindowActionHandler::createHelpMenu()
 {
-    ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
+    ActionContainer *menubar = menubarContainer(true);
     Q_ASSERT(menubar);
     menubar->appendGroup(Constants::G_HELP);
 
@@ -674,7 +671,7 @@ void MainWindowActionHandler::createHelpMenu()
 /** \brief Menu is created in the global context \sa Constants::C_GLOBAL_ID.*/
 void MainWindowActionHandler::createUpdateMenu()
 {
-    ActionContainer *menubar = actionManager()->actionContainer(Constants::MENUBAR);
+    ActionContainer *menubar = menubarContainer(true);
     Q_ASSERT(menubar);
     menubar->appendGroup(Constants::G_UPDATE);
 
@@ -1014,6 +1011,8 @@ void MainWindowActionHandler::createConfigurationActions(int actions)
         // populate with actions
         QMap<QString, QString> loc_lang = Core::ICore::instance()->translators()->availableLocalesAndLanguages();
         int i = 0;
+
+        QString lang = settings()->value(Constants::S_PREFEREDLANGUAGE, QLocale().name().left(2)).toString();
         foreach( const QString &loc, loc_lang.keys() ) {
             i++;
             QAction *action = new QAction(this);  // QString("&%1 %2").arg(QString::number(i), loc_lang.value(loc)), this);
@@ -1024,8 +1023,10 @@ void MainWindowActionHandler::createConfigurationActions(int actions)
             cmd = actionManager()->registerAction(action, loc, ctx);
             lmenu->addAction(cmd, Constants::G_LANGUAGES);
             aLanguageGroup->addAction(action);
-            if (loc == QLocale().name().left(2))
+            if (loc == lang) {
                 action->setChecked(true);
+                switchLanguage(action);
+            }
         }
         connect(aLanguageGroup, SIGNAL(triggered(QAction*)), this, SLOT(switchLanguage(QAction*)));
     }
@@ -1192,6 +1193,15 @@ bool MainWindowActionHandler::debugDialog()
     dlg.showDialog();
     return true;
 }
+
+/** \brief Shows the standard Preferences dialog. \sa Core::SettingsDialog */
+bool MainWindowActionHandler::applicationPreferences()
+{
+    Core::SettingsDialog dlg(this);
+    dlg.exec();
+    return true;
+}
+
 /** \brief Shows the standard About dialog. \sa Core::AboutDialog */
 bool MainWindowActionHandler::aboutApplication()
 {
