@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                      *
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -87,8 +73,21 @@ namespace Constants {
 
     const char * const S_PRESCRIPTIONFORMATTING_HTML      = "DrugsWidget/print/prescription/HtmlFormatting";      /*!< \brief Key for settings. */
     const char * const S_PRESCRIPTIONFORMATTING_PLAIN     = "DrugsWidget/print/prescription/PlainFormatting";      /*!< \brief Key for settings. */
-    const char * const S_DEF_PRESCRIPTIONFORMATTING       = QT_TRANSLATE_NOOP("mfDrugsConstants", "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">[[DRUG]]</span><span style=\"font-style:italic;\">[<br />[Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][<br />Daily Distribution: [DISTRIBUTED_DAILY_SCHEME]][<br />[NOTE]]</span></p>");
-    const char * const S_DEF_PRESCRIPTIONFORMATTING_PLAIN = QT_TRANSLATE_NOOP("mfDrugsConstants", "[[DRUG]][\n[Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][\nDaily Distribution: [DISTRIBUTED_DAILY_SCHEME]][\n[NOTE] ]");
+    const char * const S_DEF_PRESCRIPTIONFORMATTING       = QT_TRANSLATE_NOOP("mfDrugsConstants",
+                                                                              "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">"
+                                                                              "[[DRUG]]</span><span style=\"font-style:italic;\">[<br />"
+                                                                              "Take [Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][<br />"
+                                                                              "Route: [ROUTE]][<br />"
+                                                                              "Daily Distribution: [DISTRIBUTED_DAILY_SCHEME]][<br />"
+                                                                              "Minimum interval between intakes: [MIN_INTERVAL]][<br />"
+                                                                              "[NOTE] ]</span></p>");
+    const char * const S_DEF_PRESCRIPTIONFORMATTING_PLAIN = QT_TRANSLATE_NOOP("mfDrugsConstants",
+                                                                              "[[DRUG]][\n"
+                                                                              "Take [Q_FROM]][ to [Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ each [[PERIOD] ][PERIOD_SCHEME]][ for [D_FROM]][ to [D_TO]][ [D_SCHEME]][\n"
+                                                                              "Route: [ROUTE]][\n"
+                                                                              "Daily Distribution: [DISTRIBUTED_DAILY_SCHEME]][\n"
+                                                                              "Minimum interval between intakes: [MIN_INTERVAL]][\n"
+                                                                              "[NOTE] ]");
 
     const char * const S_ALD_PRE_HTML               = "DrugsWidget/print/ALDPreHtml";             /*!< \brief Key for settings. */
     const char * const S_ALD_POST_HTML              = "DrugsWidget/print/ALDPostHtml";            /*!< \brief Key for settings. */
@@ -102,6 +101,7 @@ namespace Constants {
     const char * const S_SELECTOR_SHOWSTRENGTH    = "DrugsWidget/Selector/ShowStrength";
     const char * const S_SELECTOR_SHOWMOLECULES   = "DrugsWidget/Selector/ToolTipShowMolecules";
     const char * const S_ALLERGYBACKGROUNDCOLOR   = "DrugsWidget/Selector/AllergiesBackground";
+    const char * const S_INTOLERANCEBACKGROUNDCOLOR = "DrugsWidget/Selector/IntolerancesBackground";
     const char * const S_MARKDRUGSWITHAVAILABLEDOSAGES = "DrugsWidget/MarkDrugsWithAvailableDosages";      /*!< \brief Key for settings. */
     const char * const S_AVAILABLEDOSAGESBACKGROUNGCOLOR = "DrugsWidget/AvailableDosagesColorBackGround";      /*!< \brief Key for settings. */
     const char * const S_DEF_AVAILABLEDOSAGESBACKGROUNGCOLOR = "#ffdddd";
@@ -115,16 +115,29 @@ namespace Constants {
     const char * const  I_SEARCHCOMMERCIAL =  "pill.png";              /*!< \brief Themed icon name for Commercial search. */
     const char * const  I_SEARCHMOLS =        "molecule.png";          /*!< \brief Themed icon name for Molecules search. */
     const char * const  I_SEARCHINN =         "black_dci.png";         /*!< \brief Themed icon name for INN search. */
+
+    const char * const  I_DRUGSINFOS =        "drug_infos.png";
+    const char * const  I_PROTOCOL_PRESCRIBEANDSAVE =  "protocol_saveandprescribe.png";
+    const char * const  I_PROTOCOL_PRESCRIBE =         "protocol_prescribe.png";
+    const char * const  I_PROTOCOL_SAVE =              "protocol_save.png";
+    const char * const  I_PROTOCOL_TESTONLY =          "protocol_testonly.png";
+
     // INTERACTIONS ICONS
     const char * const  INTERACTION_ICONCRITICAL =         "critical.png";      /*!< \brief Themed icon name for Interactions logo. */
     const char * const  INTERACTION_ICONDECONSEILLEE =     "deconseille.png";   /*!< \brief Themed icon name for Interactions logo. */
     const char * const  INTERACTION_ICONTAKEINTOACCOUNT =  "warning.png";       /*!< \brief Themed icon name for Interactions logo. */
     const char * const  INTERACTION_ICONPRECAUTION =       "info.png";          /*!< \brief Themed icon name for Interactions logo. */
-    const char * const  INTERACTION_ICONINFORMATION =      "info.png";          /*!< \brief Themed icon name for Interactions logo. */
+    const char * const  INTERACTION_ICONINFORMATION =      "information.png";          /*!< \brief Themed icon name for Interactions logo. */
     const char * const  INTERACTION_ICONUNKONW =           "help.png";          /*!< \brief Themed icon name for Interactions logo. */
     const char * const  INTERACTION_ICONOK =               "ok.png";            /*!< \brief Themed icon name for Interactions logo. */
+    const char * const  INTERACTION_ICONP450 =             "p450iam.png";            /*!< \brief Themed icon name for Interactions logo. */
+    const char * const  INTERACTION_ICONGPG =              "gpgiam.png";            /*!< \brief Themed icon name for Interactions logo. */
 
-    // HTML MASKS
+    // HELP PAGES
+    const char * const  H_INTERACTION_SYNTHETISOR = "interactions.html";
+
+    // MASKS
+    const char * const  PROTOCOL_AUTOMATIC_LABEL_MASK =  "[[Q_FROM]][-[Q_TO]] [[Q_SCHEME]][ [REPEATED_DAILY_SCHEME]][ [MEAL]][ [[PERIOD] / ][PERIOD_SCHEME]][; [D_FROM]][-[D_TO]][ [D_SCHEME]][; [DISTRIBUTED_DAILY_SCHEME]]";
     const char * const  ENCODEDHTML_FULLDOC_MEDINTUX =
             "<html>\n"
             "<head>\n"
@@ -234,8 +247,9 @@ namespace Constants {
     /** \brief Represents the tables index of drugs database */
     enum Tables
     {
-        Table_DRUGS=0, Table_COMPO, Table_PACKAGING, Table_INFORMATION,
-        Table_IAM, Table_IAM_DENOMINATION, Table_DOSAGE,
+        Table_DRUGS=0, Table_COMPO, Table_PACKAGING, Table_LK_MOL_ATC, Table_INFORMATION,
+        Table_INTERACTIONS, Table_INTERACTION_KNOWLEDGE, Table_ATC, Table_IAM_TREE, Table_SOURCES, Table_DOSAGE,
+        Table_SEARCHENGINES, Table_DRUG_ROUTES, Table_ROUTES,
         Table_MaxParam
     };
 
@@ -255,28 +269,68 @@ namespace Constants {
 
     /** \brief Represents the fields index of drugs database table COMPO */
     enum COMPOSITIONfields
-    { COMPO_UID = 0, COMPO_MOL_FORM, COMPO_MOL_CODE, COMPO_MOL_NAME, COMPO_DOSAGE, COMPO_REF_DOSAGE,
+    { COMPO_UID = 0,
+      COMPO_MOL_FORM,
+      COMPO_MOL_CODE, COMPO_MOL_NAME,
+      COMPO_MOL_ATC,
+      COMPO_DOSAGE, COMPO_REF_DOSAGE,
       COMPO_NATURE, COMPO_LK_NATURE,
       COMPO_MaxParam, COMPO_IAM_DENOMINATION, COMPO_IAM_CLASS_DENOMINATION, COMPO_VeryMaxParam
     };
 
+    enum LINKfields {
+        LK_MOLECULECODE = 0, LK_ATC_ID, LK_MaxParam
+    };
+
     enum INFOfields
     { INFO_VERSION = 0, INFO_NAME, INFO_IDENTIFIANT, INFO_COMPAT_VERSION, INFO_PROVIDER, INFO_WEBLINK,
+      INFO_COMPLEMENTARY_WWW,
       INFO_AUTHOR, INFO_LICENSE, INFO_LICENSE_TERMS, INFO_DATE, INFO_DRUG_UID_NAME, INFO_PACK_MAIN_CODE_NAME,
-      INFO_ATC, INFO_INTERACTIONS, INFO_AUTHOR_COMMENTS, INFO_LANGUAGE_COUNTRY, INFO_DRUGS_NAME_CONSTRUCTOR,
+      INFO_ATC, INFO_INTERACTIONS, INFO_MOLLINKCOMPLETION, INFO_AUTHOR_COMMENTS, INFO_LANGUAGE_COUNTRY, INFO_DRUGS_NAME_CONSTRUCTOR,
       INFO_MaxParam
     };
 
     /** \brief Represents the fields index of drugs database table IAM_DENOMINATION */
-    enum IAM_DENOMINATIONfields
-    { IAM_DENOMINATION_ID = 0, IAM_DENOMINATION,
-      IAM_DENOMINATION_MaxParam
+    enum INTERACTIONSfields
+    { IA_ID = 0, IA_ATC1, IA_ATC2, IA_IAK_ID,
+      IA_MaxParam
     };
 
     /** \brief Represents the fields index of drugs database table IAM_IMPORT */
-    enum IAMfields
-    { IAM_ID = 0, IAM_ID1, IAM_ID2, IAM_TYPE, IAM_TEXT_IAM, IAM_TEXT_CAT,
-      IAM_MaxParam, IAM_MAIN, IAM_INTERACTOR
+    enum INTERACTION_KNOWLEDGEfields
+    { IAK_ID = 0, IAK_TYPE, IAK_RISK_FR, IAK_MANAGEMENT_FR, IAK_RISK_EN, IAK_MANAGEMENT_EN,
+      IAK_REFERENCES_LINK,
+      IAK_MaxParam
+    };
+
+    /** \brief Represents the fields index of drugs database table ATC */
+    enum ATCfields
+    { ATC_ID = 0, ATC_CODE, ATC_EN, ATC_FR, ATC_DE,
+      ATC_MaxParam
+    };
+
+    /** \brief Represents the fields index of drugs database table ATC */
+    enum IAM_TREEfields
+    { TREE_ID_CLASS = 0, TREE_ID_ATC, TREE_SOURCE_LINK,
+      TREE_MaxParam
+    };
+
+    enum SOURCESfields {
+        SOURCES_ID = 0, SOURCES_SOURCE_LINK, SOURCES_TYPE, SOURCES_LINK,
+        SOURCES_TEXTUAL_REFERENCE, SOURCES_ABSTRACT, SOURCES_EXPLANATION,
+        SOURCES_MaxParam
+    };
+
+    enum SEARCHENGINESfields {
+        SEARCHENGINE_ID, SEARCHENGINE_LABEL, SEARCHENGINE_URL
+    };
+
+    enum ROUTESFields {
+        ROUTES_ID = 0, ROUTES_FR, ROUTES_EN, ROUTES_DE
+    };
+
+    enum DRUGSROUTESFields {
+        DRUG_ROUTES_UID, DRUG_ROUTES_ROUTE_ID
     };
 
     //--------------------------------------------------------------------------------------------------------
@@ -311,10 +365,12 @@ namespace Drug
         MainInnDosage,
         Administration,
         Interacts,
+        OwnInteractionsSynthesis,
         MaximumLevelOfInteraction,
         CompositionString,
         InnCompositionString,    // inn dose form ; inn dose form...
         AvailableForms,
+        AvailableRoutes,
         AvailableDosages,
         HasPrescription,
         FullPrescription,
@@ -343,6 +399,7 @@ namespace Prescription
         IntakesScheme,
         IntakesUsesFromTo,
         IntakesFullString,
+        Route,
         DurationFrom,
         DurationTo,
         DurationScheme,
@@ -377,6 +434,7 @@ namespace Interaction
         Id = 2000,
         Icon,
         Pixmap,
+        MediumPixmap,
         ToolTip,
         FullSynthesis,
         MaxParam
@@ -384,13 +442,16 @@ namespace Interaction
 
     enum TypeOfIAM
     {
-        noIAM            = 0x00000000,
-        Precaution       = 0x00000001,
-        APrendreEnCompte = 0x00000010,
-        Deconseille      = 0x00000100,
-        ContreIndication = 0x00001000,
-        Information      = 0x00010000,
-        Unknown          = 0x00100000
+        noIAM            = 0x0000,
+        Unknown          = 0x0001,
+        Information      = 0x0002,
+        InnDuplication   = 0x0004,
+        Precaution       = 0x0010,
+        APrendreEnCompte = 0x0020,
+        P450             = 0x0100,
+        GPG              = 0x0200,
+        Deconseille      = 0x1000,
+        ContreIndication = 0x8000
     };
     Q_DECLARE_FLAGS( TypesOfIAM, TypeOfIAM );
 
@@ -425,7 +486,7 @@ namespace Constants {
         DrugsDatabaseIdentifiant,    /*!< \brief Unique FreeDiams identifiant */
         INN_LK,                 /*!< \brief Si la prescription est la même pour toutes les DCI alors le champs est renseigné, sinon laissé à -1. integer */
         InnLinkedDosage,        /*!< \brief Linked dosage of the Inn. */
-        CIS_LK,                 /*!< \brief Si la prescription est unique valable pour ce médicament le code CIS et renseigné, sinon laissé à -1. integer */
+        DrugUid_LK,                 /*!< \brief Si la prescription est unique valable pour ce médicament le code CIS et renseigné, sinon laissé à -1. integer */
         CIP_LK,                 /*!< \brief Code CIP           --> int */
         Label,                  /*!< \brief Libellé            --> varchar( 300 ) */
 
@@ -435,6 +496,7 @@ namespace Constants {
         IntakesScheme,           /*!< \brief Forme sélectionnée */
         IntakesIntervalOfTime,  /*!< \brief temps entre chaque prise --> int */
         IntakesIntervalScheme,  /*!< \brief schéma de temps --> int cf enum */
+        Route,
 
         DurationFrom,           /*!< \brief espacement prises  --> double */
         DurationTo,             /*!< \brief espacement prises  --> double */
