@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -54,6 +40,7 @@
   database(DB_DOSAGES_NAME) should be defined BEFORE instance()
 
   \todo Create a specific user's right for dosage creation/edition/modification/deletion +++.
+  \todo Get user's right throught Core::IUser
 
   \ingroup freediams drugswidget
 */
@@ -87,8 +74,10 @@
 #include <QColor>
 #include <QLocale>
 
+enum Warn { WarnDebuggingDatas = false };
+
 /**
-  \todo remove QCache of DasogeModels
+  \todo remove QCache of DosageModels
 */
 
 static inline Core::IUser *user() {return Core::ICore::instance()->user();}
@@ -106,6 +95,7 @@ using namespace mfDosageModelConstants;
 
 static inline DrugsDB::Internal::DrugsBase *drugsBase() {return DrugsDB::Internal::DrugsBase::instance();}
 static inline Core::ISettings *settings()  { return Core::ICore::instance()->settings(); }
+static inline Core::ITheme *theme() {return Core::ICore::instance()->theme();}
 
 //--------------------------------------------------------------------------------------------------------
 //---------------------------------------------- Static Datas --------------------------------------------
@@ -115,7 +105,6 @@ QStringList DosageModel::m_ScoredTabletScheme = QStringList();
 QStringList DosageModel::m_PreDeterminedForms = QStringList();
 QString     DosageModel::m_ActualLangage = "";
 
-static inline Core::ITheme *theme() {return Core::ICore::instance()->theme();}
 
 //--------------------------------------------------------------------------------------------------------
 //----------------------------------------- Managing Translations ----------------------------------------
@@ -138,6 +127,8 @@ void DosageModel::retranslate()
 
     // store the langage and retranslate
     m_ActualLangage = QLocale().name().left(2);
+    m_ScoredTabletScheme.clear();
+    m_PreDeterminedForms.clear();
 
     m_ScoredTabletScheme =
             QStringList()
@@ -161,8 +152,6 @@ void DosageModel::retranslate()
             << tr("eyewash")
             << tr("instillation")
             << tr("pulverization");
-
-
 }
 
 
@@ -211,22 +200,24 @@ DosageModel::DosageModel(DrugsDB::DrugsModel *parent)
 }
 
 /** \brief Defines datas for the dosage. Database is only updated when calling submitAll(). */
-bool DosageModel::setData(const QModelIndex & index, const QVariant & value, int role)
+bool DosageModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
-    Q_ASSERT_X(m_UID != -1, "DosageModel::setData", "before using the dosagemodel, you must specify the CIS of the related drug");
+    Q_ASSERT_X(!m_UID.isNull(), "DosageModel::setData", "before using the dosagemodel, you must specify the UID of the related drug");
     if (! index.isValid())
         return false;
-    if (role == Qt::EditRole) {        
+    if (role == Qt::EditRole || role == Qt::DisplayRole) {
 
         QVariant q = data(index);
-
         // verify the value is different as model
         if (q==value) {
             return true;
+        } else if (q.isNull()) {
+            if (value.toString().isEmpty())
+                return true;
         }
 
         // set only once modification date (infinite loop prevention)
-        if (index.column()!=Dosages::Constants::ModificationDate)
+        if (index.column() != Dosages::Constants::ModificationDate)
             setData(this->index(index.row(), Dosages::Constants::ModificationDate), QDateTime::currentDateTime());
 
         // mark row as dirty
@@ -239,10 +230,22 @@ bool DosageModel::setData(const QModelIndex & index, const QVariant & value, int
 //            warn();
 //        }
 
-        if (!QSqlTableModel::setData(index, value, role)) {
-            Utils::Log::addError(this, "Can not set data to QSqlTableModel");
-            Utils::Log::addQueryError(this, query());
-            return false;
+        if (index.column()==Dosages::Constants::Route) {
+            if (value.toString().contains(QRegExp("\\D"))) {
+                // Fing the routeId
+                int routeId = drugsBase()->getRouteId(value.toString());
+                if (!QSqlTableModel::setData(index, routeId, role)) {
+                    Utils::Log::addError(this, "Can not set data to QSqlTableModel", __FILE__, __LINE__);
+                    Utils::Log::addQueryError(this, query(), __FILE__, __LINE__);
+                    return false;
+                }
+            }
+        } else {
+            if (!QSqlTableModel::setData(index, value, role)) {
+                Utils::Log::addError(this, "Can not set data to QSqlTableModel", __FILE__, __LINE__);
+                Utils::Log::addQueryError(this, query(), __FILE__, __LINE__);
+                return false;
+            }
         }
 
         QModelIndex label = this->index(index.row(), Dosages::Constants::Label);
@@ -254,7 +257,7 @@ bool DosageModel::setData(const QModelIndex & index, const QVariant & value, int
 /** \brief Retreive dosage's datas. */
 QVariant DosageModel::data(const QModelIndex & item, int role) const
 {
-    Q_ASSERT_X(m_UID != -1, "DosageModel::data", "before using the dosagemodel, you must specify the CIS of the related drug");
+    Q_ASSERT_X(!m_UID.isNull(), "DosageModel::data", "before using the dosagemodel, you must specify the UID of the related drug");
     if (!item.isValid())
         return QVariant();
 
@@ -298,7 +301,9 @@ QVariant DosageModel::data(const QModelIndex & item, int role) const
 /** \brief Create new dosages. Defaults values of the dosages are stted here. */
 bool DosageModel::insertRows(int row, int count, const QModelIndex & parent)
 {
-    Q_ASSERT_X(m_UID != -1, "DosageModel::insertRows", "before inserting row, you must specify the UID of the related drug");
+    Q_ASSERT_X(!m_UID.isNull(), "DosageModel::insertRows", "before inserting row, you must specify the UID of the related drug");
+    if (WarnDebuggingDatas)
+        qWarning() << "DosageModel::insertRows (row:" << row << ";count" << count << ")" << parent;
     QString userUuid = user()->value(Core::IUser::Uuid).toString();
     int i;
     int createdRow;
@@ -306,13 +311,13 @@ bool DosageModel::insertRows(int row, int count, const QModelIndex & parent)
     for (i=0; i < count; ++i) {
         createdRow = row+i;
         if (!QSqlTableModel::insertRows(createdRow, 1, parent)) {
-            Utils::Log::addError(this, tr("Model Error : unable to insert a row"));
+            Utils::Log::addError(this, tr("Model Error : unable to insert a row"),__FILE__, __LINE__);
             toReturn = false;
         } else {
             setData(index(createdRow, Dosages::Constants::Uuid) , QUuid::createUuid().toString());
             if (drugsBase()->actualDatabaseInformations())
                 setData(index(createdRow, Dosages::Constants::DrugsDatabaseIdentifiant) , drugsBase()->actualDatabaseInformations()->identifiant);
-            setData(index(createdRow, Dosages::Constants::CIS_LK) , m_UID);
+            setData(index(createdRow, Dosages::Constants::DrugUid_LK) , m_UID);
             setData(index(createdRow, Dosages::Constants::INN_LK) , -1);
             setData(index(createdRow, Dosages::Constants::InnLinkedDosage) , "");
             setData(index(createdRow, Dosages::Constants::IntakesTo) , 1);
@@ -327,11 +332,11 @@ bool DosageModel::insertRows(int row, int count, const QModelIndex & parent)
                 setData(index(createdRow, Dosages::Constants::IntakesScheme) , s);
             }
             setData(index(createdRow, Dosages::Constants::Period), 1);
-            setData(index(createdRow, Dosages::Constants::PeriodScheme) , tkTr(Trans::Constants::DAYS));
+            setData(index(createdRow, Dosages::Constants::PeriodScheme) , tkTr(Trans::Constants::DAY_S));
             setData(index(createdRow, Dosages::Constants::DurationTo) , 1);
             setData(index(createdRow, Dosages::Constants::DurationFrom) , 1);
             setData(index(createdRow, Dosages::Constants::DurationUsesFromTo) , false);
-            setData(index(createdRow, Dosages::Constants::DurationScheme) , tkTr(Trans::Constants::MONTHS));
+            setData(index(createdRow, Dosages::Constants::DurationScheme) , tkTr(Trans::Constants::MONTH_S));
             setData(index(createdRow, Dosages::Constants::IntakesIntervalOfTime) , 0);
             setData(index(createdRow, Dosages::Constants::MinAge) , 0);
             setData(index(createdRow, Dosages::Constants::MaxAge) , 0);
@@ -353,7 +358,9 @@ bool DosageModel::insertRows(int row, int count, const QModelIndex & parent)
 */
 bool DosageModel::removeRows(int row, int count, const QModelIndex & parent)
 {
-    Q_ASSERT_X(m_UID != -1, "DosageModel::removeRows", "before using the dosagemodel, you must specify the CIS of the related drug");
+    Q_ASSERT_X(!m_UID.isNull(), "DosageModel::removeRows", "before using the dosagemodel, you must specify the UID of the related drug");
+    if (WarnDebuggingDatas)
+        qWarning() << "DosageModel::removeRows (row:" << row << ";count" << count << ")" << parent;
 
     if (row < 0)
         return false;
@@ -375,7 +382,7 @@ bool DosageModel::removeRows(int row, int count, const QModelIndex & parent)
 /** \brief Revert a row */
 void DosageModel::revertRow(int row)
 {
-    Q_ASSERT_X(m_UID != -1, "DosageModel::revertRow", "before using the dosagemodel, you must specify the CIS of the related drug");
+    Q_ASSERT_X(!m_UID.isNull(), "DosageModel::revertRow", "before using the dosagemodel, you must specify the UID of the related drug");
     QSqlTableModel::revertRow(row);
     if (m_DirtyRows.contains(row))
         m_DirtyRows.remove(row);
@@ -384,7 +391,7 @@ void DosageModel::revertRow(int row)
 /** \brief Submit model changes to database */
 bool DosageModel::submitAll()
 {
-    Q_ASSERT_X(m_UID != -1, "DosageModel::submitAll", "before using the dosagemodel, you must specify the CIS of the related drug");
+    Q_ASSERT_X(!m_UID.isNull(), "DosageModel::submitAll", "before using the dosagemodel, you must specify the UID of the related drug");
 //    warn();
 //    qWarning() << m_DirtyInnLkRows << m_DirtyRows;
 //    foreach(const int i, m_DirtyInnLkRows) {
@@ -397,7 +404,7 @@ bool DosageModel::submitAll()
         return true;
     } else {
         m_DirtyRows = safe;
-        Utils::Log::addQueryError(this, QSqlTableModel::query());
+        Utils::Log::addQueryError(this, QSqlTableModel::query(), __FILE__, __LINE__);
     }
     //    reset();
     return false;
@@ -406,16 +413,16 @@ bool DosageModel::submitAll()
 /**
   \brief Filter the model from the drug CIS and if possible for the inn prescriptions.
 */
-bool DosageModel::setDrugUID(const int uid)
+bool DosageModel::setDrugUID(const QVariant &drugUid)
 {
-    if (uid == m_UID)
+    if (drugUid == m_UID)
         return true;
-    m_UID = uid;
-    QString filter = QString("%1=%2").arg(record().fieldName(Dosages::Constants::CIS_LK)).arg(m_UID);
+    m_UID = drugUid;
+    QString filter = QString("%1='%2'").arg(record().fieldName(Dosages::Constants::DrugUid_LK)).arg(m_UID.toString());
 
     int inn = -1;
     if (m_DrugsModel)
-        inn = m_DrugsModel->drugData(uid, Constants::Drug::MainInnCode).toInt();
+        inn = m_DrugsModel->drugData(drugUid, Constants::Drug::MainInnCode).toInt();
 
     if (inn!=-1) {
         // add INN_LK
@@ -425,17 +432,20 @@ bool DosageModel::setDrugUID(const int uid)
         innFilter = QString("(%1) AND (%2='%3')")
                     .arg(innFilter)
                     .arg(record().fieldName(Dosages::Constants::InnLinkedDosage))
-                    .arg(m_DrugsModel->drugData(uid, Constants::Drug::MainInnDosage).toString());
+                    .arg(m_DrugsModel->drugData(drugUid, Constants::Drug::MainInnDosage).toString());
         filter = QString("((%1) OR (%2))").arg(filter).arg(innFilter);
     }        
-//    qWarning() << "filter" << filter;
+
+    if (WarnDebuggingDatas)
+        qWarning() << "DosageModel filter" << filter << __FILE__ << __LINE__;
+
     setFilter(filter);
     select();
     return true;
 }
 
 /** \brief Return the actual drug's CIS */
-int DosageModel::drugUID()
+QVariant DosageModel::drugUID()
 {
     return m_UID;
 }
@@ -454,11 +464,13 @@ bool DosageModel::isDirty(const int row) const
 /** \brief Check the validity of the dosage. */
 QStringList DosageModel::isDosageValid(const int row)
 {
-    Q_ASSERT_X(m_UID != -1, "DosageModel::isDosageValid", "before using the dosagemodel, you must specify the CIS of the related drug");
+    Q_ASSERT_X(!m_UID.isNull(), "DosageModel::isDosageValid", "before using the dosagemodel, you must specify the UID of the related drug");
     QStringList errors;
     // Label
-    if (index(row, Dosages::Constants::Label).data().toString().isEmpty())
-        errors << tr("The protocol must be labelled.");
+    if (index(row, Dosages::Constants::Label).data().toString().isEmpty()) {
+        QString label = m_DrugsModel->getFullPrescription(m_DrugsModel->getDrug(m_UID), false, Constants::PROTOCOL_AUTOMATIC_LABEL_MASK);
+        setData(index(row, Dosages::Constants::Label), label);
+    }
     // Intakes
     if (index(row, Dosages::Constants::IntakesScheme).data().toString().isEmpty())
         errors << tr("The intakes' scheme must be defined.");
@@ -472,25 +484,6 @@ QStringList DosageModel::isDosageValid(const int row)
     return errors;
 }
 
-#ifndef FREEDIAMS
-/** \todo here */
-///** \brief Test user's permissions for the drugs read access */
-//bool DosageModel::userCanRead()
-//{
-//    //TODO --> test
-//    Core::IUser::UserRights r = Core::IUser::UserRights(tkUserModel::instance()->currentUserData(Core::IUser::DrugsRights).toInt());
-//    return (r & Core::IUser::ReadOwn) || (r & Core::IUser::ReadAll);
-//}
-//
-///** \brief Test user's permissions for the drugs write access */
-//bool DosageModel::userCanWrite()
-//{
-//    //TODO  --> test
-//    Core::IUser::UserRights r = Core::IUser::UserRights(tkUserModel::instance()->currentUserData(Core::IUser::DrugsRights).toInt());
-//    return (r & Core::IUser::WriteOwn) || (r & Core::IUser::WriteAll);
-//}
-#endif
-
 /**
   \brief Transforms a dosage to a drug's prescription.
   \sa DrugsModel
@@ -506,6 +499,7 @@ void DosageModel::toPrescription(const int row)
     prescr_dosage.insert(Constants::Prescription::IntakesTo ,            Dosages::Constants::IntakesTo);
     prescr_dosage.insert(Constants::Prescription::IntakesUsesFromTo ,    Dosages::Constants::IntakesUsesFromTo);
     prescr_dosage.insert(Constants::Prescription::IntakesScheme ,        Dosages::Constants::IntakesScheme);
+    prescr_dosage.insert(Constants::Prescription::Route ,                Dosages::Constants::Route);
     prescr_dosage.insert(Constants::Prescription::Period ,               Dosages::Constants::Period);
     prescr_dosage.insert(Constants::Prescription::PeriodScheme ,         Dosages::Constants::PeriodScheme);
     prescr_dosage.insert(Constants::Prescription::DurationFrom ,         Dosages::Constants::DurationFrom);
@@ -521,10 +515,14 @@ void DosageModel::toPrescription(const int row)
     foreach(const int i, prescr_dosage.keys()) {
         m_DrugsModel->setDrugData(m_UID, i, data(index(row, prescr_dosage.value(i))));
     }
-    if (index(row,Dosages::Constants::INN_LK).data().toInt() > 999) // this is an INN prescription
+
+    // Manage INN Prescriptions
+    if (index(row,Dosages::Constants::INN_LK).data().toInt() != -1) // this is an INN prescription
         m_DrugsModel->setDrugData(m_UID, Constants::Prescription::IsINNPrescription, true);
     else
         m_DrugsModel->setDrugData(m_UID, Constants::Prescription::IsINNPrescription, false);
+
+    // Reset model
     m_DrugsModel->resetModel();
 }
 
