@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -75,6 +61,7 @@
 #include <drugsbaseplugin/constants.h>
 #include <drugsbaseplugin/versionupdater.h>
 #include <drugsbaseplugin/drugsdatabaseselector.h>
+#include <drugsbaseplugin/drugsearchengine.h>
 
 #include <utils/global.h>
 #include <utils/log.h>
@@ -84,7 +71,6 @@
 #include <coreplugin/constants_tokensandsettings.h>
 #include <coreplugin/dialogs/settingsdialog.h>
 
-// include Qt headers
 #include <QCoreApplication>
 #include <QSqlDatabase>
 #include <QSqlError>
@@ -99,14 +85,31 @@
 #include <QList>
 #include <QSet>
 
+
+enum { WarnExtractedDrugs=false };
+
 using namespace DrugsDB;
 using namespace DrugsDB::Internal;
 using namespace Trans::ConstantTranslations;
 
 
 static inline Core::ISettings *settings()  { return Core::ICore::instance()->settings(); }
+static inline DrugsDB::Internal::DrugSearchEngine *searchEngine()  { return DrugsDB::Internal::DrugSearchEngine::instance(); }
 static inline QString defaultDatabaseFileName() {return settings()->databasePath() + QDir::separator() + QString(DB_DRUGS_NAME) + QDir::separator() + QString(DB_DRUGS_NAME) + "-fr_FR.db";}
 
+static inline bool connectDatabase(QSqlDatabase &DB, const QString &file, const int line)
+{
+    if (!DB.isOpen()) {
+        if (!DB.open()) {
+            Utils::Log::addError("DrugsBase", tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
+                                 .arg(DB.connectionName()).arg(DB.lastError().text()),
+                                 file, line);
+            return false;
+        }
+    }
+    return true;
+}
+
 namespace DrugsDB {
 namespace Internal {
 /**
@@ -117,22 +120,22 @@ class DrugsBasePrivate
 {
 public:
     DrugsBasePrivate(DrugsBase * base) :
-            m_DrugsBase(base),
+            q(base),
             m_ActualDBInfos(0),
             m_LogChrono(false),
             m_RefreshDrugsBase(false),
-            m_RefreshDosageBase(false)
+            m_RefreshDosageBase(false),
+            m_UseRoutes(false)
     {}
 
     ~DrugsBasePrivate()
     {
     }
 
-
 public:
-    DrugsBase *m_DrugsBase;
+    DrugsBase *q;
     DatabaseInfos *m_ActualDBInfos;
-    bool m_LogChrono, m_RefreshDrugsBase, m_RefreshDosageBase;
+    bool m_LogChrono, m_RefreshDrugsBase, m_RefreshDosageBase, m_UseRoutes;
 };
 }  // End Internal
 }  // End DrugsDB
@@ -168,10 +171,14 @@ DrugsBase::DrugsBase(QObject *parent)
     setObjectName("DrugsBase");
 
     // DRUGS DATABASE
-    addTable(Table_DRUGS,       "DRUGS");
-    addTable(Table_COMPO,       "COMPOSITION");
-    addTable(Table_PACKAGING,   "PACKAGING");
-    addTable(Table_INFORMATION, "INFORMATIONS");
+    addTable(Table_DRUGS,         "DRUGS");
+    addTable(Table_COMPO,         "COMPOSITION");
+    addTable(Table_PACKAGING,     "PACKAGING");
+    addTable(Table_LK_MOL_ATC,    "LK_MOL_ATC");
+    addTable(Table_INFORMATION,   "INFORMATIONS");
+    addTable(Table_SEARCHENGINES, "SEARCH_ENGINES");
+    addTable(Table_DRUG_ROUTES,  "DRUG_ROUTES");
+    addTable(Table_ROUTES,        "ROUTES");
 
     addField(Table_DRUGS, DRUGS_UID ,           "UID");
     addField(Table_DRUGS, DRUGS_NAME ,          "NAME");
@@ -196,17 +203,22 @@ DrugsBase::DrugsBase(QObject *parent)
     addField(Table_COMPO, COMPO_MOL_FORM,     "MOLECULE_FORM");
     addField(Table_COMPO, COMPO_MOL_CODE,     "MOLECULE_CODE");
     addField(Table_COMPO, COMPO_MOL_NAME,     "MOLECULE_NAME");
+    addField(Table_COMPO, COMPO_MOL_ATC,      "MOLECULE_ATC");
     addField(Table_COMPO, COMPO_DOSAGE,       "DOSAGE");
     addField(Table_COMPO, COMPO_REF_DOSAGE,   "DOSAGE_REF");
     addField(Table_COMPO, COMPO_NATURE,       "NATURE");
     addField(Table_COMPO, COMPO_LK_NATURE,    "LK_NATURE");
 
+    addField(Table_LK_MOL_ATC, LK_MOLECULECODE,"MOLECULE_CODE");
+    addField(Table_LK_MOL_ATC, LK_ATC_ID,      "ATC_ID");
+
     addField(Table_INFORMATION, INFO_VERSION,           "VERSION");
     addField(Table_INFORMATION, INFO_NAME,              "NAME");
     addField(Table_INFORMATION, INFO_IDENTIFIANT,       "IDENTIFIANT");
     addField(Table_INFORMATION, INFO_COMPAT_VERSION,    "COMPAT_VERSION");
     addField(Table_INFORMATION, INFO_PROVIDER,          "PROVIDER");
     addField(Table_INFORMATION, INFO_WEBLINK,           "WEBLINK");
+    addField(Table_INFORMATION, INFO_COMPLEMENTARY_WWW, "COMPLEMENTARY_WEBSITE");
     addField(Table_INFORMATION, INFO_AUTHOR,            "AUTHOR");
     addField(Table_INFORMATION, INFO_LICENSE,           "LICENSE");
     addField(Table_INFORMATION, INFO_LICENSE_TERMS,     "LICENSE_TERMS");
@@ -215,10 +227,23 @@ DrugsBase::DrugsBase(QObject *parent)
     addField(Table_INFORMATION, INFO_PACK_MAIN_CODE_NAME, "PACK_MAIN_CODE_NAME");
     addField(Table_INFORMATION, INFO_ATC,               "ATC");
     addField(Table_INFORMATION, INFO_INTERACTIONS,      "INTERACTIONS");
+    addField(Table_INFORMATION, INFO_MOLLINKCOMPLETION,      "MOL_LINK_COMPLETION");
     addField(Table_INFORMATION, INFO_AUTHOR_COMMENTS,   "AUTHOR_COMMENTS");
     addField(Table_INFORMATION, INFO_LANGUAGE_COUNTRY,  "LANGUAGE_COUNTRY");
     addField(Table_INFORMATION, INFO_DRUGS_NAME_CONSTRUCTOR, "DRUGS_NAME_CONSTRUCTOR");
 
+    addField(Table_SEARCHENGINES, SEARCHENGINE_ID, "ID");
+    addField(Table_SEARCHENGINES, SEARCHENGINE_LABEL, "LABEL");
+    addField(Table_SEARCHENGINES, SEARCHENGINE_URL, "URL");
+
+    addField(Table_DRUG_ROUTES, DRUG_ROUTES_UID, "DRUG_UID");
+    addField(Table_DRUG_ROUTES, DRUG_ROUTES_ROUTE_ID, "ROUTE_ID");
+
+    addField(Table_ROUTES, ROUTES_ID, "ID");
+    addField(Table_ROUTES, ROUTES_FR, "FR");
+    addField(Table_ROUTES, ROUTES_EN, "EN");
+    addField(Table_ROUTES, ROUTES_DE, "DE");
+
     connect(Core::ICore::instance(), SIGNAL(databaseServerChanged()), this, SLOT(onCoreDatabaseServerChanged()));
 }
 
@@ -250,7 +275,8 @@ bool DrugsBase::init()
     if (!QSqlDatabase::connectionNames().contains(Constants::DB_DRUGS_NAME)) {
         // test driver
         if (!QSqlDatabase::isDriverAvailable("QSQLITE")) {
-            Utils::Log::addError(this, tkTr(Trans::Constants::SQLITE_DRIVER_NOT_AVAILABLE));
+            Utils::Log::addError(this, tkTr(Trans::Constants::SQLITE_DRIVER_NOT_AVAILABLE),
+                                 __FILE__, __LINE__);
             Utils::warningMessageBox(tkTr(Trans::Constants::APPLICATION_FAILURE),
                                      tkTr(Trans::Constants::SQLITE_DRIVER_NOT_AVAILABLE_DETAIL),
                                      "", qApp->applicationName());
@@ -285,15 +311,18 @@ bool DrugsBase::init()
                              Utils::Database::ReadOnly, Utils::Database::SQLite)) {
             d->m_ActualDBInfos = getDatabaseInformations(DB_DRUGS_NAME);
         } else {
-            Utils::Log::addError(this, "No drugs database found.");
+            Utils::Log::addError(this, "No drugs database found.",
+                                 __FILE__, __LINE__);
             return false;
         }
 
+        // Use routes ?
+        d->m_UseRoutes = (count(Table_DRUG_ROUTES, DRUG_ROUTES_UID) > 0);
+
         // refresh InteractionsBase cache
         InteractionsBase::init(true);
     }
 
-
     // Connect and check Dosage Database
     // Check settings --> SQLite or MySQL ?
     // remove drugs database connection if exists
@@ -324,9 +353,27 @@ bool DrugsBase::init()
                              "log", "pas", 0,
                              Utils::Database::CreateDatabase);
         }
+        if (!QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME).open())
+            Utils::Log::addError("DrugsBase", tr("WARNING : can not open database %1 : %2 \n %3 ")
+                                 .arg(Dosages::Constants::DB_DOSAGES_NAME, QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME).lastError().driverText(), QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME).lastError().databaseText()),
+                                 __FILE__, __LINE__);
         checkDosageDatabaseVersion();
     }
 
+    // get all Drugs search engines
+    searchEngine()->clear();
+    QSqlQuery search(QSqlDatabase::database(Constants::DB_DRUGS_NAME));
+    QString req = select(Constants::Table_SEARCHENGINES);
+    if (search.exec(req)) {
+        while (search.next()) {
+            searchEngine()->addNewEngine(search.value(Constants::SEARCHENGINE_LABEL).toString(),
+                                         search.value(Constants::SEARCHENGINE_URL).toString());
+        }
+    } else {
+        Utils::Log::addQueryError(this, search, __FILE__, __LINE__);
+    }
+    Utils::Log::addMessage(this, QString("Getting %1 Drugs Search Engines").arg(searchEngine()->numberOfEngines()));
+
     // Initialize
     InteractionsBase::init();
     m_initialized = true;
@@ -355,6 +402,11 @@ bool DrugsBase::isDatabaseTheDefaultOne() const
     return m_IsDefaultDB;
 }
 
+bool DrugsBase::isRoutesAvailable() const
+{
+    return d->m_UseRoutes;
+}
+
 bool DrugsBase::refreshAllDatabases()
 {
     m_initialized = false;
@@ -395,7 +447,7 @@ bool DrugsBase::refreshDosageBase()
 DatabaseInfos *DrugsBase::getDatabaseInformations(const QString &connectionName)
 {
     QSqlDatabase db = QSqlDatabase::database(connectionName);
-    if (!db.open())
+    if (!connectDatabase(db, __FILE__, __LINE__))
         return 0;
 
     // check table INFORMATIONS
@@ -430,13 +482,15 @@ DatabaseInfos *DrugsBase::getDatabaseInformations(const QString &connectionName)
             info->authorComments = q.value(Constants::INFO_AUTHOR_COMMENTS).toString();
             info->lang_country = q.value(Constants::INFO_LANGUAGE_COUNTRY).toString();
             info->setDrugsNameConstructor(q.value(Constants::INFO_DRUGS_NAME_CONSTRUCTOR).toString());
+            info->complementaryWebsite = q.value(Constants::INFO_COMPLEMENTARY_WWW).toString();
+            info->moleculeLinkCompletion = q.value(Constants::INFO_MOLLINKCOMPLETION).toInt();
             info->connectionName = db.connectionName();
             if (db.driverName() == "QSQLITE") {
                 info->fileName = db.databaseName();
             }
         }
     } else {
-        Utils::Log::addQueryError(this, q);
+        Utils::Log::addQueryError(this, q, __FILE__, __LINE__);
     }
     return info;
 }
@@ -451,7 +505,7 @@ QString DrugsBase::dosageCreateTableSqlQuery()
            "`DRUGS_DATABASE_IDENTIFIANT` varchar(200) NULL,   "
            "`INN_LK`                int(11)        DEFAULT -1,"
            "`INN_DOSAGE`            varchar(100)   NULL,"    // contains the dosage of the SA INN
-           "`CIS_LK`                int(11)        DEFAULT -1,"
+           "`DRUG_UID_LK`           varchar(20)    NULL,"
            "`CIP_LK`                int(11)        DEFAULT -1,"
            "`LABEL`                 varchar(300)   NULL,"    // put NOT NULL
 
@@ -461,6 +515,7 @@ QString DrugsBase::dosageCreateTableSqlQuery()
            "`INTAKESCHEME`          varchar(200)   NULL,"    // put NOT NULL
            "`INTAKESINTERVALOFTIME` int(10)        NULL,"
            "`INTAKESINTERVALSCHEME` varchar(200)   NULL,"
+           "`ROUTE_ID`              integer        NULL,"
 
            "`DURATIONFROM`          double         NULL,"    // put NOT NULL
            "`DURATIONTO`            double         NULL,"
@@ -546,7 +601,7 @@ bool DrugsBase::createDatabase(const QString &connectionName , const QString &db
             }
             QSqlQuery q(QString("CREATE DATABASE `%1`").arg(dbName), d);
             if (!q.isActive()) {
-                Utils::Log::addQueryError("Database", q);
+                Utils::Log::addQueryError("Database", q, __FILE__, __LINE__);
                 Utils::warningMessageBox(tr("Unable to create the Protocol database."),tr("Please contact dev team."));
                 return false;
             }
@@ -579,7 +634,8 @@ bool DrugsBase::createDatabase(const QString &connectionName , const QString &db
         return true;
     } else {
         Utils::Log::addError(this, tkTr(Trans::Constants::DATABASE_1_CANNOT_BE_CREATED_ERROR_2)
-                         .arg(dbName, DB.lastError().text()));
+                         .arg(dbName, DB.lastError().text()),
+                         __FILE__, __LINE__);
     }
     return false;
 }
@@ -597,7 +653,8 @@ void DrugsBase::checkDosageDatabaseVersion()
 {
     if (!DrugsDB::VersionUpdater::instance()->isDosageDatabaseUpToDate())
         if (!DrugsDB::VersionUpdater::instance()->updateDosageDatabase())
-            Utils::Log::addError(this, "Dosage database can not be correctly updated");
+            Utils::Log::addError(this, "Dosage database can not be correctly updated",
+                                 __FILE__, __LINE__);
 }
 
 /** \brief Returns hash that contains dosage uuid has key and the xml'd dosage to transmit as value */
@@ -605,11 +662,9 @@ QHash<QString, QString> DrugsBase::getDosageToTransmit()
 {
     QHash<QString, QString> toReturn;
     QSqlDatabase DB = QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME);
-    if (!DB.open()) {
-        Utils::Log::addError(this, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
-                             .arg(Dosages::Constants::DB_DOSAGES_NAME).arg(DB.lastError().text()));
+    if (!connectDatabase(DB, __FILE__, __LINE__))
         return toReturn;
-    }
+
     QString req = QString("SELECT * FROM `DOSAGE` WHERE (`TRANSMITTED` IS NULL);");
     {
         QSqlQuery query(req,DB);
@@ -624,7 +679,7 @@ QHash<QString, QString> DrugsBase::getDosageToTransmit()
                 toReturn.insert(toXml.value("POSO_UUID"), Utils::createXml(Dosages::Constants::DB_DOSAGES_TABLE_NAME,toXml,4,false));
             }
         } else
-            Utils::Log::addQueryError(this, query);
+            Utils::Log::addQueryError(this, query, __FILE__, __LINE__);
     }
 
     req = QString("SELECT * FROM `DOSAGE` WHERE (`TRANSMITTED`<`MODIFICATIONDATE`);");
@@ -641,7 +696,7 @@ QHash<QString, QString> DrugsBase::getDosageToTransmit()
                 toReturn.insert(toXml.value("POSO_UUID"), Utils::createXml(Dosages::Constants::DB_DOSAGES_TABLE_NAME,toXml,4,false));
             }
         } else {
-            Utils::Log::addQueryError(this, query);
+            Utils::Log::addQueryError(this, query, __FILE__, __LINE__);
         }
     }
     return toReturn;
@@ -653,11 +708,9 @@ bool DrugsBase::markAllDosageTransmitted(const QStringList &dosageUuids)
     if (dosageUuids.count()==0)
         return true;
     QSqlDatabase DB = QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME);
-    if (!DB.open()) {
-        Utils::Log::addError(this, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
-                             .arg(Dosages::Constants::DB_DOSAGES_NAME).arg(DB.lastError().text()));
+    if (!connectDatabase(DB, __FILE__, __LINE__))
         return false;
-    }
+
     QStringList reqs;
     foreach(const QString &s, dosageUuids) {
         QString req = QString("UPDATE `DOSAGE` SET `TRANSMITTED`='%1' WHERE %2")
@@ -666,7 +719,8 @@ bool DrugsBase::markAllDosageTransmitted(const QStringList &dosageUuids)
         reqs << req;
     }
     if (!executeSQL(reqs,DB)) {
-        Utils::Log::addError(this, tr("Unable to update the protocol's transmission date."));
+        Utils::Log::addError(this, tr("Unable to update the protocol's transmission date."),
+                             __FILE__, __LINE__);
         return false;
     }
     return true;
@@ -685,35 +739,33 @@ struct minimalCompo {
   \brief Returns all CIS that have a recorded dosage. Manages INN dosage type.
   \todo put this in a thread...
 */
-QList<int> DrugsBase::getAllUIDThatHaveRecordedDosages() const
+QList<QVariant> DrugsBase::getAllUIDThatHaveRecordedDosages() const
 {
-    QList<int> toReturn;
+    QList<QVariant> toReturn;
 
     if (!actualDatabaseInformations())
         return toReturn;
 
     QSqlDatabase DosageDB = QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME);
-    if ((DosageDB.isOpen()) && (!DosageDB.open())) {
-        Utils::Log::addError(this, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
-                             .arg(Dosages::Constants::DB_DOSAGES_NAME).arg(DosageDB.lastError().text()));
+    if (!connectDatabase(DosageDB, __FILE__, __LINE__))
         return toReturn;
-    }
+
     QString req;
     if (m_IsDefaultDB) {
-        req = QString("SELECT DISTINCT CIS_LK FROM `DOSAGE` WHERE `DRUGS_DATABASE_IDENTIFIANT` = \"%1\";")
+        req = QString("SELECT DISTINCT `DRUG_UID_LK` FROM `DOSAGE` WHERE `DRUGS_DATABASE_IDENTIFIANT` = \"%1\";")
               .arg(Constants::DB_DEFAULT_IDENTIFIANT);
     } else {
-        req = QString("SELECT DISTINCT CIS_LK FROM `DOSAGE` WHERE `DRUGS_DATABASE_IDENTIFIANT` = \"%1\";")
+        req = QString("SELECT DISTINCT `DRUG_UID_LK` FROM `DOSAGE` WHERE `DRUGS_DATABASE_IDENTIFIANT` = \"%1\";")
               .arg(actualDatabaseInformations()->identifiant);
     }
     {
         QSqlQuery query(req,DosageDB);
         if (query.isActive()) {
             while (query.next()) {
-                toReturn << query.value(0).toInt();
+                toReturn << query.value(0);
             }
         } else {
-            Utils::Log::addQueryError(this, query);
+            Utils::Log::addQueryError(this, query, __FILE__, __LINE__);
         }
     }
 
@@ -725,17 +777,14 @@ QList<int> DrugsBase::getAllUIDThatHaveRecordedDosages() const
     QString tmp;
     QList<int> code_subst;
     QSqlDatabase DrugsDB = QSqlDatabase::database(Constants::DB_DRUGS_NAME);
-    if ((DrugsDB.isOpen()) && (!DrugsDB.open())) {
-        Utils::Log::addError(this, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
-                             .arg(Constants::DB_DRUGS_NAME).arg(DrugsDB.lastError().text()));
+    if (!connectDatabase(DrugsDB, __FILE__, __LINE__))
         return toReturn;
-    }
 
     // get all needed datas from database
-    QMultiHash<int, minimalCompo> cis_compo;
+    QMultiHash<QString, minimalCompo> cis_compo;
     foreach(int inn, inn_dosageRef.keys()) {
 //            foreach(int code, d->m_Lk_iamCode_substCode.values(inn)) {
-            foreach(int code, getLinkedCodeSubst(inn)) {
+            foreach(int code, getLinkedMoleculeCodes(inn)) {
             if (!code_subst.contains(code))
                 code_subst << code;
         }
@@ -757,45 +806,44 @@ QList<int> DrugsBase::getAllUIDThatHaveRecordedDosages() const
     QSqlQuery query(req, DrugsDB);
     if (query.isActive()) {
         while (query.next()) {
-            int cis = query.value(0).toInt();
+            QString cis = query.value(0).toString();
             minimalCompo compo;
-//            compo.inn = d->m_Lk_iamCode_substCode.key(query.value(1).toInt());
-            compo.inn = getLinkedIamCode(query.value(1).toInt()).at(0);
+            compo.inn = getLinkedAtcIds(query.value(1).toInt()).at(0);
             compo.dosage = query.value(2).toString();
             cis_compo.insertMulti(cis, compo);
         }
     } else {
-        Utils::Log::addQueryError(this, query);
+        Utils::Log::addQueryError(this, query, __FILE__, __LINE__);
     }
 
     // now check every drugs
-    foreach(const int cis, cis_compo.uniqueKeys()) {
+    foreach(const QString &uid, cis_compo.uniqueKeys()) {
         QList<int> innsOfThisDrug;
-        foreach(const minimalCompo &compo, cis_compo.values(cis)) {
+        foreach(const minimalCompo &compo, cis_compo.values(uid)) {
             if (!innsOfThisDrug.contains(compo.inn))
                 innsOfThisDrug << compo.inn;
             QString d = compo.dosage;
             foreach(const QString &r, inn_dosageRef.values(compo.inn)) {
                 // remove unneeded strings
                 if (d == r)
-                    toReturn << cis;
+                    toReturn << uid;
                 else if (d.remove(",000") == r)
-                    toReturn << cis;
+                    toReturn << uid;
                 else if (d.remove(",00") == r)
-                    toReturn << cis;
+                    toReturn << uid;
 
                 // try unit conversion
                 if (d.replace("000 mg", " g") == r) {
-                    toReturn << cis;
+                    toReturn << uid;
                 }
                 QString t = r;
                 if (t.replace("000 mg", " g") == d) {
-                    toReturn << cis;
+                    toReturn << uid;
                 }
             }
         }
         if (innsOfThisDrug.count() > 1)
-            toReturn.removeAll(cis);
+            toReturn.removeAll(uid);
     }
     return toReturn;
 }
@@ -804,11 +852,9 @@ QMultiHash<int,QString> DrugsBase::getAllINNThatHaveRecordedDosages() const
 {
     QMultiHash<int,QString> toReturn;
     QSqlDatabase DB = QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME);
-    if (!DB.open()) {
-        Utils::Log::addError(this, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
-                             .arg(Dosages::Constants::DB_DOSAGES_NAME).arg(DB.lastError().text()));
+    if (!connectDatabase(DB, __FILE__, __LINE__))
         return toReturn;
-    }
+
     QString req;
     if (m_IsDefaultDB) {
         req = QString("SELECT DISTINCT `INN_LK`, `INN_DOSAGE` FROM `DOSAGE` WHERE `DRUGS_DATABASE_IDENTIFIANT` = \"%1\";")
@@ -824,7 +870,7 @@ QMultiHash<int,QString> DrugsBase::getAllINNThatHaveRecordedDosages() const
                 toReturn.insertMulti(query.value(0).toInt(), query.value(1).toString());
             }
         } else {
-            Utils::Log::addQueryError(this, query);
+            Utils::Log::addQueryError(this, query, __FILE__, __LINE__);
         }
     }
     return toReturn;
@@ -838,9 +884,9 @@ QMultiHash<int,QString> DrugsBase::getAllINNThatHaveRecordedDosages() const
 /** \brief Return true if all the INNs of the drug are known. */
 bool DrugsBase::drugsINNIsKnown(const DrugsData *drug)
 {
-    const QList<QVariant> & list = drug->listOfCodeMolecules().toList(); //->value(Table_COMPO, COMPO_MOL_CODE).toList();
+    const QList<int> &list = drug->listOfCodeMolecules(); //->value(Table_COMPO, COMPO_MOL_CODE).toList();
     foreach(QVariant q, list)
-        if (getLinkedIamCode(q.toInt()).count() == 0)
+        if (getLinkedAtcIds(q.toInt()).count() == 0)
 //            if (d->m_Lk_iamCode_substCode.key(q.toInt()).count() == 0)
             return false;
     return true;
@@ -850,30 +896,59 @@ bool DrugsBase::drugsINNIsKnown(const DrugsData *drug)
 //-------------------------------- Retreive drugs from database ------------------------------------------
 //--------------------------------------------------------------------------------------------------------
 /** \brief Returns the unique code CIS for the CIP code \e CIP. */
-int DrugsBase::getUIDFromCIP(int CIP)
+QVariant DrugsBase::getUIDFromCIP(int CIP)
 {
     QSqlDatabase DB = QSqlDatabase::database(Constants::DB_DRUGS_NAME);
-    if (!DB.isOpen())
-        DB.open();
+    if (!connectDatabase(DB, __FILE__, __LINE__))
+        return -1;
+
     // prepare where clause
     QHash<int, QString> where;
     where.insert(PACK_PACK_UID, "=" + QString::number(CIP));
     // prepare query
     QString req = this->select(Table_PACKAGING, PACK_DRUG_UID, where);
     QSqlQuery q(req , DB);
-    if (q.isActive())
-        if (q.next())
-            return q.value(0).toInt();
-    return -1;
+    if (q.isActive()) {
+        if (q.next()) {
+            return q.value(0);
+        } else {
+            Utils::Log::addQueryError(this, q, __FILE__, __LINE__);
+        }
+    } else {
+        Utils::Log::addQueryError(this, q, __FILE__, __LINE__);
+    }
+    return QVariant();
+}
+
+QString DrugsBase::getDrugName(const QString &uid) const
+{
+    QSqlDatabase DB = QSqlDatabase::database(Constants::DB_DRUGS_NAME);
+    if (!connectDatabase(DB, __FILE__, __LINE__))
+        return QString();
+
+    // prepare where clause
+    QHash<int, QString> where;
+    where.insert(DRUGS_UID, QString("='%1'").arg(uid));
+    // prepare query
+    QString req = this->select(Table_DRUGS, DRUGS_NAME, where);
+    QSqlQuery q(req , DB);
+    if (q.isActive()) {
+        if (q.next()) {
+            return q.value(0).toString();
+        }
+    } else {
+        Utils::Log::addQueryError(this, q, __FILE__, __LINE__);
+    }
+    return QString();
 }
 
 /** \brief Retrieve and return the drug designed by the CIP code \e CIP_id. This function is not used. */
-DrugsData *DrugsBase::getDrugByCIP(const QVariant & CIP_id)
+DrugsData *DrugsBase::getDrugByCIP(const QVariant &CIP_id)
 {
     // retreive corresponding CIS
-    int u = getUIDFromCIP(CIP_id.toInt());
-    if (u == -1) return 0;
-
+    QVariant u = getUIDFromCIP(CIP_id.toInt());
+    if (u.isNull())
+        return 0;
     // retreive drugs from CIS
     return getDrugByUID(u);
 }
@@ -882,7 +957,7 @@ DrugsData *DrugsBase::getDrugByCIP(const QVariant & CIP_id)
 DrugsData *DrugsBase::getDrugByUID(const QVariant &drug_UID)
 {
     if (!d->m_ActualDBInfos) {
-        DrugsData * toReturn = new DrugsData;
+        DrugsData *toReturn = new DrugsData;
         toReturn->setValue(Table_DRUGS, DRUGS_NAME, QString("No drugs database loaded."));
         return toReturn;
     }
@@ -890,34 +965,32 @@ DrugsData *DrugsBase::getDrugByUID(const QVariant &drug_UID)
     t.start();
 
     QSqlDatabase DB = QSqlDatabase::database(Constants::DB_DRUGS_NAME);
-    if ((!DB.open()) && (!DB.isOpen())) {
-        Utils::Log::addError(this, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
-                             .arg(Constants::DB_DRUGS_NAME).arg(DB.lastError().text()));
+    if (!connectDatabase(DB, __FILE__, __LINE__))
         return 0;
-    }
 
     // construct the where clause
     QHash<int, QString> where;
-    int newUID = drug_UID.toInt();
-    if (newUID == -1) {
+    QString newUID = drug_UID.toString();
+    if (newUID == "-1" || newUID.isEmpty()) {
         QString req = select(Table_DRUGS, DRUGS_UID, where);
         req = req.remove("WHERE ") + " LIMIT 1";
         QSqlQuery q(req,DB);
         if (q.isActive()) {
             if (q.next()) {
-                newUID = q.value(0).toInt();
+                newUID = q.value(0).toString();
             }
         } else {
-            Utils::Log::addError(this, "Can find a valid DRUGS_UID in getDrugByUID where uid==-1");
-            Utils::Log::addQueryError("DrugsBase", q);
+            Utils::Log::addError(this, "Can find a valid DRUGS_UID in getDrugByUID where uid==-1",
+                                 __FILE__, __LINE__);
+            Utils::Log::addQueryError("DrugsBase", q, __FILE__, __LINE__);
             return 0;
         }
     }
-    where.insert(DRUGS_UID, QString("=%1").arg(newUID));
+    where.insert(DRUGS_UID, QString("='%1'").arg(newUID));
 
     // get DRUGS table
     QString req = select(Table_DRUGS, where);
-    DrugsData * toReturn = 0;
+    DrugsData *toReturn = 0;
     {
         QSqlQuery q(req , DB);
         if (q.isActive()) {
@@ -925,19 +998,27 @@ DrugsData *DrugsBase::getDrugByUID(const QVariant &drug_UID)
                 if (q.record().count() != DRUGS_MaxParam)
                     Utils::Log::addError("DrugsBase", QCoreApplication::translate("DrugsBase",
                                                                                   "ERROR : will retreiving %1. Wrong number of fields")
-                                         .arg("DRUGS table"));
+                                         .arg("DRUGS table"),
+                                         __FILE__, __LINE__);
                 int i = 0;
                 toReturn = new DrugsData();
                 for (i = 0; i < DRUGS_MaxParam; ++i)
                     toReturn->setValue(Table_DRUGS, i, q.value(i));
+            } else {
+                Utils::Log::addQueryError(this, q, __FILE__, __LINE__);
             }
+
+            // drug not found --> break
+            if (!toReturn)
+                return toReturn;
+
             // manage drugs denomination according to the database informations
             if (d->m_ActualDBInfos) {
                 QString tmp = d->m_ActualDBInfos->drugsNameConstructor;
                 if (!tmp.isEmpty()) {
                     tmp.replace(field(Table_DRUGS, DRUGS_NAME), toReturn->denomination());
                     tmp.replace(field(Table_DRUGS, DRUGS_FORM), toReturn->form());
-                    tmp.replace(field(Table_DRUGS, DRUGS_ROUTE), toReturn->route());
+                    tmp.replace(field(Table_DRUGS, DRUGS_ROUTE), toReturn->routes().join(", "));
                     // limit strength to three maximum --> if > 3 do not add strength
                     if (toReturn->strength().count(";") >= 3)
                         tmp.replace(field(Table_DRUGS, DRUGS_STRENGTH), "");
@@ -947,13 +1028,13 @@ DrugsData *DrugsBase::getDrugByUID(const QVariant &drug_UID)
                 }
             }
         } else {
-            Utils::Log::addQueryError(this, q);
+            Utils::Log::addQueryError(this, q, __FILE__, __LINE__);
         }
     }
 
     // get COMPO table
     where.clear();
-    where.insert(COMPO_UID, QString("=%1").arg(newUID));
+    where.insert(COMPO_UID, QString("='%1'").arg(newUID));
     QString sort = QString(" ORDER BY %1 ASC").arg(field(Table_COMPO,COMPO_LK_NATURE));
     req = select(Table_COMPO, where) + sort;
     QSet<int> codeMols;
@@ -962,12 +1043,13 @@ DrugsData *DrugsBase::getDrugByUID(const QVariant &drug_UID)
         DrugComposition *precedent = 0;
         QSqlQuery q(req , DB);
         if (q.isActive()) {
-            QList<DrugComposition*> list;
+            QList<DrugComposition *> list;
             while (q.next()) {
                 if (q.record().count() != COMPO_MaxParam)
                     Utils::Log::addError("DrugsBase", QCoreApplication::translate("DrugsBase",
                                                                                   "ERROR : will retreiving %1. Wrong number of fields")
-                                         .arg("COMPOSITION table"));
+                                         .arg("COMPOSITION table"),
+                                         __FILE__, __LINE__);
                 compo = new DrugComposition();
                 int i = 0;
                 for (i = 0; i < COMPO_MaxParam; ++i)
@@ -987,15 +1069,35 @@ DrugsData *DrugsBase::getDrugByUID(const QVariant &drug_UID)
             foreach(DrugComposition *c, list)
                 toReturn->addComposition(c);
         } else {
-            Utils::Log::addQueryError(this, q);
+            Utils::Log::addQueryError(this, q, __FILE__, __LINE__);
         }
     }
     foreach(const int i, codeMols) {
         toReturn->addInnAndIamClasses(getAllInnAndIamClassesIndex(i)) ;
     }
 
-    //     if (toReturn)
-    //         toReturn->warn();
+    // get ROUTES
+    where.clear();
+    where.insert(DRUG_ROUTES_UID, QString("='%1'").arg(toReturn->UID().toString()));
+    req = QString("%1, `%2` WHERE %3 AND %4")
+          .arg(select(Table_ROUTES))
+          .arg(table(Table_DRUG_ROUTES))
+          .arg(getWhereClause(Table_DRUG_ROUTES, where))
+          .arg(fieldEquality(Table_ROUTES, ROUTES_ID, Table_DRUG_ROUTES, DRUG_ROUTES_ROUTE_ID))
+          ;
+    QSqlQuery query(QSqlDatabase::database(Constants::DB_DRUGS_NAME));
+    if (query.exec(req)) {
+        while (query.next()) {
+            toReturn->addRoute(query.value(ROUTES_ID).toInt(), "fr", query.value(ROUTES_FR).toString());
+            toReturn->addRoute(query.value(ROUTES_ID).toInt(), "en", query.value(ROUTES_EN).toString());
+            toReturn->addRoute(query.value(ROUTES_ID).toInt(), "de", query.value(ROUTES_DE).toString());
+        }
+    } else {
+        Utils::Log::addQueryError(this, query, __FILE__, __LINE__);
+    }
+
+    if (WarnExtractedDrugs && toReturn)
+        toReturn->warn();
 
     if (d->m_LogChrono)
         Utils::Log::logTimeElapsed(t, "DrugsBase", "getDrugByUID");
@@ -1003,15 +1105,50 @@ DrugsData *DrugsBase::getDrugByUID(const QVariant &drug_UID)
     return toReturn;
 }
 
+QStringList DrugsBase::getDrugCompositionAtcCodes(const QVariant &uidVariant)
+{
+    static QMultiHash<QString, QString> cache_uid_atcLabel;
+
+    const QString &uid = uidVariant.toString();
+
+    if (cache_uid_atcLabel.keys().contains(uid))
+        return cache_uid_atcLabel.values(uid);
+
+    QSqlDatabase DB = QSqlDatabase::database(Constants::DB_DRUGS_NAME);
+    if (!connectDatabase(DB, __FILE__, __LINE__))
+        return cache_uid_atcLabel.values(uid);
+
+    // get all molecule_code for the drug
+    QHash<int, QString> where;
+    where.insert(Constants::COMPO_UID, QString("='%1'").arg(uid));
+    QString req = select(Constants::Table_COMPO, Constants::COMPO_MOL_CODE, where);
+    QList<int> molecule_codes;
+    {
+        QSqlQuery query(req, DB);
+        if (query.isActive()) {
+            while (query.next()) {
+                molecule_codes.append(query.value(0).toInt());
+            }
+        }
+    }
+    QStringList atcs;
+    foreach(int id, getLinkedAtcIds(molecule_codes)) {
+        QString n = getAtcCode(id);
+        if (!atcs.contains(n)) {
+            atcs.append(n);
+            cache_uid_atcLabel.insertMulti(uid, n);
+        }
+    }
+    return cache_uid_atcLabel.values(uid);
+}
+
 QStringList DrugsBase::getDrugInns(const QVariant &uid)
 {
     QStringList toReturn;
     QSqlDatabase DB = QSqlDatabase::database(Constants::DB_DRUGS_NAME);
-    if (!DB.open()) {
-        Utils::Log::addError(this, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
-                             .arg(Constants::DB_DRUGS_NAME).arg(DB.lastError().text()));
+    if (!connectDatabase(DB, __FILE__, __LINE__))
         return toReturn;
-    }
+
     // get all code_subst for the drug
     QHash<int, QString> where;
     where.insert(Constants::COMPO_UID, QString("='%1'").arg(uid.toString()));
@@ -1023,6 +1160,8 @@ QStringList DrugsBase::getDrugInns(const QVariant &uid)
             while (query.next()) {
                 codes.append(query.value(0).toInt());
             }
+        } else {
+            Utils::Log::addQueryError(this, query, __FILE__, __LINE__);
         }
     }
     foreach(int id, codes) {
@@ -1032,3 +1171,26 @@ QStringList DrugsBase::getDrugInns(const QVariant &uid)
     }
     return toReturn;
 }
+
+int DrugsBase::getRouteId(const QString &fromLabel)
+{
+    QSqlQuery query(QSqlDatabase::database(Constants::DB_DRUGS_NAME));
+    int field = Constants::ROUTES_EN;
+    const QString &lang = QLocale().name().left(2);
+    if (lang=="fr") {
+        field = Constants::ROUTES_FR;
+    } else if (lang=="de") {
+        field = Constants::ROUTES_DE;
+    }
+    int id = -1;
+    QHash<int, QString> where;
+    where.insert(field, QString("=\"%1\"").arg(fromLabel));
+    QString req = select(Constants::Table_ROUTES, Constants::ROUTES_ID, where);
+    if (query.exec(req)) {
+        if (query.next())
+            id = query.value(0).toInt();
+    } else {
+        Utils::Log::addQueryError(this, query, __FILE__, __LINE__);
+    }
+    return id;
+}
