@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -67,8 +53,10 @@
 #include <QApplication>
 #include <QHash>
 #include <QMultiHash>
-#include <QDebug>
 #include <QLocale>
+#include <QPair>
+
+#include <QDebug>
 
 using namespace DrugsDB::Constants;
 
@@ -109,8 +97,9 @@ public:
     QString prescriptionToText(bool toHtml);
     bool usesFromTo(const QString &from, QString &to, const int prescriptionIndex);
 
-
+public:
     QList<DrugComposition *>     m_Compositions;
+    QMultiHash<int, QPair<QString, QString > > m_Routes;  // Pair: x = lang; y = label
 
     QList<structCIP>             m_CIPs;
     QHash< int, QVariant>        m_CISValues;
@@ -165,7 +154,8 @@ void DrugsData::setValue(const int tableref, const int fieldref, const QVariant
                 d->m_COMPOValues.insertMulti(fieldref, value);
             break;
         }
-    default: Utils::Log::addError("DrugsData", "Wrong table reference parameter in DrugsData::setValue()."); break;
+    default: Utils::Log::addError("DrugsData", "Wrong table reference parameter in DrugsData::setValue().",
+                                  __FILE__, __LINE__); break;
     }
 }
 
@@ -175,6 +165,11 @@ void DrugsData::addComposition(DrugComposition *compo)
     d->m_Compositions.append(compo);
 }
 
+void DrugsData::addRoute(const int routeId, const QString &lang, const QString &label)
+{
+    d->m_Routes.insertMulti(routeId, QPair<QString,QString>(lang, label));
+}
+
 void DrugsData::addCIP(const int CIP, const QString &denomination, QDate date)
 {
     /** \todo one drug can have multi presentations ==> list */
@@ -235,7 +230,8 @@ QVariant DrugsData::value(const int tableref, const int fieldref) const
             }
             return QVariant();
         }
-    default: Utils::Log::addError("DrugsData", "Wrong table reference parameter in DrugsData::value()."); break;
+    default: Utils::Log::addError("DrugsData", "Wrong table reference parameter in DrugsData::value().",
+                                  __FILE__, __LINE__); break;
     }
     return QVariant();
 }
@@ -276,10 +272,49 @@ QVariant DrugsData::prescriptionValue(const int fieldref) const
                 return QVariant();
             break;
         }
+    case Prescription::Route :
+        {
+            QString lang = QLocale().name().left(2);
+            typedef QPair<QString, QString> pair;
+            foreach(const pair &p, d->m_Routes.values(d->m_PrescriptionValues.value(Prescription::Route,-1).toInt())) {
+                if (p.first == lang)
+                    return p.second;
+            }
+        }
     }
     return d->m_PrescriptionValues.value(fieldref);
 }
 
+namespace {
+    const char *const XML_COMPOSITION                  = "Composition";
+    const char *const XML_COMPOSITION_INN              = "inn";
+    const char *const XML_COMPOSITION_ATC              = "atc";
+    const char *const XML_COMPOSITION_FORM             = "form";
+    const char *const XML_COMPOSITION_ROUTE            = "route";
+    const char *const XML_COMPOSITION_STRENGTH         = "strenght";
+    const char *const XML_COMPOSITION_MOLECULAR        = "molecularName";
+    const char *const XML_COMPOSITION_NATURE           = "nature";
+    const char *const XML_COMPOSITION_NATURE_LK        = "natureLink";
+}
+QString DrugsData::compositionToXml()
+{
+    QString tmp;
+    /** \todo add ATC to drug composition */
+    foreach(DrugComposition *compo, d->m_Compositions) {
+        tmp += QString("<%1").arg(::XML_COMPOSITION);
+        tmp += QString(" %1=\"%2\" ").arg(::XML_COMPOSITION_INN).arg(compo->innName());
+//        tmp += QString(" %1=\"%2\" ").arg(::XML_COMPOSITION_ATC).arg(compo);
+        tmp += QString(" %1=\"%2\" ").arg(::XML_COMPOSITION_FORM).arg(compo->form());
+        tmp += QString(" %1=\"%2\" ").arg(::XML_COMPOSITION_ROUTE).arg(routes().join(", "));
+        tmp += QString(" %1=\"%2\" ").arg(::XML_COMPOSITION_STRENGTH).arg(compo->innDosage());
+        tmp += QString(" %1=\"%2\" ").arg(::XML_COMPOSITION_MOLECULAR).arg(compo->moleculeName());
+        tmp += QString(" %1=\"%2\" ").arg(::XML_COMPOSITION_NATURE).arg(compo->nature());
+        tmp += QString(" %1=\"%2\" ").arg(::XML_COMPOSITION_NATURE_LK).arg(compo->lkNature());
+        tmp += QString("/>\n");
+    }
+    return tmp;
+}
+
 /**
   \brief Return the drug denomination with or without pharmaceutical firms name
   \sa DrugsDB::Constants::S_HIDELABORATORY
@@ -298,13 +333,13 @@ QString DrugsData::denomination() const
         }
         return d->m_NoLaboDenomination;
     }
-    return value(Constants::Table_DRUGS,Constants::DRUGS_NAME).toString();
+    return value(Constants::Table_DRUGS, Constants::DRUGS_NAME).toString();
 }
 
 /** \brief Returns the list of all the molecules' code of the drug composition */
-QVariant DrugsData::listOfCodeMolecules() const
+QList<int> DrugsData::listOfCodeMolecules() const
 {
-    QVariantList tmp;
+    QList<int> tmp;
     foreach(DrugComposition *compo, d->m_Compositions)
         tmp << compo->m_CodeMolecule;
     return tmp;
@@ -315,11 +350,24 @@ QStringList DrugsData::listOfInnClasses() const
 {
     QStringList tmp;
     foreach(int i, this->allInnAndIamClasses())
-        if (i < 999)
-            tmp << drugsBase()->getInnDenomination(i);
+        if ((200000 < i) && (i < 299999))
+            tmp << drugsBase()->getAtcLabel(i);
+    tmp.sort();
     return tmp;
 }
 
+QStringList DrugsData::routes() const
+{
+    QString lang = QLocale().name().left(2);
+    QStringList toReturn;
+    typedef QPair<QString, QString> pair;
+    foreach(const pair &p, d->m_Routes.values()) {
+        if (p.first == lang)
+            toReturn << p.second;
+    }
+    return toReturn;
+}
+
 /** \brief Returns the list of the molecules' name */
 QStringList DrugsData::listOfMolecules() const
 {
@@ -334,29 +382,82 @@ QStringList DrugsData::listOfInn() const
 {
     // return the list of distinct know INN of this drug
     QStringList toReturn;
-    QString tmp = "";
     foreach(DrugComposition *compo, d->m_Compositions) {
-        if (tmp != compo->innName()) {
-            toReturn << compo->innName();
-            tmp = compo->innName();
-        }
+        toReturn << compo->innName();
     }
-//    qWarning() << toReturn;
+    toReturn.removeDuplicates();
+//    qWarning() << toReturn << __FILE__ << __LINE__;
     return toReturn;
 }
 
-/** \brief Returns all Inn and IamClasses codes knwon for this drug. */
+int DrugsData::numberOfInn() const
+{
+//    qWarning() << allInnAndIamClasses() << __FILE__ <<__LINE__;
+    return allInnAndIamClasses().count();
+}
+
+/** \brief Returns all Inn and IamClasses codes known for this drug. */
 QSet<int> DrugsData::allInnAndIamClasses() const
 {
     return d->m_IamCodes;
 }
 
+QSet<int> DrugsData::allSevenCharsAtcIds() const
+{
+    QSet<int> list;
+    foreach(int i, d->m_IamCodes) {
+        if (i < 99999) {
+            if (drugsBase()->getAtcCode(i).length()==7) {
+                list << i;
+            }
+        }
+    }
+    return list;
+}
+
+QStringList DrugsData::allSevenCharsAtcCodes() const
+{
+    QStringList list;
+    foreach(int i, d->m_IamCodes) {
+        if (i < 99999) {
+            const QString &code = drugsBase()->getAtcCode(i);
+            if (code.length()==7) {
+                list << code;
+            }
+        }
+    }
+    return list;
+}
+
+QSet<int> DrugsData::allAtcIds() const
+{
+    QSet<int> list;
+    foreach(int i, d->m_IamCodes) {
+        if (i < 99999) {
+            list << i;
+        }
+    }
+    return list;
+}
+
+QStringList DrugsData::allAtcCodes() const
+{
+    QStringList list;
+    foreach(int i, d->m_IamCodes) {
+        if (i < 99999) {
+            list <<  drugsBase()->getAtcCode(i);
+        }
+    }
+    return list;
+}
+
+
 /** \brief Returns all Inn and IamClasses codes knwon for this drug. */
 int DrugsData::mainInnCode() const
 {
     QSet<int> list;
     foreach(int i, d->m_IamCodes) {
-        if (i>999)
+        if (i < 99999)
             list << i;
     }
     if (list.count() == 1)
@@ -367,7 +468,7 @@ int DrugsData::mainInnCode() const
 /** \brief Returns the main Inn for this drug. If there is more than one inn or no inn, it returns a null string.*/
 QString DrugsData::mainInnName() const
 {
-    return drugsBase()->getInnDenomination(mainInnCode());
+    return drugsBase()->getAtcLabel(mainInnCode());
 }
 
 /**
@@ -478,7 +579,6 @@ QString DrugsData::toHtml() const
 {
     QString msg;
 
-    const QStringList &mols = this->listOfMolecules();
     const QStringList &iams = this->listOfInn();
     const QStringList &iamClass = this->listOfInnClasses();
     QString textIams, textClass;
@@ -492,27 +592,62 @@ QString DrugsData::toHtml() const
     else
         textClass = iamClass.join("<br>");
 
+    QString uidName = "UID";
+    if (drugsBase()->actualDatabaseInformations()) {
+        if (!drugsBase()->actualDatabaseInformations()->drugsUidName.isEmpty())
+            uidName = drugsBase()->actualDatabaseInformations()->drugsUidName;
+    }
+    QString atc;
+    if (!value(Table_DRUGS, DRUGS_ATC).toString().isEmpty()) {
+        atc = " ; ATC: " + value(Table_DRUGS, DRUGS_ATC).toString();
+    }
+    QString mark = value(Table_DRUGS, DRUGS_AUTHORIZATION).toString();
+    if (!mark.isEmpty()) {
+        mark.prepend("<br>");
+        mark += " | " + value(Table_DRUGS, DRUGS_TYPE_MP).toString();
+    }
+
     msg += QString("<table border=1 cellpadding=2 cellspacing=2 width=100%>\n"
                     " <tr>\n"
                     "   <td colspan=2 rowspan=1 align=center>\n"
                     "       <span style=\"font-weight: bold;\">%1</span>\n"
-                    "       <br>UID = %2\n"
-                    "       <br>ATC = %3\n"
+                    "       %2"
                     "   </td>\n"
                     " </tr>\n"
                     " <tr>\n"
-                    "   <td>%4</td>\n"
-                    "   <td>%5</td>\n"
-                    " </tr>\n"
-                    " <tr>\n"
-                    "   <td colspan=2 rowspan=1>%6</td>\n"
-                    " </tr>\n"
-                    "</table>\n\n")
+                    "   <td colspan=2 rowspan=1>\n"
+                    "       %3\n"
+                    "       <br>%4\n"
+                    "       <br>%5 %6: %7 %8\n"
+                    "   </td>\n"
+                    " </tr>\n")
             .arg(denomination())
+            .arg(mark)
+            .arg(QCoreApplication::translate("DrugsData", "Form(s): ") + value(Table_DRUGS, DRUGS_FORM).toString())
+            .arg(QCoreApplication::translate("DrugsData", "Route(s): ") + value(Table_DRUGS, DRUGS_ROUTE).toString())
+            .arg(QCoreApplication::translate("DrugsData", "Identifier(s): "), uidName)
             .arg(value(Table_DRUGS, DRUGS_UID).toString())
-            .arg(value(Table_DRUGS, DRUGS_ATC).toString())
-            .arg(mols.join("<br>"))
-            .arg(textIams)
+            .arg(atc)
+            ;
+
+    QString tmp = "";
+    QString name;
+    foreach(DrugComposition *compo, d->m_Compositions) {
+        if (compo->innName().isEmpty()) {
+            name = compo->moleculeName();
+        } else if (compo->m_InnCode < 200000) {
+            name = compo->innName();
+        }
+        tmp += QString("<tr><td>%1</td><td>%2</td></tr>").arg(name).arg(compo->dosage());
+        name.clear();
+    }
+
+    msg += QString(" %1\n"
+                   " <tr>\n"
+                   "   <td colspan=2 rowspan=1>%2</td>\n"
+                   " </tr>\n"
+                   "</table>\n\n")
+            .arg(tmp)
             .arg(textClass);
     return msg;
 }
@@ -559,7 +694,6 @@ QString DrugsData::drugsListToHtml(const QDrugsList & list)
     return msg;
 }
 
-
 bool DrugsData::lessThan(const DrugsData *drug1, const DrugsData *drug2)
 {
     bool ald1, ald2;
@@ -589,12 +723,16 @@ QString DrugsData::warnText() const
     if (!Utils::isDebugCompilation())
         return QString();
     QString tmp;
+    tmp += d->m_CISValues[Constants::DRUGS_NAME].toString() + "\n";
+
     foreach(const int i, d->m_CISValues.keys())
-        tmp += QString("CIS : %1 == %2\n")
+        tmp += QString("  %1 = %2\n")
                            .arg(DrugsBase::instance()->field(Table_DRUGS, i))
                            .arg(d->m_CISValues[i].toString());
+
     foreach(DrugComposition *compo, d->m_Compositions)
         tmp += compo->warnText();
+
     foreach(const int i, d->m_PrescriptionValues.keys())
         tmp += QString("Prescription : %1 == %2\n")
                            .arg(i)
@@ -611,7 +749,7 @@ void DrugsData::smallDrugWarn() const
     if (!Utils::isDebugCompilation())
         return;
     Utils::Log::addMessage("DrugsData", QString("get drug: %1 \t %2 \t %3 \t %4")
-                      .arg(this->UID())
+                      .arg(this->UID().toString())
                       .arg(this->denomination().leftJustified(60, ' '), this->form(), this->dosageOfMolecules().join(";")));
 }
 
