@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -74,6 +60,7 @@
 #include <QHash>
 #include <QString>
 #include <QDir>
+#include <QDomDocument>
 
 static inline Core::ISettings *settings() {return Core::ICore::instance()->settings();}
 static inline DrugsDB::Internal::DrugsBase *drugsBase() {return DrugsDB::Internal::DrugsBase::instance();}
@@ -90,7 +77,7 @@ namespace DrugsIOConstants {
     const char *const XML_PRESCRIPTION_MAINTAG             = "Prescription";
     const char *const XML_PRESCRIPTION_ISTEXTUAL           = "IsTextual";
     const char *const XML_PRESCRIPTION_TEXTUALDRUGNAME     = "TextualDrugName";
-    const char *const XML_PRESCRIPTION_CIS                 = "Drug_UID";
+    const char *const XML_PRESCRIPTION_UID                 = "Drug_UID";
     const char *const XML_PRESCRIPTION_TESTONLY            = "OnlyForTest";
     const char *const XML_PRESCRIPTION_ID                  = "Id";
     const char *const XML_PRESCRIPTION_USEDDOSAGE          = "RefDosage";
@@ -118,6 +105,7 @@ namespace DrugsIOConstants {
     const char *const XML_PRESCRIPTION_TOHTML              = "Html";
     const char *const XML_EXTRADATAS_TAG                   = "ExtraDatas";
     const char *const XML_FULLPRESCRIPTION_TAG             = "FullPrescription";
+    const char *const XML_DATEOFGENERATION_TAG             = "DateOfGeneration";
 
     const char *const XML_DRUG_DENOMINATION            = "DrugName";
     const char *const XML_DRUG_INNS                    = "DrugINN";
@@ -134,6 +122,8 @@ using namespace DrugsDB::Constants;
 using namespace Trans::ConstantTranslations;
 
 
+/** \todo memory leak potential when using static functions -> who is deleting the instance singleton ? */
+
 namespace DrugsDB {
 namespace Internal {
 /** \brief Private part of DrugsIO \internal */
@@ -191,9 +181,7 @@ public:
     /** \brief For the Xml transformation of the prescription, return the mfDrugsConstants::Prescription for the xml tag \e xmltag */
     int xmlTagToColumnIndex(const QString &xmltag)
     {
-        if (!m_PrescriptionXmlTags.values().contains(xmltag))
-            return -1;
-        return m_PrescriptionXmlTags.key(xmltag);
+        return m_PrescriptionXmlTags.key(xmltag, -1);
     }
 
 
@@ -265,7 +253,7 @@ void DrugsIO::dosageTransmissionDone()
         Utils::Log::addMessage(this, tr("Dosages transmitted."));
 	Internal::DrugsBase::instance()->markAllDosageTransmitted(d->m_Datas.keys());
     } else
-        Utils::Log::addError(this, tr("Dosage not correctly transmitted"));
+        Utils::Log::addError(this, tr("Dosage not correctly transmitted"), __FILE__, __LINE__);
     d->m_Datas.clear();
     Q_EMIT transmissionDone();
 }
@@ -284,32 +272,39 @@ bool DrugsIO::prescriptionFromXml(DrugsDB::DrugsModel *m, const QString &xmlCont
     Q_ASSERT(m);
     QString xml = xmlContent;
 
-    // check prescription encoding version
-    bool needUpdate = (!DrugsDB::VersionUpdater::instance()->isXmlIOUpToDate(xml));
+    // check prescription encoding version && update XML content if needed
+    bool needUpdate = (!DrugsDB::VersionUpdater::instance()->isXmlIOUpToDate(xmlContent));
     QString version;
     if (needUpdate) {
         version = DrugsDB::VersionUpdater::instance()->xmlVersion(xmlContent);
         Utils::Log::addMessage("DrugsIO::prescriptionFromXml", "Reading old prescription file : version " + version);
-        xml = DrugsDB::VersionUpdater::instance()->updateXmlIOContent(xml);
+        xml = DrugsDB::VersionUpdater::instance()->updateXmlIOContent(xmlContent);
     }
 
+    // Read the XML file using QDomDocument
+    QDomDocument doc;
+    QString error;
+    int line = -1;
+    int column = -1;
+    if (!doc.setContent(xml, &error, &line, &column)) {
+        Utils::warningMessageBox(tr("You are trying to read a corrupted XML file."),
+                                 tr("Error: %1\nLine: %2, Column: %3").arg(error).arg(line).arg(column));
+        return false;
+    }
+
+    /** \todo XML: check document type: <!DOCTYPE name> */
+    QDomElement root = doc.firstChildElement(XML_ROOT_TAG);
+
     // Check if the drugs database correspond to the actual one
     QString xmlDbName = DrugsDB::Constants::DB_DEFAULT_IDENTIFIANT;
-    QString start = QString("<%1>").arg(XML_DRUGS_DATABASE_NAME);
-    QString finish;
-    if (xml.contains(start)) {
-        int begin = xml.indexOf(start) + start.length();
-        finish = QString("</%1").arg(XML_DRUGS_DATABASE_NAME);
-        int end = xml.indexOf(finish, begin);
-        if (begin==-1 || end==-1) {
-            Utils::Log::addError("DrugsIO", tr("Unable to load XML prescription : tag %1 is missing").arg(XML_DRUGS_DATABASE_NAME));
-            return false;
-        }
-        xmlDbName = xml.mid( begin, end - begin);
+    QDomElement drugsDb = root.firstChildElement(::XML_DRUGS_DATABASE_NAME);
+    if (!drugsDb.isNull()) {
+        xmlDbName = drugsDb.text();
     }
     if (drugsBase()->actualDatabaseInformations()->identifiant != xmlDbName) {
         Utils::Log::addError("DrugsIO", QString("Try to load a prescription from another drugs database. Actual: %1 ; Xml: %2")
-                             .arg(drugsBase()->actualDatabaseInformations()->identifiant, xmlDbName));
+                             .arg(drugsBase()->actualDatabaseInformations()->identifiant, xmlDbName),
+                             __FILE__, __LINE__);
         Utils::warningMessageBox(tr("Prescription specifies a different drugs database than the actual one."),
                                  tr("You are trying to load prescription that uses a different drugs database than the "
                                     "actual one. You can not read this prescription unless you change the current "
@@ -321,60 +316,101 @@ bool DrugsIO::prescriptionFromXml(DrugsDB::DrugsModel *m, const QString &xmlCont
     }
 
     // retreive the prescription (inside the XML_FULLPRESCRIPTION_TAG tags)
-    start = QString("<%1").arg(XML_FULLPRESCRIPTION_TAG);
-    finish = QString("</%1>").arg(XML_FULLPRESCRIPTION_TAG);
-    int begin = xml.indexOf(start) + start.length();
-    begin = xml.indexOf("\">", begin) + 2;
-    int end = xml.indexOf(finish, begin);
-    if (begin==-1 || end==-1) {
-        Utils::Log::addError("DrugsIO", tr("Unable to load XML prescription : tag %1 is missing").arg(XML_FULLPRESCRIPTION_TAG));
+    QDomElement fullPrescription = root.firstChildElement(XML_FULLPRESCRIPTION_TAG);
+    if (fullPrescription.isNull()) {
+        Utils::Log::addError("DrugsIO", tr("Unable to load XML prescription : tag %1 is missing").arg(XML_FULLPRESCRIPTION_TAG),
+                             __FILE__, __LINE__);
+        Utils::warningMessageBox(tr("You are trying to read a corrupted XML file."),
+                                 tr("Missing tag: %1").arg(XML_FULLPRESCRIPTION_TAG));
         return false;
     }
-    QString x = xml.mid( begin, end - begin);
-
-    // split full prescription drug by drug
-    QString splitter = QString("</%1>").arg(XML_PRESCRIPTION_MAINTAG);
-    QStringList drugs = x.split(splitter, QString::SkipEmptyParts );
 
     // clear model
     Q_ASSERT(m);
     if (loader==ReplacePrescription)
         m->clearDrugsList();
 
-    // build model with serialized prescription
-    QHash<QString, QString> hash;
+    // Read prescription itself
     QList<int> rowsToUpdate;
-    int row;
-    foreach(const QString &s, drugs) {
-        // Some verifications
-        if (!Utils::readXml(s+QString("</%1>").arg(XML_PRESCRIPTION_MAINTAG), XML_PRESCRIPTION_MAINTAG,hash,false)) {
-            Utils::Log::addError("DrugsIO",tr("Unable to read xml prescription"));
-            continue;
-        }
-        if ((hash.isEmpty()) || (!hash.keys().contains(XML_PRESCRIPTION_CIS)))
-            continue;
-
-        // Add infos to the model
-        if (hash.value(XML_PRESCRIPTION_ISTEXTUAL).compare("true",Qt::CaseInsensitive) == 0) {
-            row = m->addTextualPrescription(hash.value(XML_PRESCRIPTION_TEXTUALDRUGNAME), "");
+    int row = 0;
+    QString errorMsg;
+    bool hasError = false;
+    QDomElement prescr = fullPrescription.firstChildElement(XML_PRESCRIPTION_MAINTAG);
+    while (!prescr.isNull()) {
+        QDomElement item = prescr.firstChildElement(XML_PRESCRIPTION_ISTEXTUAL);
+        // is textual ?
+        if (item.text().compare("true",Qt::CaseInsensitive) == 0) {
+            QString denomination = prescr.firstChildElement(::XML_PRESCRIPTION_TEXTUALDRUGNAME).text();
+            row = m->addTextualPrescription(denomination, "");
         } else {
-            row = m->addDrug(hash.value(XML_PRESCRIPTION_CIS).toInt(), false);
+            // is a good UID ?
+            item = prescr.firstChildElement(::XML_PRESCRIPTION_UID);
+            if (item.isNull() || item.text().isEmpty()) {
+                // no UID
+                QString denomination = prescr.firstChildElement(::XML_DRUG_DENOMINATION).text();
+                errorMsg += tr("  * %1 was added as a textual drug.\n").arg(denomination);
+                row = m->addTextualPrescription(denomination, "");
+                hasError = true;
+                prescr = prescr.nextSiblingElement(XML_PRESCRIPTION_MAINTAG);
+                continue;
+            } else {   // UID informed
+                // UID == -1 --> if denomination known add as textual else ignore
+                if (item.text()=="-1") {
+                    QString denomination = prescr.firstChildElement(::XML_DRUG_DENOMINATION).text();
+                    if (!denomination.isEmpty()) {
+                        errorMsg += tr("  * %1 was added as a textual drug.\n").arg(denomination);
+                        hasError = true;
+                    }
+                    prescr = prescr.nextSiblingElement(XML_PRESCRIPTION_MAINTAG);
+                    continue;
+                }
+                // UID already in prescription ?
+                if (m->containsDrug(item.text())) {
+                    QString denomination = m->drugData(item.text(), Constants::Drug::Denomination).toString();
+                    errorMsg += tr("  * %1 (%2) is already in the prescription. Drug is ignored.\n").arg(denomination).arg(item.text());
+                    hasError = true;
+                    prescr = prescr.nextSiblingElement(XML_PRESCRIPTION_MAINTAG);
+                    continue;
+                }
+                row = m->addDrug(item.text(), false);
+                if (row == -1) {
+                    QString denomination = prescr.firstChildElement(::XML_DRUG_DENOMINATION).text();
+                    errorMsg += tr("  * %1 (%2) was added as a textual drug.\n").arg(denomination).arg(item.text());
+                    row = m->addTextualPrescription(denomination, "");
+                    hasError = true;
+                }
+            }
         }
-        hash.remove(XML_PRESCRIPTION_CIS);
-        foreach(const QString &k, hash.keys()) {
-            m->setData( m->index(row, instance()->d->xmlTagToColumnIndex(k)), hash.value(k) );
+
+        // Read all prescription
+        item = prescr.firstChildElement();
+        while (!item.isNull()) {
+            if (item.tagName().compare(::XML_DRUG_DENOMINATION) != 0 &&
+                item.tagName().compare(::XML_PRESCRIPTION_UID) != 0) {
+                int column = instance()->d->xmlTagToColumnIndex(item.tagName());
+                if (column != -1)
+                    m->setData(m->index(row, column), item.text());
+            }
+            item = item.nextSiblingElement();
         }
-        hash.clear();
 
         // check Model Updaters
         if (needUpdate) {
             rowsToUpdate.append(row);
         }
+
+        prescr = prescr.nextSiblingElement(XML_PRESCRIPTION_MAINTAG);
     }
+
     if ((needUpdate) && (!version.isEmpty())){
         DrugsDB::VersionUpdater::instance()->updateXmlIOModel(version, m, rowsToUpdate);
     }
 
+    if (!errorMsg.isEmpty()) {
+        errorMsg.prepend(tr("Interaction checking will not take these drugs into account.\n"));
+        Utils::warningMessageBox(tr("FreeDiams encountered errors while reading the XML prescription."), errorMsg);
+    }
+
     // check interaction, emit final signal from model for views to update
     m->checkInteractions();
     Q_EMIT m->numberOfRowsChanged();
@@ -413,7 +449,8 @@ bool DrugsIO::loadPrescription(DrugsDB::DrugsModel *m, const QString &fileName,
 {
     Q_ASSERT(m);
     if (fileName.isEmpty()) {
-        Utils::Log::addError("DrugsIO", tr("No file name passed to load prescription"));
+        Utils::Log::addError("DrugsIO", tr("No file name passed to load prescription"),
+                             __FILE__, __LINE__);
         return false;
     }
     QFileInfo info(fileName);
@@ -421,11 +458,13 @@ bool DrugsIO::loadPrescription(DrugsDB::DrugsModel *m, const QString &fileName,
         info.setFile(qApp->applicationDirPath() + QDir::separator() + fileName);
 
     if (!info.exists()) {
-        Utils::Log::addError("DrugsIO", tkTr(Trans::Constants::FILE_1_DOESNOT_EXISTS).arg(info.absoluteFilePath()));
+        Utils::Log::addError("DrugsIO", tkTr(Trans::Constants::FILE_1_DOESNOT_EXISTS).arg(info.absoluteFilePath()),
+                             __FILE__, __LINE__);
         return false;
     }
     if (!info.isReadable()) {
-        Utils::Log::addError("DrugsIO", tkTr(Trans::Constants::FILE_1_ISNOT_READABLE).arg(info.absoluteFilePath()));
+        Utils::Log::addError("DrugsIO", tkTr(Trans::Constants::FILE_1_ISNOT_READABLE).arg(info.absoluteFilePath()),
+                             __FILE__, __LINE__);
         return false;
     }
     xmlExtraDatas.clear();
@@ -452,7 +491,7 @@ bool DrugsIO::loadPrescription(DrugsDB::DrugsModel *m, const QString &fileName,
   Prescription is automatically sorted.\n
   The XML encoded prescription is added inside the HTML code.\n
 */
-QString DrugsIO::prescriptionToHtml(DrugsDB::DrugsModel *m, int version)
+QString DrugsIO::prescriptionToHtml(DrugsDB::DrugsModel *m, const QString &xmlExtraDatas, int version)
 {
     Q_ASSERT(m);
     // clean the model (sort it, hide testing drugs)
@@ -561,10 +600,14 @@ QString DrugsIO::prescriptionToHtml(DrugsDB::DrugsModel *m, int version)
 
     toReturn.replace("{GENERATOR}", qApp->applicationName());
     toReturn.replace("{PRESCRIPTION}", tmp );
+
+    // add XML extraDatas
+    QString xmldPrescription = prescriptionToXml(m, xmlExtraDatas);
+
     toReturn.replace("{ENCODEDPRESCRIPTION}", QString("%1%2")
                      .arg(ENCODEDHTML_FREEDIAMSTAG)
 //                         .arg(QString(prescriptionToXml(m))));
-                     .arg(QString(prescriptionToXml(m).toAscii().toBase64())));
+                     .arg(QString(xmldPrescription.toAscii().toBase64())));
 
 //    Utils::saveStringToFile(toReturn, "/Users/eric/Desktop/essai.html");
 
@@ -573,11 +616,10 @@ QString DrugsIO::prescriptionToHtml(DrugsDB::DrugsModel *m, int version)
     return toReturn;
 }
 
-
 /**
   \brief Transforms the DrugsModel's prescription into a XML encoded string.
 */
-QString DrugsIO::prescriptionToXml(DrugsDB::DrugsModel *m)
+QString DrugsIO::prescriptionToXml(DrugsDB::DrugsModel *m, const QString &xmlExtraData)
 {
     Q_ASSERT(m);
     if (!m->testingDrugsAreVisible()) {
@@ -604,6 +646,10 @@ QString DrugsIO::prescriptionToXml(DrugsDB::DrugsModel *m)
                 ;
     } else {
         keysToSave
+                << Drug::Denomination
+                << Drug::Form
+                << Drug::Route
+                << Drug::GlobalStrength
                 << Prescription::IsTextualOnly
                 << Prescription::UsedDosage
                 << Prescription::Pack_UID
@@ -632,10 +678,17 @@ QString DrugsIO::prescriptionToXml(DrugsDB::DrugsModel *m)
     }
     QHash<QString, QString> forXml;
     int i;
-    for(i=0; i<m->rowCount() ; ++i) {
-        forXml.insert(XML_PRESCRIPTION_CIS, m->index(i, Drug::UID).data().toString());
+    Internal::DrugsData * drug = 0;
+
+    // Process each prescribed drugs
+    for(i=0; i < m->rowCount() ; ++i) {
+        forXml.insert(XML_PRESCRIPTION_UID, m->index(i, Drug::UID).data().toString());
         if (m->index(i, Prescription::OnlyForTest).data().toBool()) {
             forXml.insert(instance()->d->xmlTagForPrescriptionRow(Prescription::OnlyForTest), "true");
+            forXml.insert(instance()->d->xmlTagForPrescriptionRow(Drug::Denomination), m->index(i, Drug::Denomination).data().toString());
+            forXml.insert(instance()->d->xmlTagForPrescriptionRow(Drug::Form), m->index(i, Drug::Form).data().toString());
+            forXml.insert(instance()->d->xmlTagForPrescriptionRow(Drug::Route), m->index(i, Drug::Route).data().toString());
+            forXml.insert(instance()->d->xmlTagForPrescriptionRow(Drug::GlobalStrength), m->index(i, Drug::GlobalStrength).data().toString());
         } else {
             foreach(int k, keysToSave) {
                 if (m->index(i, k).data().type() == QVariant::StringList)
@@ -648,8 +701,19 @@ QString DrugsIO::prescriptionToXml(DrugsDB::DrugsModel *m)
             forXml.insert(XML_PRESCRIPTION_TEXTUALDRUGNAME,
                           m->index(i, Drug::Denomination).data().toString());
         }
-        xmldPrescription += Utils::createXml(XML_PRESCRIPTION_MAINTAG, forXml,4,false);
+        xmldPrescription += Utils::createXml(XML_PRESCRIPTION_MAINTAG, forXml);
         forXml.clear();
+
+        // Insert composition
+        drug = m->getDrug(m->index(i, Drug::UID).data());
+        Q_ASSERT(drug);
+        if (drug) {
+            // Process drugs composition
+            QString tmp = drug->compositionToXml();
+            int index = xmldPrescription.lastIndexOf(XML_PRESCRIPTION_MAINTAG) - 2;
+            xmldPrescription.insert(index, tmp);
+        }
+
     }
 
     // Add full prescription tag and version
@@ -660,22 +724,50 @@ QString DrugsIO::prescriptionToXml(DrugsDB::DrugsModel *m)
     // Close Full prescription
     xmldPrescription.append(QString("</%1>\n").arg(XML_FULLPRESCRIPTION_TAG));
 
-    // Add drugsBase identifiant
+    // Add drugsBase informations
     QString dbName;
-    if (drugsBase()->actualDatabaseInformations())
+    QString dbInfoAttribs;
+    if (drugsBase()->actualDatabaseInformations()) {
         dbName = drugsBase()->actualDatabaseInformations()->identifiant;
-    else
+        QString t = drugsBase()->actualDatabaseInformations()->version;
+        dbInfoAttribs += QString("version=\"%1\" ").arg(t.replace("\"","'"));
+        t = drugsBase()->actualDatabaseInformations()->compatVersion;
+        dbInfoAttribs += QString("compatWithFreeDiamsVersion=\"%1\" ").arg(t.replace("\"","'"));
+        t = drugsBase()->actualDatabaseInformations()->complementaryWebsite;
+        dbInfoAttribs += QString("complementaryWebSite=\"%1\" ").arg(t.replace("\"","'"));
+        dbInfoAttribs += QString("date=\"%1\" ").arg(drugsBase()->actualDatabaseInformations()->date.toString(Qt::ISODate));
+        t = drugsBase()->actualDatabaseInformations()->provider;
+        dbInfoAttribs += QString("provider=\"%1\" ").arg(t.replace("\"","'"));
+        t = drugsBase()->actualDatabaseInformations()->weblink;
+        dbInfoAttribs += QString("webLink=\"%1\" ").arg(t.replace("\"","'"));
+        t = drugsBase()->actualDatabaseInformations()->packUidName;
+        dbInfoAttribs += QString("packUidName=\"%1\" ").arg(t.replace("\"","'"));
+        t = drugsBase()->actualDatabaseInformations()->drugsUidName;
+        dbInfoAttribs += QString("drugUidName=\"%1\" ").arg(t.replace("\"","'"));
+    } else {
         dbName = Constants::DB_DEFAULT_IDENTIFIANT;
-    xmldPrescription.prepend(QString("<%1>%2</%1>\n").arg(XML_DRUGS_DATABASE_NAME).arg(dbName));
+    }
+    xmldPrescription.prepend(QString("<%1 %2>%3</%1>\n")
+                             .arg(XML_DRUGS_DATABASE_NAME)
+                             .arg(dbInfoAttribs)
+                             .arg(dbName));
 
-    // Add the main root node
+    // Add the date of generation
+    xmldPrescription.prepend(QString("<%1>%2</%1>\n").arg(XML_DATEOFGENERATION_TAG).arg(QDateTime::currentDateTime().toString(Qt::ISODate)));
+
+    // Add the main root node and extraData
     xmldPrescription.prepend(QString("<%1>\n").arg(XML_ROOT_TAG));
+    xmldPrescription.append(xmlExtraData);
     xmldPrescription.append(QString("</%1>\n").arg(XML_ROOT_TAG));
 
     // Add the version and the FullPrescription tags
     xmldPrescription.prepend(QString("%1\n").arg(XML_HEADER));
 
-    return xmldPrescription;
+    // Beautifying the XML
+    QDomDocument root;
+    root.setContent(xmldPrescription);
+
+    return root.toString(4);
 }
 
 /**
@@ -686,15 +778,11 @@ QString DrugsIO::prescriptionToXml(DrugsDB::DrugsModel *m)
 bool DrugsIO::savePrescription(DrugsDB::DrugsModel *model, const QHash<QString,QString> &extraDatas, const QString &toFileName)
 {
     Q_ASSERT(model);
-    QString xmldPrescription = prescriptionToXml(model);
-    // add extraDatas
+    QString extra;
     if (!extraDatas.isEmpty()) {
-        QString tmp = Utils::createXml(XML_EXTRADATAS_TAG, extraDatas, 4, false);
-        xmldPrescription.append(tmp);
-        tmp = QString("</%1>").arg(XML_ROOT_TAG);
-        xmldPrescription.remove(tmp);
-        xmldPrescription.append(tmp);
+        extra = Utils::createXml(XML_EXTRADATAS_TAG, extraDatas);
     }
+    QString xmldPrescription = prescriptionToXml(model, extra);
     if (toFileName.isEmpty())
         return Utils::saveStringToFile(xmldPrescription,
                                       QDir::homePath() + "/prescription.di",
@@ -711,16 +799,13 @@ bool DrugsIO::savePrescription(DrugsDB::DrugsModel *model, const QHash<QString,Q
 bool DrugsIO::savePrescription(DrugsDB::DrugsModel *model, const QString &extraXmlDatas, const QString &toFileName)
 {
     Q_ASSERT(model);
-    QString xmldPrescription = prescriptionToXml(model);
-    // add extraDatas
+    QString extra;
     if (!extraXmlDatas.isEmpty()) {
-        xmldPrescription.append(QString("\n<%1>\n").arg(XML_EXTRADATAS_TAG));
-        xmldPrescription.append(extraXmlDatas);
-        xmldPrescription.append(QString("\n</%1>\n").arg(XML_EXTRADATAS_TAG));
-        QString tmp = QString("</%1>").arg(XML_ROOT_TAG);
-        xmldPrescription.remove(tmp);
-        xmldPrescription.append(tmp);
+        extra.append(QString("\n<%1>\n").arg(XML_EXTRADATAS_TAG));
+        extra.append(extraXmlDatas);
+        extra.append(QString("\n</%1>\n").arg(XML_EXTRADATAS_TAG));
     }
+    QString xmldPrescription = prescriptionToXml(model, extra);
     if (toFileName.isEmpty())
         return Utils::saveStringToFile(xmldPrescription,
                                       QDir::homePath() + "/prescription.di",
@@ -729,36 +814,6 @@ bool DrugsIO::savePrescription(DrugsDB::DrugsModel *model, const QString &extraX
         return Utils::saveStringToFile(xmldPrescription, toFileName, Utils::Overwrite, Utils::DontWarnUser);
 }
 
-//static QString prepareHeader()
-//{
-//    QString header = user()->value(Core::IUser::PrescriptionHeader).toString();
-//    user()->replaceTokens(header);
-//    /** \todo Create a prefs for Date format */
-//    Utils::replaceToken(header, Core::Constants::TOKEN_DATE, QDate::currentDate().toString(QLocale().dateFormat()));
-//    Core::IPatient *patient = Core::ICore::instance()->patient();
-//    patient->replaceTokens(header);
-//    return header;
-//}
-//
-//static QString prepareFooter(DrugsDB::DrugsModel *model)
-//{
-//    QString footer = user()->value(Core::IUser::PrescriptionFooter).toString();
-//    user()->replaceTokens(footer);
-//    Utils::replaceToken(footer, Core::Constants::TOKEN_NUMBEROFDRUGS, QString::number(model->rowCount()));
-//    Core::IPatient *patient = Core::ICore::instance()->patient();
-//    patient->replaceTokens(footer);
-//    footer.replace("</body>",QString("<br /><span style=\"align:left;font-size:6pt;color:black;\">%1</span></p></body>")
-//                   .arg(QCoreApplication::translate("DrugsIO", "Made with %1.").arg(qApp->applicationName())));
-//    return footer;
-//}
-//
-//static inline void setUserWatermark(Print::Printer *p)
-//{
-//    p->addHtmlWatermark(user()->value(Core::IUser::PrescriptionWatermark).toString(),
-//                       Print::Printer::Presence(user()->value(Core::IUser::PrescriptionWatermarkPresence).toInt()),
-//                       Qt::AlignmentFlag(user()->value(Core::IUser::PrescriptionWatermarkAlignement).toInt()));
-//}
-
 bool DrugsIO::printPrescription(DrugsDB::DrugsModel *model)
 {
     Core::IDocumentPrinter *p = printer();
@@ -768,7 +823,7 @@ bool DrugsIO::printPrescription(DrugsDB::DrugsModel *model)
     /** \todo add EPISODE_DATE token for FMF */
     p->addTokens(Core::IDocumentPrinter::Tokens_Global, tokens);
     /** \todo add more options for the user : select papers, print duplicatas... */
-    return p->print(DrugsDB::DrugsIO::prescriptionToHtml(model, DrugsIO::MedinTuxVersion),
+    return p->print(DrugsDB::DrugsIO::prescriptionToHtml(model, "", DrugsIO::MedinTuxVersion),
                     Core::IDocumentPrinter::Papers_Prescription_User,
                     settings()->value(Constants::S_PRINTDUPLICATAS).toBool());
 }
@@ -784,7 +839,7 @@ void DrugsIO::prescriptionPreview(DrugsDB::DrugsModel *model)
     p->addTokens(Core::IDocumentPrinter::Tokens_Global, tokens);
 
     /** \todo add more options for the user : select papers, print duplicatas... */
-    p->printPreview(DrugsDB::DrugsIO::prescriptionToHtml(model, DrugsIO::MedinTuxVersion),
+    p->printPreview(DrugsDB::DrugsIO::prescriptionToHtml(model, "", DrugsIO::MedinTuxVersion),
              Core::IDocumentPrinter::Papers_Prescription_User,
              settings()->value(Constants::S_PRINTDUPLICATAS).toBool());
 }
