@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -49,13 +35,13 @@
 
 #include "drugsmodel.h"
 
-// include drugwidgets headers
 #include <drugsbaseplugin/drugsbase.h>
 #include <drugsbaseplugin/drugsinteraction.h>
 #include <drugsbaseplugin/drugsio.h>
 #include <drugsbaseplugin/interactionsmanager.h>
 #include <drugsbaseplugin/constants.h>
 #include <drugsbaseplugin/dailyschememodel.h>
+#include <drugsbaseplugin/globaldrugsmodel.h>
 
 #include <utils/global.h>
 #include <utils/log.h>
@@ -79,6 +65,7 @@
 #include <QStringList>
 #include <QMimeData>
 #include <QDomDocument>
+#include <QDir>
 
 
 namespace mfDrugsModelConstants {
@@ -122,7 +109,7 @@ public:
     }
 
     /** \brief Return the pointer to the drug if it is already in the drugs list, otherwise return 0 */
-    DrugsData *getDrug(const int uid)
+    DrugsData *getDrug(const QVariant &uid)
     {
         if (m_LastDrugRequiered) {
             if (m_LastDrugRequiered->UID() == uid) {
@@ -179,14 +166,14 @@ public:
         case Drug::UID :                return drug->UID();
         case Drug::Pack_UID :           return drug->CIPs();
         case Drug::Form :               return drug->form();
-        case Drug::Route :              return drug->route();
+        case Drug::Route :              return drug->routes().join(", ");
         case Drug::ATC :                return drug->ATC();
         case Drug::IsScoredTablet :     return drug->isScoredTablet();
         case Drug::GlobalStrength :     return drug->strength();
         case Drug::Molecules :          return drug->listOfMolecules();
         case Drug::AllInnsKnown :       return drugsBase()->drugsINNIsKnown(drug);
         case Drug::Inns :               return drug->listOfInn();
-        case Drug::InnsATCcodes :  /** \todo code here */            return QVariant();
+        case Drug::InnsATCcodes :       return drug->allAtcCodes();
         case Drug::MainInnCode :        return drug->mainInnCode();
         case Drug::MainInnDosage :      return drug->mainInnDosage();
         case Drug::MainInnName :        return drug->mainInnName();
@@ -196,9 +183,16 @@ public:
         case Drug::MaximumLevelOfInteraction : return int(m_InteractionsManager->getMaximumTypeOfIAM(drug));
         case Drug::CompositionString :  return drug->toHtml();
         case Drug::InnCompositionString :  return drug->innComposition();
-        case Drug::CodeMoleculesList :  return drug->listOfCodeMolecules();
+        case Drug::CodeMoleculesList :
+            {
+                QVariantList list;
+                foreach(int code, drug->listOfCodeMolecules())
+                    list << code;
+                return list;
+            }
         case Drug::HasPrescription :    return drug->hasPrescription();
         case Drug::LinkToSCP :          return drug->linkToSCP();
+        case Drug::AvailableRoutes : return drug->routes();
         case Drug::AvailableForms :
             {
                 QStringList toReturn;
@@ -206,14 +200,9 @@ public:
                 toReturn << tkTr(Trans::Constants::INTAKES);
                 if (drug->numberOfInn() == 1) {
                     toReturn << QApplication::translate("DrugsModel", "x %1 of %2")
-                            .arg(drug->dosageOfMolecules().at(0) , drug->listOfInn().at(0));
+                            .arg(drug->dosageOfMolecules().at(0))
+                            .arg(drug->listOfInn().at(0));
                 }
-                if (!settings()->value(Constants::S_USERRECORDEDFORMS).isNull()) {
-                    foreach(const QString &s, settings()->value(Constants::S_USERRECORDEDFORMS).toStringList())
-                        if (!s.isEmpty())
-                            toReturn << s;
-                }
-                toReturn << DosageModel::predeterminedForms();
                 return toReturn;
                 break;
             }
@@ -244,6 +233,7 @@ public:
         case Prescription::IntakesUsesFromTo :     return drug->prescriptionValue(Prescription::IntakesUsesFromTo);
         case Prescription::IntakesIntervalOfTime : return drug->prescriptionValue(Prescription::IntakesIntervalOfTime);
         case Prescription::IntakesIntervalScheme : return drug->prescriptionValue(Prescription::IntakesIntervalScheme);
+        case Prescription::Route :                 return drug->prescriptionValue(Prescription::Route);
         case Prescription::DurationFrom :          return drug->prescriptionValue(Prescription::DurationFrom);
         case Prescription::DurationTo :            return drug->prescriptionValue(Prescription::DurationTo);
         case Prescription::DurationScheme :        return drug->prescriptionValue(Prescription::DurationScheme);
@@ -263,6 +253,7 @@ public:
         case Interaction::Id :     return QVariant();
         case Interaction::Icon :   return m_InteractionsManager->iamIcon(drug, m_levelOfWarning);
         case Interaction::Pixmap : return m_InteractionsManager->iamIcon(drug, m_levelOfWarning).pixmap(16,16);
+        case Interaction::MediumPixmap : return m_InteractionsManager->iamIcon(drug, m_levelOfWarning, true).pixmap(64,64);
         case Interaction::ToolTip :
             {
                 QString display;
@@ -277,10 +268,43 @@ public:
                 return display;
                 break;
             }
+        case Drug::OwnInteractionsSynthesis:
+            {
+                QString display;
+                QList<DrugsInteraction *> list = m_InteractionsManager->getAllInteractionsFound();
+                QList<DrugsInteraction *> concernedInteractions;
+                QList<DrugsData *> concernedDrugs;
+                int i = 0;
+                display.append("<p>");
+                foreach(DrugsInteraction *interaction, list) {
+                    if (interaction->drugs().contains((DrugsData*)drug)) {
+                        concernedInteractions.append(interaction);
+                        foreach(DrugsData *drg, interaction->drugs()) {
+                            if (!concernedDrugs.contains(drg))
+                                concernedDrugs.append(drg);
+                        }
+                    }
+                }
+                foreach(DrugsData *drg, concernedDrugs) {
+                    ++i;
+                    display.append(QString("%1&nbsp;.&nbsp;%2<br />")
+                                   .arg(i)
+                                   .arg(drg->denomination()));
+                }
+                display.append("</p><p>");
+                if (concernedDrugs.count() > 0) {
+                    display.append(m_InteractionsManager->synthesisToHtml(concernedInteractions, false));
+                } else {
+                    display = tkTr(Trans::Constants::NO_1_FOUND).arg(tkTr(Trans::Constants::INTERACTION));
+                }
+                display.append("</p>");
+                return display;
+                break;
+            }
         case Interaction::FullSynthesis :
             {
                 QString display;
-                const QList<DrugsInteraction *> & list = m_InteractionsManager->getAllInteractionsFound();
+                QList<DrugsInteraction *> list = m_InteractionsManager->getAllInteractionsFound();
                 int i = 0;
                 display.append("<p>");
                 foreach(DrugsData *drg, m_DrugsList) {
@@ -326,11 +350,11 @@ DrugsModel::DrugsModel(QObject * parent)
     ++handler;
     setObjectName("DrugsModel_" + QString::number(handler));
     if (!drugsBase()->isInitialized())
-        Utils::Log::addError(this,"Drugs database not intialized");
+        Utils::Log::addError(this,"Drugs database not intialized", __FILE__, __LINE__);
     d->m_DrugsList.clear();
     d->m_DosageModelList.clear();
     d->m_InteractionsManager = new InteractionsManager(this);
-    Utils::Log::addMessage(this, "Instance created");
+//    Utils::Log::addMessage(this, "Instance created");
     connect(drugsBase(), SIGNAL(dosageBaseHasChanged()), this, SLOT(dosageDatabaseChanged()));
 }
 
@@ -409,9 +433,9 @@ bool DrugsModel::setData(const QModelIndex &index, const QVariant &value, int ro
   Drug must be setted into the model otherwise, this function returns false.\n
   If you want the model to be refreshed call resetModel() after all datas were setted.
 */
-bool DrugsModel::setDrugData(const int CIS, const int column, const QVariant &value)
+bool DrugsModel::setDrugData(const QVariant &drugUid, const int column, const QVariant &value)
 {
-    Internal::DrugsData *drug = d->getDrug(CIS);
+    Internal::DrugsData *drug = d->getDrug(drugUid);
     if (!drug)
         return false;
     if (d->setDrugData(drug, column, value)) {
@@ -468,7 +492,12 @@ QVariant DrugsModel::data(const QModelIndex &index, int role) const
     }
     else if (role == Qt::ToolTipRole) {
         QString display;
-        display = drug->toHtml();
+        if (GlobalDrugsModel::hasAllergy(drug)) {
+            display += QString("<table width=100%><tr><td><img src=\"%1\"></td><td width=100% align=center><span style=\"color:red;font-weight:600\">%2</span></td><td><img src=\"%1\"></span></td></tr></table><br>")
+                   .arg(settings()->path(Core::ISettings::SmallPixmapPath) + QDir::separator() + QString(Core::Constants::ICONFORBIDDEN))
+                   .arg(tr("KNOWN ALLERGY"));
+        }
+        display += drug->toHtml();
 
         if (d->m_InteractionsManager->drugHaveInteraction(drug)) {
             const QList<Internal::DrugsInteraction *> &list = d->m_InteractionsManager->getInteractions(drug);
@@ -484,14 +513,16 @@ QVariant DrugsModel::data(const QModelIndex &index, int role) const
         // Drugs only for testings
         if (drug->prescriptionValue(Constants::Prescription::OnlyForTest).toBool())
             return QColor(FORTEST_BACKGROUND_COLOR);
+        // Allergy / Intolerances
+        if (GlobalDrugsModel::hasAllergy(drug))
+            return QColor(settings()->value(DrugsDB::Constants::S_ALLERGYBACKGROUNDCOLOR).toString());
+        if (GlobalDrugsModel::hasIntolerance(drug))
+            return QColor(settings()->value(DrugsDB::Constants::S_INTOLERANCEBACKGROUNDCOLOR).toString());
     }
     else if (role == Qt::ForegroundRole) {
         if (drug->prescriptionValue(Constants::Prescription::OnlyForTest).toBool())
             return QColor(FORTEST_FOREROUND_COLOR);
     }
-    //     else if (role == Qt::SizeHintRole) {
-    //         return QSize(d->m_RowSize[index.row()],d->m_RowSize[index.row()]);
-    //     }
     return QVariant();
 }
 
@@ -499,9 +530,9 @@ QVariant DrugsModel::data(const QModelIndex &index, int role) const
   \brief At anytime, you can get all values of drugs inside the prescription model using the CIS as row index.
   \sa data()
 */
-QVariant DrugsModel::drugData(const int CIS, const int column)
+QVariant DrugsModel::drugData(const QVariant &drugUid, const int column)
 {
-    Internal::DrugsData *drug = d->getDrug(CIS);
+    Internal::DrugsData *drug = d->getDrug(drugUid);
     if (!drug)
         return QVariant();
     return d->getDrugValue(drug, column);
@@ -592,9 +623,9 @@ int DrugsModel::addDrug(Internal::DrugsData *drug, bool automaticInteractionChec
    Return the index of the inserted drug into the list or -1 if no drug was inserted.
    \sa addDrug()
 */
-int DrugsModel::addDrug(const int uid, bool automaticInteractionChecking)
+int DrugsModel::addDrug(const QVariant &drugUid, bool automaticInteractionChecking)
 {
-    return addDrug(drugsBase()->getDrugByUID(uid), automaticInteractionChecking);
+    return addDrug(drugsBase()->getDrugByUID(drugUid), automaticInteractionChecking);
 }
 
 /**
@@ -632,19 +663,34 @@ void DrugsModel::setDrugsList(QDrugsList &list)
 }
 
 /** \brief Returns true if the drug is already in the prescription */
-bool DrugsModel::containsDrug(const int uid) const
+bool DrugsModel::containsDrug(const QVariant &drugUid) const
 {
-    if (d->getDrug(uid))
+    if (d->getDrug(drugUid))
         return true;
     return false;
 }
 
+/** \brief direct access to the DrugsData pointer. The pointer MUST BE DELETED. */
+Internal::DrugsData *DrugsModel::getDrug(const QVariant &drugUid) const
+{
+    return d->getDrug(drugUid);
+}
+
 /** \brief Returns true if the actual prescription has interaction(s). */
 bool DrugsModel::prescriptionHasInteractions()
 {
     return (d->m_InteractionsManager->getAllInteractionsFound().count()>0);
 }
 
+bool DrugsModel::prescriptionHasAllergies()
+{
+    foreach(const Internal::DrugsData *drug, d->m_DrugsList) {
+        if (GlobalDrugsModel::hasAllergy(drug))
+            return true;
+    }
+
+    return false;
+}
 
 /**
   \brief Sort the drugs inside prescription. \sa DrugsDB::lessThan().
@@ -745,7 +791,7 @@ bool DrugsModel::isModified() const
 
 
 /** \brief Returns the dosage model for the selected drug */
-Internal::DosageModel * DrugsModel::dosageModel(const int uid)
+Internal::DosageModel * DrugsModel::dosageModel(const QVariant &drugUid)
 {
 //    if (! d->m_DosageModelList.keys().contains(uid)) {
 //        d->m_DosageModelList.insert(uid, new Internal::DosageModel(this));
@@ -756,7 +802,7 @@ Internal::DosageModel * DrugsModel::dosageModel(const int uid)
 //    }
 //    return d->m_DosageModelList.value(uid);
     Internal::DosageModel *m = new Internal::DosageModel(this);
-    m->setDrugUID(uid);
+    m->setDrugUID(drugUid);
     return m;
 }
 
@@ -767,7 +813,7 @@ Internal::DosageModel *DrugsModel::dosageModel(const QModelIndex &drugIndex)
         return 0;
     if (drugIndex.column() != Constants::Drug::UID)
         return 0;
-    return dosageModel(drugIndex.data().toInt());
+    return dosageModel(drugIndex.data());
 }
 
 InteractionsManager *DrugsModel::currentInteractionManger() const
@@ -776,14 +822,14 @@ InteractionsManager *DrugsModel::currentInteractionManger() const
 }
 
 /** \brief Removes a drug from the prescription */
-int DrugsModel::removeDrug(const int uid)
+int DrugsModel::removeDrug(const QVariant &drugUid)
 {
     // Take care that this function removes all occurence of the referenced drug
     d->m_LastDrugRequiered = 0;
     d->m_InteractionsManager->clearDrugsList();
     int i = 0;
     foreach(Internal::DrugsData * drug, d->m_DrugsList) {
-        if (drug->UID() == uid) {
+        if (drug->UID() == drugUid) {
             d->m_DrugsList.removeAt(d->m_DrugsList.indexOf(drug));
             delete drug;
             ++i;
@@ -851,13 +897,16 @@ QString DrugsModel::getFullPrescription(const Internal::DrugsData *drug, bool to
     tokens_value.insert("DAILY_SCHEME", "");
     tokens_value.insert("REPEATED_DAILY_SCHEME", "");
     tokens_value.insert("DISTRIBUTED_DAILY_SCHEME", "");
+    tokens_value.insert("PERIOD", "");
     tokens_value.insert("PERIOD_SCHEME", "");
+    tokens_value.insert("ROUTE", "");
     tokens_value.insert("D_FROM", "");
     tokens_value.insert("D_TO", "");
     tokens_value.insert("D_SCHEME", "");
     tokens_value.insert("MEAL", "");
-    tokens_value.insert("PERIOD", "");
     tokens_value.insert("NOTE", "");
+    tokens_value.insert("MIN_INTERVAL", "");
+    tokens_value.insert("MIN_INTERVAL_SCHEME", "");
 
     // Manage Textual drugs only
     if (drug->prescriptionValue(Constants::Prescription::IsTextualOnly).toBool()) {
@@ -903,20 +952,35 @@ QString DrugsModel::getFullPrescription(const Internal::DrugsData *drug, bool to
 
     // Duration
     if (drug->prescriptionValue(Constants::Prescription::DurationFrom).toDouble()) {
-        tokens_value["PERIOD_SCHEME"] = drug->prescriptionValue(Constants::Prescription::PeriodScheme).toString();
         tokens_value["D_FROM"] = QString::number(drug->prescriptionValue(Constants::Prescription::DurationFrom).toDouble());
         if (drug->prescriptionValue(Constants::Prescription::DurationUsesFromTo).toBool())
             tokens_value["D_TO"] = QString::number(drug->prescriptionValue(Constants::Prescription::DurationTo).toDouble());
 
+        // Manage plurial form
+        tokens_value["PERIOD_SCHEME"] = drug->prescriptionValue(Constants::Prescription::PeriodScheme).toString();
         tokens_value["D_SCHEME"] = drug->prescriptionValue(Constants::Prescription::DurationScheme).toString();
+        int max = qMax(drug->prescriptionValue(Constants::Prescription::DurationFrom).toDouble(), drug->prescriptionValue(Constants::Prescription::DurationTo).toDouble());
+        if (periods().contains(tokens_value["D_SCHEME"])) {
+            tokens_value["D_SCHEME"] = periodPlurialForm(periods().indexOf(tokens_value["D_SCHEME"]), max, tokens_value["D_SCHEME"]);
+        }
+        max = drug->prescriptionValue(Constants::Prescription::Period).toDouble();
+        if (max==1 && QLocale().name().left(2)=="fr")
+            ++max;
+        if (periods().contains(tokens_value["PERIOD_SCHEME"])) {
+            tokens_value["PERIOD_SCHEME"] = periodPlurialForm(periods().indexOf(tokens_value["PERIOD_SCHEME"]), max, tokens_value["PERIOD_SCHEME"]);
+        }
     } else {
         tokens_value["PERIOD_SCHEME"] = tokens_value["D_FROM"] = tokens_value["D_TO"] = tokens_value["D_SCHEME"] = "";
     }
 
     tokens_value["MEAL"] = Trans::ConstantTranslations::mealTime(drug->prescriptionValue(Constants::Prescription::MealTimeSchemeIndex).toInt());
     QString tmp2 = drug->prescriptionValue(Constants::Prescription::Period).toString();
-    if (tmp2 == "1")
+
+    /** \todo provide a better management of 'EACH DAY__S__' here .. \sa Translation::periodPlurialForm()*/
+    // Period management of 'EACH DAY__S'
+    if (tmp2 == "1") {
         tmp2.clear();
+    }
     tokens_value["PERIOD"] = tmp2;
 
     if (toHtml) {
@@ -924,10 +988,27 @@ QString DrugsModel::getFullPrescription(const Internal::DrugsData *drug, bool to
     } else {
         tokens_value["NOTE"] = drug->prescriptionValue(Constants::Prescription::Note).toString();
     }
+
+    // Min interval
+    const QVariant &interval = drug->prescriptionValue(Constants::Prescription::IntakesIntervalOfTime);
+    const QVariant &intervalScheme = drug->prescriptionValue(Constants::Prescription::IntakesIntervalScheme);
+    if ((!interval.isNull() && !intervalScheme.isNull()) &&
+        interval.toInt() > 0) {
+        tokens_value["MIN_INTERVAL"] = interval.toString() + " " + periodPlurialForm(intervalScheme.toInt(), interval.toInt());
+    }
+
+    // Route
+    tokens_value["ROUTE"] = drug->prescriptionValue(Constants::Prescription::Route).toString();
+
     Utils::replaceTokens(tmp, tokens_value);
     return tmp;
 }
 
+DrugsDB::InteractionsManager *DrugsModel::interactionsManager() const
+{
+    return d->m_InteractionsManager;
+}
+
 Qt::DropActions DrugsModel::supportedDropActions() const
 {
 #if QT_VERSION >= 0x040600
