@@ -1,3 +1,23 @@
+/***************************************************************************
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
+ *                                                                         *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
+ *                                                                         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
+ *                                                                         *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
+ ***************************************************************************/
 /**
   \class DrugsDB::DatabaseUpdater
   \brief This class manages drugs and dosages databases updates from versions to versions
@@ -44,108 +64,328 @@ using namespace DrugsDB;
 ///////////////////////////////////////////////////////////////////////
 namespace {
 
-    class Dosage_030_To_040 : public DrugsDB::DosageDatabaseUpdateStep
+class Dosage_050_To_054 : public DrugsDB::DosageDatabaseUpdateStep
+{
+public:
+    // From v 0.5.0 To v 0.5.4
+    // - Renaming and redefining DRUG_UID_LK varchar(20) instead of CIS_LK integer
+    Dosage_050_To_054() : DrugsDB::DosageDatabaseUpdateStep() {}
+    ~Dosage_050_To_054() {}
+
+    QString userMessage() const
     {
-    public:
-        // From v 0.0.8 To v 0.2.0
-        // - Adding DRUGS_DATABASE_FILENAME
-        Dosage_030_To_040() : DrugsDB::DosageDatabaseUpdateStep() {}
-        ~Dosage_030_To_040() {}
+        return QApplication::translate("DatabaseUpdater", "Your dosage database needs to be "
+                                       "updated from version 0.5.0 to version 0.5.4.\n"
+                                       "This will be automatically done.");
+    }
 
-        QString userMessage() const
-        {
-            return QApplication::translate("DatabaseUpdater", "Your dosage database needs to be "
-                                           "updated from version 0.2.0 to version 0.4.0.\n"
-                                           "This will be automatically done.");
-        }
+    QString fromVersion() const { return "0.5.0"; }
+    QString toVersion() const { return "0.5.4"; }
 
-        QString fromVersion() const { return "0.2.0"; }
-        QString toVersion() const { return "0.4.0"; }
+    void setConnectionName(const QString &name) { m_Name = name; }
 
-        void setConnectionName(const QString &name) { m_Name = name; }
+    bool retreiveValuesToUpdate() const  {return true;}
 
-        bool retreiveValuesToUpdate() const  {return true;}
-
-        bool updateDatabaseScheme() const
-        {
-            // these versions only use SQLite
-            QSqlDatabase db = QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME);
+    bool updateDatabaseScheme() const
+    {
+        // these versions only use SQLite
+        QSqlDatabase db = QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME);
+        if (!db.isOpen()) {
             if (!db.open()) {
+                Utils::Log::addError("VersionUpdater", tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
+                                     .arg(db.connectionName()).arg(db.lastError().text()),
+                                     __FILE__, __LINE__);
                 return false;
             }
-            QStringList req;
+        }
+        QStringList req;
+        if (db.driverName() == "QSQLITE") {
             req << "﻿ALTER TABLE `DOSAGE` RENAME TO `OLD_DOSAGE`;";
             req << DrugsDB::Internal::DrugsBase::dosageCreateTableSqlQuery();
             req << QString("INSERT INTO `DOSAGE` (%1) SELECT %1 FROM `OLD_DOSAGE`;")
-                          .arg("`POSO_ID`,"
-                               "`POSO_UUID`,"
-                               // "`DRUGS_DATABASE_IDENTIFIANT`,"
-                               "`INN_LK`,"
-                               "`INN_DOSAGE`,"
-                               "`CIS_LK`,"
-                               "`CIP_LK`,"
-                               "`LABEL`,"
-                               "`INTAKEFROM`,"
-                               "`INTAKETO`,"
-                               "`INTAKEFROMTO`,"
-                               "`INTAKESCHEME`,"
-                               "`INTAKESINTERVALOFTIME`,"
-                               "`INTAKESINTERVALSCHEME`,"
-                               "`DURATIONFROM`,"
-                               "`DURATIONTO`,"
-                               "`DURATIONFROMTO`,"
-                               "`DURATIONSCHEME`,"
-                               "`PERIOD`,"
-                               "`PERIODSCHEME`,"
-                               "`ADMINCHEME`,"
-                               "`DAILYSCHEME`,"
-                               "`MEALSCHEME`,"
-                               "`ISALD`,"
-                               "`TYPEOFTREATEMENT`,"
-                               "`MINAGE`,"
-                               "`MAXAGE`,"
-                               "`MINAGEREFERENCE`,"
-                               "`MAXAGEREFERENCE`,"
-                               "`MINWEIGHT`,"
-                               "`SEXLIMIT`,"
-                               "`MINCLEARANCE`,"
-                               "`MAXCLEARANCE`,"
-                               "`PREGNANCYLIMITS`,"
-                               "`BREASTFEEDINGLIMITS`,"
-                               "`PHYSIOLOGICALLIMITS`,"
-                               "`NOTE`,"
-                               "`CIM10_LK`,"
-                               "`CIM10_LIMITS_LK`,"
-                               "`EDRC_LK`,"
-                               "`EXTRAS`,"
-                               "`USERVALIDATOR`,"
-                               "`CREATIONDATE`,"
-                               "`MODIFICATIONDATE`,"
-                               "`TRANSMITTED`,"
-                               "`ORDER`");
-            req << QString("UPDATE `DOSAGE` SET `DRUGS_DATABASE_IDENTIFIANT`=\"%1\";").arg(DrugsDB::Constants::DB_DEFAULT_IDENTIFIANT);
+                    .arg("`POSO_ID`,"
+                         "`POSO_UUID`,"
+                         "`DRUGS_DATABASE_IDENTIFIANT`,"
+                         "`INN_LK`,"
+                         "`INN_DOSAGE`,"
+                         "`DRUG_UID_LK`,"
+                         "`CIP_LK`,"
+                         "`LABEL`,"
+                         "`INTAKEFROM`,"
+                         "`INTAKETO`,"
+                         "`INTAKEFROMTO`,"
+                         "`INTAKESCHEME`,"
+                         "`INTAKESINTERVALOFTIME`,"
+                         "`INTAKESINTERVALSCHEME`,"
+                         "`DURATIONFROM`,"
+                         "`DURATIONTO`,"
+                         "`DURATIONFROMTO`,"
+                         "`DURATIONSCHEME`,"
+                         "`PERIOD`,"
+                         "`PERIODSCHEME`,"
+                         "`ADMINCHEME`,"
+                         "`DAILYSCHEME`,"
+                         "`MEALSCHEME`,"
+                         "`ISALD`,"
+                         "`TYPEOFTREATEMENT`,"
+                         "`MINAGE`,"
+                         "`MAXAGE`,"
+                         "`MINAGEREFERENCE`,"
+                         "`MAXAGEREFERENCE`,"
+                         "`MINWEIGHT`,"
+                         "`SEXLIMIT`,"
+                         "`MINCLEARANCE`,"
+                         "`MAXCLEARANCE`,"
+                         "`PREGNANCYLIMITS`,"
+                         "`BREASTFEEDINGLIMITS`,"
+                         "`PHYSIOLOGICALLIMITS`,"
+                         "`NOTE`,"
+                         "`CIM10_LK`,"
+                         "`CIM10_LIMITS_LK`,"
+                         "`EDRC_LK`,"
+                         "`EXTRAS`,"
+                         "`USERVALIDATOR`,"
+                         "`CREATIONDATE`,"
+                         "`MODIFICATIONDATE`,"
+                         "`TRANSMITTED`,"
+                         "`ORDER`");
             req << "DROP TABLE `OLD_DOSAGE`;";
-            req << "﻿DELETE FROM `VERSION`;";
-            req << "INSERT INTO `VERSION` (`ACTUAL`) VALUES('0.4.0');";
-            foreach(const QString &r, req) {
-                QSqlQuery q(r,db);
-                if (q.isActive()) {
-                    q.finish();
-                } else {
-                    Utils::Log::addQueryError("VersionUpdater", q);
-                }
-            }
-            Utils::Log::addMessage("VersionUpdater",QString("Dosage Database SQL update done from %1 to %2").arg("0.2.0", "0.4.0"));
-            return true;
+        } else if (db.driverName()=="QMYSQL") {
+            req << "ALTER TABLE `DOSAGE` ADD `ROUTE` integer AFTER `INTAKESINTERVALSCHEME`;";
         }
+        req << "﻿DELETE FROM `VERSION`;";
+        req << "INSERT INTO `VERSION` (`ACTUAL`) VALUES('0.5.4');";
 
-        bool saveUpdatedValuesToDatabase() const {return true;}
+        foreach(const QString &r, req) {
+            QSqlQuery q(r,db);
+            if (q.isActive()) {
+                q.finish();
+            } else {
+                Utils::Log::addQueryError("VersionUpdater", q, __FILE__, __LINE__);
+            }
+        }
+        Utils::Log::addMessage("VersionUpdater", QString("Dosage Database SQL update done from %1 to %2").arg("0.4.0", "0.5.0"));
+        return true;
+    }
 
-    private:
-        QString m_Name;
-        mutable QMap<int, int> m_Id_DailySchemes;
-        mutable QMap<int, int> m_Id_MealSchemes;
-    };
+    bool saveUpdatedValuesToDatabase() const {return true;}
+
+private:
+    QString m_Name;
+};
+
+class Dosage_040_To_050 : public DrugsDB::DosageDatabaseUpdateStep
+{
+public:
+    // From v 0.4.0 To v 0.5.0
+    // - Renaming and redefining DRUG_UID_LK varchar(20) instead of CIS_LK integer
+    Dosage_040_To_050() : DrugsDB::DosageDatabaseUpdateStep() {}
+    ~Dosage_040_To_050() {}
+
+    QString userMessage() const
+    {
+        return QApplication::translate("DatabaseUpdater", "Your dosage database needs to be "
+                                       "updated from version 0.4.0 to version 0.5.0.\n"
+                                       "This will be automatically done.");
+    }
+
+    QString fromVersion() const { return "0.4.0"; }
+    QString toVersion() const { return "0.5.0"; }
+
+    void setConnectionName(const QString &name) { m_Name = name; }
+
+    bool retreiveValuesToUpdate() const  {return true;}
+
+    bool updateDatabaseScheme() const
+    {
+        // these versions only use SQLite
+        QSqlDatabase db = QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME);
+        if (!db.isOpen()) {
+            if (!db.open()) {
+                Utils::Log::addError("VersionUpdater", tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
+                                     .arg(db.connectionName()).arg(db.lastError().text()),
+                                     __FILE__, __LINE__);
+                return false;
+            }
+        }
+        QStringList req;
+        if (db.driverName() == "QSQLITE") {
+            req << "﻿ALTER TABLE `DOSAGE` RENAME TO `OLD_DOSAGE`;";
+            req << DrugsDB::Internal::DrugsBase::dosageCreateTableSqlQuery();
+            req << QString("INSERT INTO `DOSAGE` (%1, `DRUG_UID_LK`) SELECT %1, `CIS_LK` FROM `OLD_DOSAGE`;")
+                    .arg("`POSO_ID`,"
+                         "`POSO_UUID`,"
+                         "`DRUGS_DATABASE_IDENTIFIANT`,"
+                         "`INN_LK`,"
+                         "`INN_DOSAGE`,"
+                         "`CIP_LK`,"
+                         "`LABEL`,"
+                         "`INTAKEFROM`,"
+                         "`INTAKETO`,"
+                         "`INTAKEFROMTO`,"
+                         "`INTAKESCHEME`,"
+                         "`INTAKESINTERVALOFTIME`,"
+                         "`INTAKESINTERVALSCHEME`,"
+                         "`DURATIONFROM`,"
+                         "`DURATIONTO`,"
+                         "`DURATIONFROMTO`,"
+                         "`DURATIONSCHEME`,"
+                         "`PERIOD`,"
+                         "`PERIODSCHEME`,"
+                         "`ADMINCHEME`,"
+                         "`DAILYSCHEME`,"
+                         "`MEALSCHEME`,"
+                         "`ISALD`,"
+                         "`TYPEOFTREATEMENT`,"
+                         "`MINAGE`,"
+                         "`MAXAGE`,"
+                         "`MINAGEREFERENCE`,"
+                         "`MAXAGEREFERENCE`,"
+                         "`MINWEIGHT`,"
+                         "`SEXLIMIT`,"
+                         "`MINCLEARANCE`,"
+                         "`MAXCLEARANCE`,"
+                         "`PREGNANCYLIMITS`,"
+                         "`BREASTFEEDINGLIMITS`,"
+                         "`PHYSIOLOGICALLIMITS`,"
+                         "`NOTE`,"
+                         "`CIM10_LK`,"
+                         "`CIM10_LIMITS_LK`,"
+                         "`EDRC_LK`,"
+                         "`EXTRAS`,"
+                         "`USERVALIDATOR`,"
+                         "`CREATIONDATE`,"
+                         "`MODIFICATIONDATE`,"
+                         "`TRANSMITTED`,"
+                         "`ORDER`");
+            req << "DROP TABLE `OLD_DOSAGE`;";
+        } else if (db.driverName()=="QMYSQL") {
+            req << "ALTER TABLE `DOSAGE` ADD `DRUG_UID_LK` varchar(20) AFTER `INN_DOSAGE`;";
+            req << "ALTER TABLE `DOSAGE` DROP COLUMN `CIS_LK`;";
+        }
+        req << "﻿DELETE FROM `VERSION`;";
+        req << "INSERT INTO `VERSION` (`ACTUAL`) VALUES('0.5.0');";
+
+        foreach(const QString &r, req) {
+            QSqlQuery q(r,db);
+            if (q.isActive()) {
+                q.finish();
+            } else {
+                Utils::Log::addQueryError("VersionUpdater", q, __FILE__, __LINE__);
+            }
+        }
+        Utils::Log::addMessage("VersionUpdater", QString("Dosage Database SQL update done from %1 to %2").arg("0.4.0", "0.5.0"));
+        return true;
+    }
+
+    bool saveUpdatedValuesToDatabase() const {return true;}
+
+private:
+    QString m_Name;
+};
+
+class Dosage_030_To_040 : public DrugsDB::DosageDatabaseUpdateStep
+{
+public:
+    // From v 0.3.0 To v 0.4.0
+    // - Adding DRUGS_DATABASE_FILENAME
+    Dosage_030_To_040() : DrugsDB::DosageDatabaseUpdateStep() {}
+    ~Dosage_030_To_040() {}
+
+    QString userMessage() const
+    {
+        return QApplication::translate("DatabaseUpdater", "Your dosage database needs to be "
+                                       "updated from version 0.2.0 to version 0.4.0.\n"
+                                       "This will be automatically done.");
+    }
+
+    QString fromVersion() const { return "0.2.0"; }
+    QString toVersion() const { return "0.4.0"; }
+
+    void setConnectionName(const QString &name) { m_Name = name; }
+
+    bool retreiveValuesToUpdate() const  {return true;}
+
+    bool updateDatabaseScheme() const
+    {
+        // these versions only use SQLite
+        QSqlDatabase db = QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME);
+        if (!db.open()) {
+            return false;
+        }
+        QStringList req;
+        req << "﻿ALTER TABLE `DOSAGE` RENAME TO `OLD_DOSAGE`;";
+        req << DrugsDB::Internal::DrugsBase::dosageCreateTableSqlQuery();
+        req << QString("INSERT INTO `DOSAGE` (%1) SELECT %1 FROM `OLD_DOSAGE`;")
+                .arg("`POSO_ID`,"
+                     "`POSO_UUID`,"
+                     // "`DRUGS_DATABASE_IDENTIFIANT`,"
+                     "`INN_LK`,"
+                     "`INN_DOSAGE`,"
+                     "`CIS_LK`,"
+                     "`CIP_LK`,"
+                     "`LABEL`,"
+                     "`INTAKEFROM`,"
+                     "`INTAKETO`,"
+                     "`INTAKEFROMTO`,"
+                     "`INTAKESCHEME`,"
+                     "`INTAKESINTERVALOFTIME`,"
+                     "`INTAKESINTERVALSCHEME`,"
+                     "`DURATIONFROM`,"
+                     "`DURATIONTO`,"
+                     "`DURATIONFROMTO`,"
+                     "`DURATIONSCHEME`,"
+                     "`PERIOD`,"
+                     "`PERIODSCHEME`,"
+                     "`ADMINCHEME`,"
+                     "`DAILYSCHEME`,"
+                     "`MEALSCHEME`,"
+                     "`ISALD`,"
+                     "`TYPEOFTREATEMENT`,"
+                     "`MINAGE`,"
+                     "`MAXAGE`,"
+                     "`MINAGEREFERENCE`,"
+                     "`MAXAGEREFERENCE`,"
+                     "`MINWEIGHT`,"
+                     "`SEXLIMIT`,"
+                     "`MINCLEARANCE`,"
+                     "`MAXCLEARANCE`,"
+                     "`PREGNANCYLIMITS`,"
+                     "`BREASTFEEDINGLIMITS`,"
+                     "`PHYSIOLOGICALLIMITS`,"
+                     "`NOTE`,"
+                     "`CIM10_LK`,"
+                     "`CIM10_LIMITS_LK`,"
+                     "`EDRC_LK`,"
+                     "`EXTRAS`,"
+                     "`USERVALIDATOR`,"
+                     "`CREATIONDATE`,"
+                     "`MODIFICATIONDATE`,"
+                     "`TRANSMITTED`,"
+                     "`ORDER`");
+        req << QString("UPDATE `DOSAGE` SET `DRUGS_DATABASE_IDENTIFIANT`=\"%1\";").arg(DrugsDB::Constants::DB_DEFAULT_IDENTIFIANT);
+        req << "DROP TABLE `OLD_DOSAGE`;";
+        req << "﻿DELETE FROM `VERSION`;";
+        req << "INSERT INTO `VERSION` (`ACTUAL`) VALUES('0.4.0');";
+        foreach(const QString &r, req) {
+            QSqlQuery q(r,db);
+            if (q.isActive()) {
+                q.finish();
+            } else {
+                Utils::Log::addQueryError("VersionUpdater", q, __FILE__, __LINE__);
+            }
+        }
+        Utils::Log::addMessage("VersionUpdater",QString("Dosage Database SQL update done from %1 to %2").arg("0.2.0", "0.4.0"));
+        return true;
+    }
+
+    bool saveUpdatedValuesToDatabase() const {return true;}
+
+private:
+    QString m_Name;
+    mutable QMap<int, int> m_Id_DailySchemes;
+    mutable QMap<int, int> m_Id_MealSchemes;
+};
 
 class Dosage_008_To_020 : public DrugsDB::DosageDatabaseUpdateStep
 {
@@ -175,7 +415,8 @@ public:
         QSqlDatabase db = QSqlDatabase::database(m_Name);
         if (!db.open()) {
             Utils::warningMessageBox(tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2).arg(m_Name, db.lastError().text()),"","","");
-            Utils::Log::addError("DatabaseUpdater", tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2).arg(m_Name, db.lastError().text()));
+            Utils::Log::addError("DatabaseUpdater", tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2).arg(m_Name, db.lastError().text()),
+                                 __FILE__, __LINE__);
             return false;
         }
         QString req = "SELECT `POSO_ID`, `DAILYSCHEME` FROM `DOSAGE` WHERE (`DAILYSCHEME`>0) ORDER BY `POSO_ID` ASC;";
@@ -185,7 +426,7 @@ public:
                 m_Id_DailySchemes.insert(q.value(0).toInt(), q.value(1).toInt());
             }
         } else {
-            Utils::Log::addQueryError("DatabaseUpdater", q);
+            Utils::Log::addQueryError("DatabaseUpdater", q, __FILE__, __LINE__);
             return false;
         }
         q.finish();
@@ -196,7 +437,7 @@ public:
                 m_Id_MealSchemes.insert(q.value(0).toInt(), q.value(1).toInt());
             }
         } else {
-            Utils::Log::addQueryError("DatabaseUpdater", q);
+            Utils::Log::addQueryError("DatabaseUpdater", q, __FILE__, __LINE__);
             return false;
         }
         return true;
@@ -266,7 +507,7 @@ public:
             if (q.isActive()) {
                 q.finish();
             } else {
-                Utils::Log::addQueryError("VersionUpdater", q);
+                Utils::Log::addQueryError("VersionUpdater", q, __FILE__, __LINE__);
             }
         }
         Utils::Log::addMessage("VersionUpdater",QString("Dosage Database SQL update done from %1 to %2").arg("0.0.8", "0.2.0"));
@@ -312,7 +553,7 @@ public:
             if (q.isActive()) {
                 q.finish();
             } else {
-                Utils::Log::addQueryError("DatabaseUpdater", q);
+                Utils::Log::addQueryError("DatabaseUpdater", q, __FILE__, __LINE__);
             }
             req.clear();
         }
@@ -323,7 +564,7 @@ public:
             if (q.isActive()) {
                 q.finish();
             } else {
-                Utils::Log::addQueryError("DatabaseUpdater", q);
+                Utils::Log::addQueryError("DatabaseUpdater", q, __FILE__, __LINE__);
             }
             req.clear();
         }
@@ -340,6 +581,7 @@ private:
 class IO_Update_From_0008_To_020 : public DrugsDB::DrugsIOUpdateStep
 {
 public:
+    // Adding root FreeDiams tag
     // Unfortunatly DailyScheme was not saved before 0.2.0 --> so no update is available
     // MealTime scheme must be update since an empty choice has been added at index (0)
     IO_Update_From_0008_To_020() : DrugsDB::DrugsIOUpdateStep() {}
@@ -348,8 +590,14 @@ public:
     QString fromVersion() const {return "0.0.8";}
     QString toVersion() const {return "0.2.0";}
 
-    bool updateFromXml() const {return false;}
-    bool executeXmlUpdate(QString &xml) const {Q_UNUSED(xml); return true;}
+    bool updateFromXml() const {return true;}
+    bool executeXmlUpdate(QString &xml) const
+    {
+        int begin = xml.indexOf("<FullPrescription");
+        xml.insert(begin, "<FreeDiams>");
+        xml.append("</FreeDiams>");
+        return true;
+    }
 
     bool updateFromModel() const {return true;}
     bool executeUpdate(DrugsDB::DrugsModel *model, QList<int> rows) const
@@ -380,6 +628,13 @@ public:
     bool updateFromXml() const {return true;}
     bool executeXmlUpdate(QString &xml) const
     {
+        // add root tag <FreeDiams> ?
+        if (!xml.contains("<FreeDiams>", Qt::CaseInsensitive)) {
+            int begin = xml.indexOf("<?xml");
+            begin = xml.indexOf(">", begin) + 1;
+            xml.insert(begin, "<FreeDiams>");
+            xml.append("</FreeDiams>");
+        }
         // Rename some tags
         xml.replace("<CIS>","<Drug_UID>");
         xml.replace("</CIS>", "</Drug_UID>");
@@ -409,6 +664,38 @@ public:
     }
 };
 
+class IO_Update_From_040_To_050 : public DrugsDB::DrugsIOUpdateStep
+{
+public:
+    // Add missing main root tag
+    IO_Update_From_040_To_050() : DrugsDB::DrugsIOUpdateStep() {}
+    ~IO_Update_From_040_To_050() {}
+
+    QString fromVersion() const {return "0.4.0";}
+    QString toVersion() const {return "0.5.0";}
+
+    bool updateFromXml() const {return true;}
+    bool executeXmlUpdate(QString &xml) const
+    {
+        // add root tag <FreeDiams> ?
+        if (!xml.contains("<FreeDiams>", Qt::CaseInsensitive)) {
+            int begin = xml.indexOf("<?xml");
+            begin = xml.indexOf(">", begin) + 1;
+            xml.insert(begin, "<FreeDiams>");
+            xml.append("</FreeDiams>");
+        }
+        return true;
+    }
+
+    bool updateFromModel() const {return false;}
+    bool executeUpdate(DrugsDB::DrugsModel *model, QList<int> rows) const
+    {
+        Q_UNUSED(model);
+        Q_UNUSED(rows);
+        return true;
+    }
+};
+
 }  // End anonymous namespace
 
 namespace DrugsDB {
@@ -423,13 +710,15 @@ public:
         qDeleteAll(m_Updaters);
     }
 
-    static QStringList dosageDatabaseVersions() { return QStringList() << "0.0.8" << "0.2.0" << "0.4.0"; }
-    static QStringList xmlIoVersions() {return QStringList() << "0.0.8" << "0.2.0" << "0.4.0"; }
+    static QStringList dosageDatabaseVersions() { return QStringList() << "0.0.8" << "0.2.0" << "0.4.0" << "0.5.0" << "0.5.4"; }
+    static QStringList xmlIoVersions() {return QStringList() << "0.0.8" << "0.2.0" << "0.4.0" << "0.5.0"; }
 
     QString xmlVersion(const QString &xml)
     {
+        /** \todo read with QDomDoc */
         QString v;
-        if (xml.startsWith("<?xml version=\"1.0\"")) {
+        if (xml.startsWith("<?xml version=\"1.0\"") ||
+            xml.startsWith("<?xml version='1.0'")) {
             int begin = xml.indexOf("<FullPrescription version=\"") + 27;
             int end = xml.indexOf("\">", begin);
             v = xml.mid(begin,end-begin).simplified();
@@ -483,8 +772,12 @@ VersionUpdater::VersionUpdater() : d(0)
     // Here is the good place to create updaters objects
     d->m_Updaters.append(new ::Dosage_008_To_020);
     d->m_Updaters.append(new ::Dosage_030_To_040);
+    d->m_Updaters.append(new ::Dosage_040_To_050);
+    d->m_Updaters.append(new ::Dosage_050_To_054);
+
     d->m_Updaters.append(new ::IO_Update_From_0008_To_020);
     d->m_Updaters.append(new ::IO_Update_From_020_To_040);
+    d->m_Updaters.append(new ::IO_Update_From_040_To_050);
 }
 
 VersionUpdater::~VersionUpdater()
@@ -497,13 +790,14 @@ VersionUpdater::~VersionUpdater()
 
 bool VersionUpdater::isDosageDatabaseUpToDate() const
 {
-    if (!d->m_DosageDatabaseVersion.isEmpty())
-        return (d->m_DosageDatabaseVersion==d->dosageDatabaseVersions().last());
+//    if (!d->m_DosageDatabaseVersion.isEmpty())
+//        return (d->m_DosageDatabaseVersion==d->dosageDatabaseVersions().last());
 
     QSqlDatabase db = QSqlDatabase::database(Dosages::Constants::DB_DOSAGES_NAME);
     if (!db.open()) {
         Utils::warningMessageBox(tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2).arg(Dosages::Constants::DB_DOSAGES_NAME, db.lastError().text()),"","","");
-        Utils::Log::addError("VersionUpdater",tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2).arg(Dosages::Constants::DB_DOSAGES_NAME, db.lastError().text()));
+        Utils::Log::addError("VersionUpdater",tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2).arg(Dosages::Constants::DB_DOSAGES_NAME, db.lastError().text()),
+                             __FILE__, __LINE__);
         return true;
     }
     QString req = "﻿SELECT `ACTUAL` FROM `VERSION` ORDER BY `ACTUAL` LIMIT 1;";
@@ -513,7 +807,7 @@ bool VersionUpdater::isDosageDatabaseUpToDate() const
             d->m_DosageDatabaseVersion = q.value(0).toString();
         }
     } else {
-        Utils::Log::addQueryError("VersionUpdater", q);
+        Utils::Log::addQueryError("VersionUpdater", q, __FILE__, __LINE__);
         return true;
     }
     q.finish();
@@ -531,17 +825,20 @@ bool VersionUpdater::updateDosageDatabase()
         step->setConnectionName(Dosages::Constants::DB_DOSAGES_NAME);
         if (!step->retreiveValuesToUpdate()) {
             Utils::Log::addError("VersionUpdater", QString("Error while updating %1 from %2 to %3 : %4")
-                                 .arg(Dosages::Constants::DB_DOSAGES_NAME, step->fromVersion(), step->toVersion()));
+                                 .arg(Dosages::Constants::DB_DOSAGES_NAME, step->fromVersion(), step->toVersion()),
+                                 __FILE__, __LINE__);
             return false;
         }
         if (!step->updateDatabaseScheme()) {
             Utils::Log::addError("VersionUpdater", QString("Error while updating %1 from %2 to %3 : %4")
-                                 .arg(Dosages::Constants::DB_DOSAGES_NAME, step->fromVersion(), step->toVersion()));
+                                 .arg(Dosages::Constants::DB_DOSAGES_NAME, step->fromVersion(), step->toVersion()),
+                                 __FILE__, __LINE__);
             return false;
         }
         if (!step->saveUpdatedValuesToDatabase()) {
             Utils::Log::addError("VersionUpdater", QString("Error while updating %1 from %2 to %3 : %4")
-                                 .arg(Dosages::Constants::DB_DOSAGES_NAME, step->fromVersion(), step->toVersion()));
+                                 .arg(Dosages::Constants::DB_DOSAGES_NAME, step->fromVersion(), step->toVersion()),
+                                 __FILE__, __LINE__);
             return false;
         }
         version = step->toVersion();
@@ -583,10 +880,12 @@ QString VersionUpdater::updateXmlIOContent(const QString &xmlContent)
             break;
         if (step->updateFromXml()) {
             if (step->fromVersion() == version) {
-                if (!step->executeXmlUpdate(xml))
-                    Utils::Log::addError("VersionUpdater", QString("Error when updating from %1 to %2").arg(version).arg(step->toVersion()));
-                else
+                if (!step->executeXmlUpdate(xml)) {
+                    Utils::Log::addError("VersionUpdater", QString("Error when updating from %1 to %2").arg(version).arg(step->toVersion()),
+                                         __FILE__, __LINE__);
+                } else {
                     version = step->toVersion();
+                }
             }
         } else {
             version = step->toVersion();
@@ -607,7 +906,8 @@ bool VersionUpdater::updateXmlIOModel(const QString &fromVersion, DrugsDB::Drugs
         if (step->updateFromModel()) {
             if (step->fromVersion() == version) {
                 if (!step->executeUpdate(model, rowsToUpdate))
-                    Utils::Log::addError("VersionUpdater", QString("Error when updating from %1 to %2").arg(version).arg(step->toVersion()));
+                    Utils::Log::addError("VersionUpdater", QString("Error when updating from %1 to %2").arg(version).arg(step->toVersion()),
+                                         __FILE__, __LINE__);
                 else
                     version = step->toVersion();
             }
