@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -40,7 +26,7 @@
  ***************************************************************************/
 
 /**
-  \class DosageViewer
+  \class DrugsWidget::DosageViewer
   \brief QWidget for dosage creation / edition / modification. A dosage is a standard set of datas that will be used to help
   doctors when prescribing a drug.
   If you want to create a new dosage, you must create a new row onto the model BEFORE.\n
@@ -53,6 +39,7 @@
 
 #include "mfDosageViewer.h"
 
+#include <drugsbaseplugin/drugsbase.h>
 #include <drugsbaseplugin/drugsdata.h>
 #include <drugsbaseplugin/dosagemodel.h>
 #include <drugsbaseplugin/drugsmodel.h>
@@ -83,8 +70,13 @@
 
 using namespace DrugsWidget::Constants;
 using namespace DrugsWidget::Internal;
+using namespace Trans::ConstantTranslations;
 
 inline static DrugsDB::DrugsModel *drugModel() { return DrugsWidget::DrugsWidgetManager::instance()->currentDrugsModel(); }
+inline static Core::ITheme *theme() {return Core::ICore::instance()->theme();}
+static inline Core::ISettings *settings() {return Core::ICore::instance()->settings();}
+static inline DrugsDB::Internal::DrugsBase *drugsBase() {return DrugsDB::Internal::DrugsBase::instance();}
+
 
 namespace DrugsWidget {
 namespace Internal {
@@ -97,7 +89,7 @@ class DosageViewerPrivate
 {
 public:
     DosageViewerPrivate(DosageViewer *parent) :
-            m_Mapper(0), m_DosageModel(0), m_CIS(-1), m_SpinDelegate(0), q(parent) {}
+            m_Mapper(0), m_DosageModel(0), m_SpinDelegate(0), q(parent) {}
 
     void setCheckBoxStateToModel(const int index, const int qtCheckState)
     {
@@ -106,7 +98,7 @@ public:
 //            qWarning() << "dosage" << Dosages::Constants::IntakesUsesFromTo << m_Mapper->currentIndex() <<  m_DosageModel->data(m_DosageModel->index(m_Mapper->currentIndex(), index));
         } else {
 //            qWarning() << "drug";
-            drugModel()->setDrugData(m_CIS, index, qtCheckState==Qt::Checked);
+            drugModel()->setDrugData(m_DrugUid, index, qtCheckState==Qt::Checked);
         }
     }
 
@@ -119,9 +111,14 @@ public:
             m_Mapper = new QDataWidgetMapper(q);
             m_Mapper->setModel(drugModel());
             m_Mapper->setSubmitPolicy(QDataWidgetMapper::AutoSubmit);
+
             m_Mapper->addMapping(q->intakesFromSpin, Prescription::IntakesFrom, "value");
             m_Mapper->addMapping(q->intakesToSpin, Prescription::IntakesTo, "value");
             m_Mapper->addMapping(q->intakesCombo, Prescription::IntakesScheme, "currentText");
+
+            if (drugsBase()->isRoutesAvailable())
+                m_Mapper->addMapping(q->routeCombo, Prescription::Route, "currentText");
+
             m_Mapper->addMapping(q->periodSchemeCombo, Prescription::PeriodScheme, "currentText");
             m_Mapper->addMapping(q->periodSpin, Prescription::Period, "value");
 
@@ -133,6 +130,7 @@ public:
             m_Mapper->addMapping(q->intervalTimeSchemeCombo, Prescription::IntakesIntervalScheme, "currentIndex");
             m_Mapper->addMapping(q->mealTimeCombo, Prescription::MealTimeSchemeIndex, "currentIndex");
             m_Mapper->addMapping(q->noteTextEdit, Prescription::Note, "plainText");
+
             q->tabWidget->removeTab(6);
             q->tabWidget->removeTab(4);
             q->tabWidget->removeTab(3);
@@ -159,6 +157,8 @@ public:
             m_Mapper->addMapping(q->intakesCombo, Dosages::Constants::IntakesScheme, "currentText");
             m_Mapper->addMapping(q->periodSchemeCombo, Dosages::Constants::PeriodScheme, "currentText");
             m_Mapper->addMapping(q->periodSpin, Dosages::Constants::Period, "value");
+            if (drugsBase()->isRoutesAvailable())
+                m_Mapper->addMapping(q->routeCombo, Dosages::Constants::Route, "currentText");
 
             m_Mapper->addMapping(q->durationFromSpin, Dosages::Constants::DurationFrom);
             m_Mapper->addMapping(q->durationToSpin, Dosages::Constants::DurationTo);
@@ -231,14 +231,14 @@ public:
 
             // Intakes
             q->intakesCombo->setCurrentIndex(-1);
-            q->intakesCombo->setEditText(drugModel()->drugData(m_CIS, Prescription::IntakesScheme).toString());
+            q->intakesCombo->setEditText(drugModel()->drugData(m_DrugUid, Prescription::IntakesScheme).toString());
             // Period
-            q->periodSpin->setValue(drugModel()->drugData(m_CIS, Prescription::Period).toDouble());
-            q->periodSchemeCombo->setEditText(drugModel()->drugData(m_CIS, Prescription::PeriodScheme).toString());
+            q->periodSpin->setValue(drugModel()->drugData(m_DrugUid, Prescription::Period).toDouble());
+            q->periodSchemeCombo->setEditText(drugModel()->drugData(m_DrugUid, Prescription::PeriodScheme).toString());
             // Duration
-            q->durationCombo->setEditText(drugModel()->drugData(m_CIS, Prescription::DurationScheme).toString());
+            q->durationCombo->setEditText(drugModel()->drugData(m_DrugUid, Prescription::DurationScheme).toString());
             // Interval
-            q->minIntervalIntakesSpin->setValue(drugModel()->drugData(m_CIS, Prescription::IntakesIntervalOfTime).toDouble());
+            q->minIntervalIntakesSpin->setValue(drugModel()->drugData(m_DrugUid, Prescription::IntakesIntervalOfTime).toDouble());
 
             bool intakeRange = drugModel()->index(row, Prescription::IntakesUsesFromTo).data().toBool();
             q->fromToIntakesCheck->setChecked(intakeRange);
@@ -250,20 +250,20 @@ public:
             q->durationToLabel->setVisible(durationRange);
             q->durationToSpin->setVisible(durationRange);
 
-            q->aldCheck->setChecked(drugModel()->drugData(m_CIS, Prescription::IsALD).toBool());
+            q->aldCheck->setChecked(drugModel()->drugData(m_DrugUid, Prescription::IsALD).toBool());
             // populate DailSchemeModel
             DrugsDB::DailySchemeModel *daily = q->dailyScheme->model();
             Q_ASSERT(daily);
-            daily->setSerializedContent(drugModel()->drugData(m_CIS, Prescription::DailyScheme).toString());
+            daily->setSerializedContent(drugModel()->drugData(m_DrugUid, Prescription::DailyScheme).toString());
 //            q->dailySchemeView->resizeColumnsToContents();
         }
 
         // Link to French RCP
-        if (!drugModel()->drugData(m_CIS, DrugsDB::Constants::Drug::LinkToSCP).isNull()) {
-            q->frenchRCPButton->setEnabled(true);
-            q->frenchRCPButton->setToolTip(drugModel()->drugData(m_CIS, DrugsDB::Constants::Drug::LinkToSCP).toString());
+        if (!drugModel()->drugData(m_DrugUid, DrugsDB::Constants::Drug::LinkToSCP).isNull()) {
+            q->monographButton->setEnabled(true);
+            q->monographButton->setToolTip(drugModel()->drugData(m_DrugUid, DrugsDB::Constants::Drug::LinkToSCP).toString());
         } else {
-            q->frenchRCPButton->setEnabled(false);
+            q->monographButton->setEnabled(false);
         }
     }
 
@@ -281,11 +281,11 @@ public:
     void fillDrugsData()
     {
         Q_ASSERT(q);
-        q->labelOfDosageLabel->setToolTip(drugModel()->drugData(m_CIS, DrugsDB::Constants::Drug::AvailableDosages).toString());
-        q->drugNameLabel->setText(drugModel()->drugData(m_CIS, DrugsDB::Constants::Drug::Denomination).toString());
-        q->drugNameLabel->setToolTip(drugModel()->drugData(m_CIS, DrugsDB::Constants::Drug::CompositionString).toString());
-        q->interactionLabel->setPixmap(drugModel()->drugData(m_CIS, DrugsDB::Constants::Interaction::Icon).value<QIcon>().pixmap(16,16));
-        q->interactionLabel->setToolTip(drugModel()->drugData(m_CIS, DrugsDB::Constants::Interaction::ToolTip).toString());
+        q->labelOfDosageLabel->setToolTip(drugModel()->drugData(m_DrugUid, DrugsDB::Constants::Drug::AvailableDosages).toString());
+        q->drugNameLabel->setText(drugModel()->drugData(m_DrugUid, DrugsDB::Constants::Drug::Denomination).toString());
+        q->drugNameLabel->setToolTip(drugModel()->drugData(m_DrugUid, DrugsDB::Constants::Drug::CompositionString).toString());
+        q->interactionLabel->setPixmap(drugModel()->drugData(m_DrugUid, DrugsDB::Constants::Interaction::Icon).value<QIcon>().pixmap(16,16));
+        q->interactionLabel->setToolTip(drugModel()->drugData(m_DrugUid, DrugsDB::Constants::Interaction::ToolTip).toString());
     }
 
     /**
@@ -301,18 +301,36 @@ public:
         q->intakesToSpin->hide();
         q->durationToLabel->hide();
         q->durationToSpin->hide();
+
         // Prepare some combos
         q->durationCombo->clear();
         q->durationCombo->addItems(Trans::ConstantTranslations::periods());
         q->durationCombo->setCurrentIndex(Trans::Constants::Time::Months);
+
         q->periodSchemeCombo->clear();
         q->periodSchemeCombo->addItems(Trans::ConstantTranslations::periods());
         q->periodSchemeCombo->setCurrentIndex(Trans::Constants::Time::Days);
+
         q->intervalTimeSchemeCombo->clear();
         q->intervalTimeSchemeCombo->addItems(Trans::ConstantTranslations::periods());
         q->intervalTimeSchemeCombo->setCurrentIndex(Trans::Constants::Time::Days);
-        q->intakesCombo->addItems(drugModel()->drugData(m_CIS, Drug::AvailableForms).toStringList());
+
+        q->routeCombo->clear();
+        if (drugsBase()->isRoutesAvailable()) {
+            q->routeCombo->addItems(drugModel()->drugData(m_DrugUid, Drug::AvailableRoutes).toStringList());
+            q->routeCombo->setCurrentIndex(0);
+        }
+
+        q->intakesCombo->fancyClear();
+        q->intakesCombo->fancyAddItems(drugModel()->drugData(m_DrugUid, Drug::AvailableForms).toStringList(), "Model");
+        q->intakesCombo->fancyAddItems(settings()->value(Constants::S_USERRECORDEDFORMS).toStringList(), Constants::USERRECORDEDFORMS_COLOR);
         q->intakesCombo->setCurrentIndex(0);
+
+//        q->intakesCombo->clear();
+//        q->intakesCombo->addItems(drugModel()->drugData(m_DrugUid, Drug::AvailableForms).toStringList());
+//        q->intakesCombo->addItems(settings()->value(Constants::S_USERRECORDEDFORMS).toStringList());
+//        q->intakesCombo->setCurrentIndex(0);
+
         q->mealTimeCombo->clear();
         q->mealTimeCombo->addItems(Trans::ConstantTranslations::mealTime());
 
@@ -324,7 +342,7 @@ public:
         q->hourlyTableWidget->verticalHeader()->hide();
         q->hourlyTableWidget->horizontalHeader()->hide();
         q->hourlyTableWidget->resizeColumnsToContents();
-        bool isScored = drugModel()->drugData(m_CIS, Drug::IsScoredTablet).toBool();
+        bool isScored = drugModel()->drugData(m_DrugUid, Drug::IsScoredTablet).toBool();
         if (isScored) {
             q->intakesToSpin->setDecimals(2);
             q->intakesFromSpin->setDecimals(2);
@@ -358,19 +376,6 @@ public:
             q->dosageForAllInnCheck->setVisible(dosageCanLinkWithInn());
     }
 
-//    void setDailyMaximum(double max)
-//    {
-//        DrugsDB::DailySchemeModel *daily = static_cast<DrugsDB::DailySchemeModel*>(q->dailySchemeView->model());
-//        DrugsDB::DailySchemeModel *daily = q->dailyScheme->model();
-//        Q_ASSERT(daily);
-//        if (daily) {
-//            daily->setMaximumDay(max);
-//        }
-//        if (m_SpinDelegate) {
-//            m_SpinDelegate->setMaximum(max-daily->sum());
-//        }
-//    }
-
     void recalculateDailySchemeMaximum()
     {
         if (!q->fromToIntakesCheck->isChecked()) {
@@ -383,8 +388,8 @@ public:
     bool dosageCanLinkWithInn()
     {
         if (m_DosageModel) {
-            return ((drugModel()->drugData(m_CIS, DrugsDB::Constants::Drug::MainInnCode).toInt()!=-1) &&
-                    (drugModel()->drugData(m_CIS, DrugsDB::Constants::Drug::AllInnsKnown).toBool()));
+            return ((drugModel()->drugData(m_DrugUid, DrugsDB::Constants::Drug::MainInnCode).toInt()!=-1) &&
+                    (drugModel()->drugData(m_DrugUid, DrugsDB::Constants::Drug::AllInnsKnown).toBool()));
         }
         return false;
     }
@@ -392,9 +397,10 @@ public:
 public:
     QDataWidgetMapper  *m_Mapper;
     DrugsDB::Internal::DosageModel *m_DosageModel;
-    QString             m_ActualDosageUuid;
-    int                 m_CIS;
+    QString m_ActualDosageUuid;
+    QVariant m_DrugUid;
     Utils::SpinBoxDelegate *m_SpinDelegate;
+
 private:
     DosageViewer *q;
 };
@@ -418,7 +424,10 @@ DosageViewer::DosageViewer(QWidget *parent)
     // Ui initialization
     setupUi(this);
     setWindowTitle(tr("Drug Dosage Creator") + " - " + qApp->applicationName());
-    userformsButton->setIcon(Core::ICore::instance()->theme()->icon(Core::Constants::ICONEDIT));
+    userformsButton->setIcon(theme()->icon(Core::Constants::ICONEDIT));
+    intakesCombo->setRemoveLightIcon(theme()->icon(Core::Constants::ICONCLOSELIGHT));
+    intakesCombo->setMoveUpLightIcon(theme()->icon(Core::Constants::ICONMOVEUPLIGHT));
+    intakesCombo->setMoveDownLightIcon(theme()->icon(Core::Constants::ICONMOVEDOWNLIGHT));
     // remove last page of tabWidget (TODO page)
     tabWidget->removeTab(tabWidget->count()-1);
 
@@ -431,13 +440,19 @@ DosageViewer::DosageViewer(QWidget *parent)
     // show first page of the tabwidget   ;;   Hide unused tables
     tabWidget->setCurrentIndex(0);
     this->hourlyTableWidget->hide();
+
+    // manage routes ?
+    if (!drugsBase()->isRoutesAvailable()) {
+        routeCombo->hide();
+        routeLabel->hide();
+    }
 }
 
 /** \brief Use this function to define a drugsModel behavior. */
-void DosageViewer::useDrugsModel(const int CIS, const int drugRow)
+void DosageViewer::useDrugsModel(const QVariant &drugUid, const int drugRow)
 {
-    Q_ASSERT(drugModel()->containsDrug(CIS));
-    d->m_CIS = CIS;
+    Q_ASSERT(drugModel()->containsDrug(drugUid));
+    d->m_DrugUid = drugUid;
     d->m_DosageModel = 0;
     d->resetUiToDefaults();
     d->fillDrugsData();
@@ -450,7 +465,7 @@ void DosageViewer::setDosageModel(DrugsDB::Internal::DosageModel *model)
 {
     Q_ASSERT(model);
     d->m_DosageModel = model;
-    d->m_CIS = model->drugUID();
+    d->m_DrugUid = model->drugUID();
     d->resetUiToDefaults();
     d->fillDrugsData();
     d->createDosageMapper();
@@ -461,6 +476,9 @@ void DosageViewer::setDosageModel(DrugsDB::Internal::DosageModel *model)
     } else {
         changeCurrentRow(0);
     }
+
+    // Connect Widgets datas modifications to datasChanged signal
+    connect(d->m_DosageModel,SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SIGNAL(protocolDataschanged()));
 }
 
 /** \brief Destructor */
@@ -480,7 +498,7 @@ void DosageViewer::changeCurrentRow(const int dosageRow)
     d->m_Mapper->setCurrentIndex(dosageRow);
     d->changeNonMappedDataFromModelToUi(dosageRow);
     d->recalculateDailySchemeMaximum();
-    qWarning() << dosageRow << QString("%1 = %2,").arg(drugModel()->drugData(d->m_CIS,DrugsDB::Constants::Drug::MainInnName).toString().toUpper()).arg(d->m_CIS);
+    qWarning() << QString("MAIN INN %1 = UID %2").arg(drugModel()->drugData(d->m_DrugUid, DrugsDB::Constants::Drug::MainInnName).toString().toUpper()).arg(d->m_DrugUid.toString())<<__FILE__<<__LINE__;
 }
 
 /** \brief Only provided because of focus bug */
@@ -495,10 +513,12 @@ void DosageViewer::commitToModel()
         if (daily) {
             d->m_DosageModel->setData(d->m_DosageModel->index(d->m_Mapper->currentIndex(), Dosages::Constants::DailyScheme), daily->serializedContent());
         }
+//        d->m_DosageModel->setData(d->m_DosageModel->index(d->m_Mapper->currentIndex(), Dosages::Constants::Route), routeId);
     } else {
         if (daily) {
-            drugModel()->setDrugData(d->m_CIS, DrugsDB::Constants::Prescription::DailyScheme, daily->serializedContent());
+            drugModel()->setDrugData(d->m_DrugUid, DrugsDB::Constants::Prescription::DailyScheme, daily->serializedContent());
         }
+//        drugModel()->setDrugData(d->m_DrugUid, DrugsDB::Constants::Prescription::Route, routeId);
     }
 }
 
@@ -517,13 +537,15 @@ void DosageViewer::changeCurrentRow(const QModelIndex &current, const QModelInde
 void DosageViewer::done(int r)
 {
     if (r == QDialog::Accepted) {
-        // match the user's form for the settings
-        const QStringList &pre = DrugsDB::Internal::DosageModel::predeterminedForms();
-        const QStringList &av  = drugModel()->drugData(d->m_CIS, DrugsDB::Constants::Drug::AvailableForms).toStringList();
-        if ((pre.indexOf(intakesCombo->currentText()) == -1) &&
-            (av.indexOf(intakesCombo->currentText()) == -1)) {
-            Core::ICore::instance()->settings()->appendToValue(S_USERRECORDEDFORMS, intakesCombo->currentText());
-        }
+        // save user's intake forms
+        QStringList list = intakesCombo->fancyItems(Constants::USERRECORDEDFORMS_COLOR);
+        QStringList doNotInsert = intakesCombo->fancyItems("Model");
+        if (!doNotInsert.contains(intakesCombo->currentText()))
+            list.insert(0, intakesCombo->currentText());
+        list.removeDuplicates();
+        list.removeAll(tkTr(Trans::Constants::INTAKES));
+        settings()->setValue(S_USERRECORDEDFORMS, list);
+        settings()->sync();
     }
 }
 
@@ -574,10 +596,10 @@ void DosageViewer::on_durationFromSpin_valueChanged(double value)
 /** \brief Show a menu with the user recorded forms */
 void DosageViewer::on_userformsButton_clicked()
 {
-    if (Core::ICore::instance()->settings()->value(S_USERRECORDEDFORMS, QVariant()).isNull())
+    if (settings()->value(S_USERRECORDEDFORMS, QVariant()).isNull())
         return;
 
-    const QStringList &ulist = Core::ICore::instance()->settings()->value(S_USERRECORDEDFORMS).toStringList();
+    const QStringList &ulist = settings()->value(S_USERRECORDEDFORMS).toStringList();
     QList<QAction*> list;
     foreach(const QString &form, ulist) {
         if (!form.isEmpty())
@@ -590,13 +612,13 @@ void DosageViewer::on_userformsButton_clicked()
     if (!a)
         return;
     if (a == aclear) {
-        Core::ICore::instance()->settings()->setValue(S_USERRECORDEDFORMS, QString());
+        settings()->setValue(S_USERRECORDEDFORMS, QString());
     } else {
         intakesCombo->setEditText(a->text());
         if (d->m_DosageModel)
             d->m_DosageModel->setData(d->m_DosageModel->index(d->m_Mapper->currentIndex(),Dosages::Constants::IntakesScheme),a->text());
         else
-            drugModel()->setDrugData(d->m_CIS, DrugsDB::Constants::Prescription::IntakesScheme, a->text());
+            drugModel()->setDrugData(d->m_DrugUid, DrugsDB::Constants::Prescription::IntakesScheme, a->text());
     }
 }
 
@@ -607,25 +629,25 @@ void DosageViewer::on_dosageForAllInnCheck_stateChanged(int state)
         // INN Prescription ?
         int row = d->m_Mapper->currentIndex();
             if ((dosageForAllInnCheck->isEnabled()) && (state==Qt::Checked)) {
-//                qWarning() << "INN" << drugModel()->drugData(d->m_CIS, DrugsDB::Constants::Drug::MainInnCode);
-                d->m_DosageModel->setData(d->m_DosageModel->index(row, Dosages::Constants::CIS_LK), d->m_CIS);
+//                qWarning() << "INN" << drugModel()->drugData(d->m_DrugUid, DrugsDB::Constants::Drug::MainInnCode);
+                d->m_DosageModel->setData(d->m_DosageModel->index(row, Dosages::Constants::DrugUid_LK), d->m_DrugUid);
                 d->m_DosageModel->setData(d->m_DosageModel->index(row, Dosages::Constants::CIP_LK), -1);
                 d->m_DosageModel->setData(d->m_DosageModel->index(row, Dosages::Constants::INN_LK),
-                                           drugModel()->drugData(d->m_CIS, DrugsDB::Constants::Drug::MainInnCode));
+                                           drugModel()->drugData(d->m_DrugUid, DrugsDB::Constants::Drug::MainInnCode));
                 d->m_DosageModel->setData(d->m_DosageModel->index(row, Dosages::Constants::InnLinkedDosage),
-                                           drugModel()->drugData(d->m_CIS, DrugsDB::Constants::Drug::MainInnDosage));
+                                           drugModel()->drugData(d->m_DrugUid, DrugsDB::Constants::Drug::MainInnDosage));
             } else {
 //                qWarning() << "not INN";
-                d->m_DosageModel->setData(d->m_DosageModel->index(row, Dosages::Constants::CIS_LK), d->m_CIS);
+                d->m_DosageModel->setData(d->m_DosageModel->index(row, Dosages::Constants::DrugUid_LK), d->m_DrugUid);
                 d->m_DosageModel->setData(d->m_DosageModel->index(row, Dosages::Constants::CIP_LK), -1);
                 d->m_DosageModel->setData(d->m_DosageModel->index(row, Dosages::Constants::INN_LK), -1);
                 d->m_DosageModel->setData(d->m_DosageModel->index(row, Dosages::Constants::InnLinkedDosage), "");
             }
         innCompositionLabel->show();
         innCompositionLabel->setText(tr("Linking to : ")
-                                      + drugModel()->drugData(d->m_CIS, DrugsDB::Constants::Drug::MainInnName).toString() + " "
+                                      + drugModel()->drugData(d->m_DrugUid, DrugsDB::Constants::Drug::MainInnName).toString() + " "
 //                                      + tr("Dosage of molecule : ")
-                                      + drugModel()->drugData(d->m_CIS, DrugsDB::Constants::Drug::MainInnDosage).toString());
+                                      + drugModel()->drugData(d->m_DrugUid, DrugsDB::Constants::Drug::MainInnDosage).toString());
     } else
         innCompositionLabel->hide();
 }
@@ -638,9 +660,9 @@ void DosageViewer::on_aldCheck_stateChanged(int state)
         d->setCheckBoxStateToModel(DrugsDB::Constants::Prescription::IsALD, state);
 }
 
-void DosageViewer::on_frenchRCPButton_clicked()
+void DosageViewer::on_monographButton_clicked()
 {
-    QDesktopServices::openUrl(QUrl(drugModel()->drugData(d->m_CIS, DrugsDB::Constants::Drug::LinkToSCP).toString()));
+    QDesktopServices::openUrl(QUrl(drugModel()->drugData(d->m_DrugUid, DrugsDB::Constants::Drug::LinkToSCP).toString()));
 }
 
 void DosageViewer::on_tabWidget_currentChanged(int)
