@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -102,6 +88,14 @@ void DrugsViewOptionsPage::applyChanges()
 
 void DrugsViewOptionsPage::finish() { delete m_Widget; }
 
+QString DrugsViewOptionsPage::helpPage()
+{
+    QString l = QLocale().name().left(2);
+    if (l=="fr")
+        return Constants::H_PREFERENCES_VIEW_FR;
+    return Constants::H_PREFERENCES_VIEW_EN;
+}
+
 void DrugsViewOptionsPage::checkSettingsValidity()
 {
     QHash<QString, QVariant> defaultvalues;
@@ -115,6 +109,9 @@ void DrugsViewOptionsPage::checkSettingsValidity()
     defaultvalues.insert(DrugsDB::Constants::S_SHOWICONSINPRESCRIPTION,true);
     defaultvalues.insert(DrugsDB::Constants::S_MARKDRUGSWITHAVAILABLEDOSAGES,true);
     defaultvalues.insert(DrugsDB::Constants::S_AVAILABLEDOSAGESBACKGROUNGCOLOR, DrugsDB::Constants::S_DEF_AVAILABLEDOSAGESBACKGROUNGCOLOR);
+    defaultvalues.insert(S_DYNAMICALERTS, true);
+    defaultvalues.insert(S_DYNAMICALERTS_LEVEL, DrugsDB::Constants::Interaction::ContreIndication);
+    defaultvalues.insert(S_PATIENTNAMESORDER, 0);
 
     foreach(const QString &k, defaultvalues.keys()) {
         if (settings()->value(k) == QVariant())
@@ -162,6 +159,13 @@ void DrugsSelectorOptionsPage::applyChanges()
 }
 
 void DrugsSelectorOptionsPage::finish() { delete m_Widget; }
+QString DrugsSelectorOptionsPage::helpPage()
+{
+    QString l = QLocale().name().left(2);
+    if (l=="fr")
+        return Constants::H_PREFERENCES_SELECTOR_FR;
+    return Constants::H_PREFERENCES_SELECTOR_EN;
+}
 
 void DrugsSelectorOptionsPage::checkSettingsValidity()
 {
@@ -174,6 +178,7 @@ void DrugsSelectorOptionsPage::checkSettingsValidity()
     defaultvalues.insert(DrugsDB::Constants::S_MARKDRUGSWITHAVAILABLEDOSAGES,true);
     defaultvalues.insert(DrugsDB::Constants::S_AVAILABLEDOSAGESBACKGROUNGCOLOR, DrugsDB::Constants::S_DEF_AVAILABLEDOSAGESBACKGROUNGCOLOR);
     defaultvalues.insert(DrugsDB::Constants::S_ALLERGYBACKGROUNDCOLOR, "red");
+    defaultvalues.insert(DrugsDB::Constants::S_INTOLERANCEBACKGROUNDCOLOR, "yellow");
 
     foreach(const QString &k, defaultvalues.keys()) {
         if (settings()->value(k) == QVariant())
@@ -236,6 +241,19 @@ void DrugsPrintOptionsPage::checkSettingsValidity()
             settings()->setValue(k, defaultvalues.value(k));
     }
 
+    defaultvalues.clear();
+
+    if (Core::ICore::instance()->updatePreferences()) {
+        Utils::Log::addMessage(this, tr("Updating posologic sentence."));
+        defaultvalues.insert(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_HTML,
+                             QCoreApplication::translate(Constants::DRUGCONSTANTS_TR_CONTEXT, DrugsDB::Constants::S_DEF_PRESCRIPTIONFORMATTING));
+        defaultvalues.insert(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_PLAIN,
+                             QCoreApplication::translate(Constants::DRUGCONSTANTS_TR_CONTEXT, DrugsDB::Constants::S_DEF_PRESCRIPTIONFORMATTING_PLAIN));
+        foreach(const QString &k, defaultvalues.keys()) {
+            settings()->setValue(k, defaultvalues.value(k));
+        }
+    }
+
     QTextDocument t;
     t.setHtml(settings()->value(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_HTML).toString());
     if (settings()->value(DrugsDB::Constants::S_PRESCRIPTIONFORMATTING_PLAIN).isNull() ||
@@ -251,6 +269,13 @@ void DrugsPrintOptionsPage::checkSettingsValidity()
 }
 
 void DrugsPrintOptionsPage::finish() { delete m_Widget; }
+QString DrugsPrintOptionsPage::helpPage()
+{
+    QString l = QLocale().name().left(2);
+    if (l=="fr")
+        return Constants::H_PREFERENCES_PRINT_FR;
+    return Constants::H_PREFERENCES_PRINT_EN;
+}
 
 QWidget *DrugsPrintOptionsPage::createPage(QWidget *parent)
 {
@@ -308,6 +333,13 @@ void DrugsUserOptionsPage::checkSettingsValidity()
 }
 
 void DrugsUserOptionsPage::finish() { delete m_Widget; }
+QString DrugsUserOptionsPage::helpPage()
+{
+    QString l = QLocale().name().left(2);
+    if (l=="fr")
+        return Constants::H_PREFERENCES_USER_FR;
+    return Constants::H_PREFERENCES_USER_EN;
+}
 
 QWidget *DrugsUserOptionsPage::createPage(QWidget *parent)
 {
@@ -362,6 +394,13 @@ void DrugsExtraOptionsPage::checkSettingsValidity()
 }
 
 void DrugsExtraOptionsPage::finish() { delete m_Widget; }
+QString DrugsExtraOptionsPage::helpPage()
+{
+    QString l = QLocale().name().left(2);
+    if (l=="fr")
+        return Constants::H_PREFERENCES_EXTRA_FR;
+    return Constants::H_PREFERENCES_EXTRA_EN;
+}
 
 QWidget *DrugsExtraOptionsPage::createPage(QWidget *parent)
 {
@@ -379,6 +418,7 @@ DrugsViewWidget::DrugsViewWidget(QWidget *parent) :
 {
     setupUi(this);
     setDatasToUi();
+    testerBox->hide();
 }
 
 void DrugsViewWidget::setDatasToUi()
@@ -401,7 +441,17 @@ void DrugsViewWidget::setDatasToUi()
 
     viewFontCombo->setCurrentFont(s->value(S_VIEWFONT).toString());
     viewFontSizeSpin->setValue(s->value(S_VIEWFONTSIZE).toInt());
+    patientNameOrder->setCurrentIndex(s->value(S_PATIENTNAMESORDER, 0).toInt());
     showIconsCheck->setChecked(s->value(DrugsDB::Constants::S_SHOWICONSINPRESCRIPTION).toBool());
+
+    dynamicAlerts->setChecked(s->value(S_DYNAMICALERTS).toBool());
+    int level = s->value(S_DYNAMICALERTS_LEVEL).toInt();
+    switch (level)
+    {
+    case DrugsDB::Constants::Interaction::ContreIndication: dynamicAlertsLevel->setCurrentIndex(2); break;
+    case DrugsDB::Constants::Interaction::Deconseille: dynamicAlertsLevel->setCurrentIndex(1); break;
+    case 0: dynamicAlertsLevel->setCurrentIndex(0); break;
+    }
 }
 
 void DrugsViewWidget::saveToSettings(Core::ISettings *sets)
@@ -433,7 +483,16 @@ void DrugsViewWidget::saveToSettings(Core::ISettings *sets)
     if (DrugsWidget::DrugsWidgetManager::instance()->currentView())
         DrugsWidget::DrugsWidgetManager::instance()->currentView()->changeFontTo(font);
 
+    s->setValue(S_PATIENTNAMESORDER, patientNameOrder->currentIndex());
     s->setValue(DrugsDB::Constants::S_SHOWICONSINPRESCRIPTION, showIconsCheck->isChecked());
+
+    s->setValue(S_DYNAMICALERTS, dynamicAlerts->isChecked());
+    switch (dynamicAlertsLevel->currentIndex())
+    {
+    case 2: s->setValue(S_DYNAMICALERTS_LEVEL, DrugsDB::Constants::Interaction::ContreIndication); break;
+    case 1: s->setValue(S_DYNAMICALERTS_LEVEL, DrugsDB::Constants::Interaction::Deconseille); break;
+    case 0: s->setValue(S_DYNAMICALERTS_LEVEL, 0); break;
+    }
 }
 
 void DrugsViewWidget::writeDefaultSettings(Core::ISettings *s)
@@ -447,6 +506,9 @@ void DrugsViewWidget::writeDefaultSettings(Core::ISettings *s)
     s->setValue(S_DRUGHISTORY, QVariant());
     s->setValue(DrugsDB::Constants::S_LEVELOFWARNING , 0);
     s->setValue(DrugsDB::Constants::S_SHOWICONSINPRESCRIPTION , true);
+    s->setValue(S_DYNAMICALERTS, true);
+    s->setValue(S_DYNAMICALERTS_LEVEL, DrugsDB::Constants::Interaction::ContreIndication);
+    s->setValue(S_PATIENTNAMESORDER, 0);
 
     s->setValue(S_DRUGFONT , QFont().toString());
     s->setValue(S_PRESCRIPTIONFONT , QFont().toString());
@@ -487,6 +549,7 @@ void DrugsSelectorWidget::setDatasToUi()
     useBackgroundForDosages->setChecked(settings()->value(DrugsDB::Constants::S_MARKDRUGSWITHAVAILABLEDOSAGES).toBool());
     backgroundDosagesAvailableButton->setColor(QColor(settings()->value(DrugsDB::Constants::S_AVAILABLEDOSAGESBACKGROUNGCOLOR).toString()));
     backgroundAllergiesButton->setColor(QColor(settings()->value(DrugsDB::Constants::S_ALLERGYBACKGROUNDCOLOR).toString()));
+    backgroundIntoleranceButton->setColor(QColor(settings()->value(DrugsDB::Constants::S_INTOLERANCEBACKGROUNDCOLOR).toString()));
 }
 
 void DrugsSelectorWidget::saveToSettings(Core::ISettings *sets)
@@ -506,6 +569,7 @@ void DrugsSelectorWidget::saveToSettings(Core::ISettings *sets)
     s->setValue(DrugsDB::Constants::S_MARKDRUGSWITHAVAILABLEDOSAGES, useBackgroundForDosages->isChecked());
     s->setValue(DrugsDB::Constants::S_AVAILABLEDOSAGESBACKGROUNGCOLOR, backgroundDosagesAvailableButton->color());
     s->setValue(DrugsDB::Constants::S_ALLERGYBACKGROUNDCOLOR, backgroundAllergiesButton->color());
+    s->setValue(DrugsDB::Constants::S_INTOLERANCEBACKGROUNDCOLOR, backgroundIntoleranceButton->color());
 
     s->sync();
     if (DrugsWidget::DrugsWidgetManager::instance()->currentView())
@@ -526,6 +590,7 @@ void DrugsSelectorWidget::writeDefaultSettings(Core::ISettings *s)
     s->setValue(DrugsDB::Constants::S_MARKDRUGSWITHAVAILABLEDOSAGES,true);
     s->setValue(DrugsDB::Constants::S_AVAILABLEDOSAGESBACKGROUNGCOLOR, DrugsDB::Constants::S_DEF_AVAILABLEDOSAGESBACKGROUNGCOLOR);
     s->setValue(DrugsDB::Constants::S_ALLERGYBACKGROUNDCOLOR, "red");
+    s->setValue(DrugsDB::Constants::S_INTOLERANCEBACKGROUNDCOLOR, "yellow");
 
     s->sync();
 
@@ -558,19 +623,19 @@ DrugsPrintWidget::DrugsPrintWidget(QWidget *parent) :
     /** \todo Change the UID */
     drug = DrugsDB::Internal::DrugsBase::instance()->getDrugByUID("-1");
     if (!drug) {
-        Utils::Log::addError(this, "Unable to retreive a drug from the database");
+        Utils::Log::addError(this, "Unable to retreive a drug from the database", __FILE__, __LINE__);
     } else {
         drug->setPrescriptionValue(Prescription::IntakesFrom, 1);
         drug->setPrescriptionValue(Prescription::IntakesTo, 3);
         drug->setPrescriptionValue(Prescription::IntakesScheme, tkTr(Trans::Constants::INTAKES));
         drug->setPrescriptionValue(Prescription::IntakesUsesFromTo, true);
         drug->setPrescriptionValue(Prescription::Period, 2);
-        drug->setPrescriptionValue(Prescription::PeriodScheme, tkTr(Trans::Constants::DAYS));
+        drug->setPrescriptionValue(Prescription::PeriodScheme, tkTr(Trans::Constants::DAY_S));
         drug->setPrescriptionValue(Prescription::IntakesIntervalOfTime, 2);
-        drug->setPrescriptionValue(Prescription::IntakesIntervalScheme, tkTr(Trans::Constants::DAYS));
+        drug->setPrescriptionValue(Prescription::IntakesIntervalScheme, tkTr(Trans::Constants::DAY_S));
         drug->setPrescriptionValue(Prescription::DurationFrom, 1);
         drug->setPrescriptionValue(Prescription::DurationTo, 3);
-        drug->setPrescriptionValue(Prescription::DurationScheme, tkTr(Trans::Constants::WEEKS));
+        drug->setPrescriptionValue(Prescription::DurationScheme, tkTr(Trans::Constants::WEEK_S));
         drug->setPrescriptionValue(Prescription::DurationUsesFromTo, true);
         drug->setPrescriptionValue(Prescription::MealTimeSchemeIndex, 1);
         drug->setPrescriptionValue(Prescription::Note, tr("This a note to take into account<br />written in two lines..."));
