@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -48,6 +34,7 @@
 #include <drugsbaseplugin/drugsmodel.h>
 #include <drugsbaseplugin/globaldrugsmodel.h>
 #include <drugsbaseplugin/drugsdatabaseselector.h>
+#include <drugsbaseplugin/atctreemodel.h>
 
 #include <coreplugin/icore.h>
 #include <coreplugin/isettings.h>
@@ -63,6 +50,8 @@
 #include <QSqlRecord>
 #include <QSqlTableModel>
 #include <QHeaderView>
+#include <QScrollBar>
+#include <QSortFilterProxyModel>
 
 #include <QDebug>
 
@@ -81,21 +70,72 @@ static inline Core::ISettings *settings() {return Core::ICore::instance()->setti
 static inline Core::ITheme *theme() {return Core::ICore::instance()->theme();}
 static inline Core::ActionManager *actionManager() { return Core::ICore::instance()->actionManager(); }
 inline static DrugsDB::DrugsModel *drugModel() { return DrugsWidget::DrugsWidgetManager::instance()->currentDrugsModel(); }
+static inline Core::IMainWindow *mainWindow() {return Core::ICore::instance()->mainWindow();}
+
+namespace DrugsWidget {
+namespace Internal {
+
+class TreeProxyModel : public QSortFilterProxyModel
+{
+public:
+    TreeProxyModel(QObject *parent = 0)
+        : QSortFilterProxyModel(parent)
+    {
+        setFilterCaseSensitivity(Qt::CaseInsensitive);
+    }
+
+protected:
+    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
+    {
+        if(filterRegExp().isEmpty())
+            return true;
+
+        QModelIndex current(sourceModel()->index(sourceRow, filterKeyColumn(), sourceParent));
+
+        if(sourceModel()->hasChildren(current)) {
+            bool atLeastOneValidChild = false;
+            int i = 0;
+            while(!atLeastOneValidChild) {
+                const QModelIndex child(current.child(i, current.column()));
+                if (!child.isValid())
+                    // No valid child
+                    break;
+
+                atLeastOneValidChild = filterAcceptsRow(i, current);
+                i++;
+            }
+            return atLeastOneValidChild;
+        }
+
+        return sourceModel()->data(current).toString().contains(filterRegExp());
+    }
+};
+
+}
+}
+
 
 DrugSelector::DrugSelector(QWidget *parent) :
         QWidget(parent),
-        m_DrugsModel(0), m_InnModel(0),
+        m_DrugsModel(0), m_InnModel(0), m_AtcProxyModel(0),
         m_SearchToolButton(0),
         m_DrugsHistoricButton(0),
         m_HistoryAct(0)
 {
 }
 
+DrugSelector::~DrugSelector()
+{
+    mainWindow()->setWindowTitle(m_WinTitle);
+}
+
 void DrugSelector::initialize()
 {
     setupUi(this);
     textButton->setIcon(theme()->icon(Core::Constants::ICONPENCIL));
 
+    m_WinTitle = mainWindow()->windowTitle();
+
     createToolButtons();
 
     createDrugModelView();
@@ -123,9 +163,12 @@ void DrugSelector::initialize()
 
     retranslateUi("");
 
+    searchLine->setDelayedSignals(true);
+
     connect(drugsBase(), SIGNAL(drugsBaseHasChanged()), this, SLOT(onDrugsBaseChanged()));
 }
 
+/** \brief Define the \e font to use on all the views */
 void DrugSelector::setFont(const QFont &font)
 {
     drugsView->setFont(font);
@@ -133,6 +176,12 @@ void DrugSelector::setFont(const QFont &font)
     searchLine->setFont(font);
 }
 
+void DrugSelector::onSearchShortCutTriggered()
+{
+    searchLine->setFocus();
+    searchLine->selectAll();
+}
+
 void DrugSelector::createToolButtons()
 {
     m_SearchToolButton = new QToolButton(searchLine);   // parent object will be redefined
@@ -157,11 +206,14 @@ void DrugSelector::createToolButtons()
     searchLine->setRightButton(m_DrugsHistoricButton);
 }
 
+/** \brief Update the views if user selected another drugs database */
 void DrugSelector::onDrugsBaseChanged()
 {
-    delete m_DrugsModel;
-    m_DrugsModel = 0;
+    QSqlTableModel *old = m_DrugsModel;
+    m_DrugsModel = new DrugsDB::GlobalDrugsModel(this);
     createDrugModelView();
+    delete old;
+    old = 0;
 }
 
 void DrugSelector::createDrugModelView()
@@ -185,8 +237,8 @@ void DrugSelector::createDrugModelView()
 
 void DrugSelector::updateDrugsViewColumns()
 {
-    drugsView->setColumnHidden(DrugsDB::Constants::DRUGS_ROUTE, !settings()->value(DrugsDB::Constants::S_SELECTOR_SHOWFORM).toBool());
-    drugsView->setColumnHidden(DrugsDB::Constants::DRUGS_FORM , !settings()->value(DrugsDB::Constants::S_SELECTOR_SHOWROUTE).toBool());
+    drugsView->setColumnHidden(DrugsDB::Constants::DRUGS_ROUTE, !settings()->value(DrugsDB::Constants::S_SELECTOR_SHOWROUTE).toBool());
+    drugsView->setColumnHidden(DrugsDB::Constants::DRUGS_FORM , !settings()->value(DrugsDB::Constants::S_SELECTOR_SHOWFORM).toBool());
     drugsView->setColumnHidden(DrugsDB::Constants::DRUGS_STRENGTH , !settings()->value(DrugsDB::Constants::S_SELECTOR_SHOWSTRENGTH).toBool());
     // managing model fields
     drugsView->hideColumn(DrugsDB::Constants::DRUGS_LINK_SPC);
@@ -200,18 +252,16 @@ void DrugSelector::createINNModelView()
 {
     using namespace DrugsDB::Constants;
     // create model and tableview for Iam Class / INNs
-    m_InnModel = new QSqlTableModel(this, QSqlDatabase::database(DrugsDB::Constants::DB_IAM_NAME));
-    m_InnModel->setTable(drugsBase()->iamTable(Table_IAM_DENOMINATION));
-    m_InnModel->setEditStrategy(QSqlTableModel::OnManualSubmit);
-    QHashWhere where;
-    where.insert(IAM_DENOMINATION_ID, ">999");
-    m_InnModel->setFilter(drugsBase()->getIamWhereClause(Table_IAM_DENOMINATION, where));
-    m_InnModel->select();
-    InnView->setModel(m_InnModel);
-    InnView->setColumnHidden(0 , true);
-    InnView->resizeColumnsToContents();
-    InnView->verticalHeader()->hide();
-    InnView->horizontalHeader()->hide();
+    m_InnModel = new DrugsDB::AtcTreeModel(this);
+    m_InnModel->init();
+
+    m_AtcProxyModel = new TreeProxyModel(this);
+    m_AtcProxyModel->setSourceModel(m_InnModel);
+    InnView->setModel(m_AtcProxyModel);
+
+    //InnView->setModel(m_InnModel);
+    InnView->header()->setStretchLastSection(false);
+    InnView->header()->setResizeMode(0, QHeaderView::Stretch);
     InnView->hide();
 }
 
@@ -222,7 +272,7 @@ void DrugSelector::createDrugsHistoryActions()
 
     m_HistoryAct = new QActionGroup(this);
     foreach(QString s, settings()->value(Constants::S_DRUGHISTORY).toStringList()) {
-        QAction * a = new QAction(s.left(s.lastIndexOf(",")).left(70) + "..." , m_HistoryAct);
+        QAction *a = new QAction(s.left(s.lastIndexOf(",")).left(70) + "..." , m_HistoryAct);
         a->setToolTip(s);
         m_HistoryAct->addAction(a);
     }
@@ -233,11 +283,13 @@ void DrugSelector::createDrugsHistoryActions()
     m_DrugsHistoricButton->addActions(m_HistoryAct->actions());
 }
 
+/** \brief Connect the search line edit to the filter update */
 void DrugSelector::connectFilter()
 {
     connect(searchLine, SIGNAL(textChanged(const QString &)), this, SLOT(updateModelFilter()));
 }
 
+/** \brief Disconnect the search line edit to the filter update */
 void DrugSelector::disconnectFilter()
 {
     disconnect(searchLine, SIGNAL(textChanged(const QString &)), this, SLOT(updateModelFilter()));
@@ -267,11 +319,12 @@ void DrugSelector::retranslateUi(const QString &)
 //    }
 }
 
+/** \brief Prepare the filter's masks according to the selected search method. */
 void DrugSelector::setSearchMethod(int method)
 {
     if (method == Constants::SearchCommercial) {
 #ifdef FREEDIAMS
-        Core::ICore::instance()->mainWindow()->setWindowTitle(qApp->applicationName() + " - " + qApp->applicationVersion() + " - " + tkTr(Constants::SEARCHCOMMERCIAL_TEXT));
+        mainWindow()->setWindowTitle(m_WinTitle + " - " + QApplication::translate(Constants::DRUGCONSTANTS_TR_CONTEXT, Constants::SEARCHCOMMERCIAL_TEXT));
 #endif
         m_filterModel = "";
         InnView->hide();
@@ -290,7 +343,7 @@ void DrugSelector::setSearchMethod(int method)
     }
     else if (method == Constants::SearchMolecules) {
 #ifdef FREEDIAMS
-        Core::ICore::instance()->mainWindow()->setWindowTitle(qApp->applicationName() + " - " + qApp->applicationVersion() + " - " + tkTr(Constants::SEARCHMOLECULES_TEXT));
+        mainWindow()->setWindowTitle(m_WinTitle + " - " + QApplication::translate(Constants::DRUGCONSTANTS_TR_CONTEXT, Constants::SEARCHMOLECULES_TEXT));
 #endif
         m_filterModel = "";
         InnView->hide();
@@ -311,7 +364,7 @@ void DrugSelector::setSearchMethod(int method)
     }
     else if (method == Constants::SearchInn) {
 #ifdef FREEDIAMS
-        Core::ICore::instance()->mainWindow()->setWindowTitle(qApp->applicationName() + " - " + qApp->applicationVersion() + " - " + tkTr(Constants::SEARCHINN_TEXT));
+        mainWindow()->setWindowTitle(m_WinTitle + " - " + QApplication::translate(Constants::DRUGCONSTANTS_TR_CONTEXT, Constants::SEARCHINN_TEXT));
 #endif
         m_filterModel = "";
         // show inn model and view
@@ -340,12 +393,17 @@ void DrugSelector::setSearchMethod(int method)
     updateModelFilter();
 }
 
+/**
+  \brief update the GlobalDrugModel filter according to the search method and the search text.
+  \sa void DrugSelector::setSearchMethod(int method)
+*/
 void DrugSelector::updateModelFilter()
 {
     if (searchLine->searchText().isEmpty()) {
         if (WarnSearchFilter)
             qWarning() << "No search filter";
         m_DrugsModel->setFilter("");
+        m_AtcProxyModel->setFilterWildcard("*");
         return;
     }
     QString tmp = m_filterModel;
@@ -356,17 +414,18 @@ void DrugSelector::updateModelFilter()
             qWarning() << "Search filter" << tmp;
     } else {
         // Search By INN
-        // refresh inn view and model
-        QHashWhere where;
-        where.insert(DrugsDB::Constants::IAM_DENOMINATION , QString("LIKE '%1%' ").arg(search));
-        m_InnModel->setFilter(drugsBase()->getIamWhereClause(DrugsDB::Constants::Table_IAM_DENOMINATION, where));
-        // retreive code_subst associated with searched text
-        QList<int> codes = drugsBase()->getLinkedSubstCode(search);
+        m_AtcProxyModel->setFilterWildcard(search + "*");
+        m_AtcProxyModel->setFilterKeyColumn(0);
+        InnView->expandAll();
+
+        // retreive molecule_codes associated with searched text
+        QList<int> codes = drugsBase()->getLinkedMoleculeCodes(search);
         QString list = "";
         foreach(int i, codes)
             list += QString::number(i) + ", " ;
         list.chop(2);
         m_DrugsModel->setFilter(tmp.replace("__replaceit__", list));
+
         if (WarnSearchFilter)
             qWarning() << "Search filter" << tmp;
     }
@@ -380,14 +439,16 @@ void DrugSelector::on_InnView_clicked(const QModelIndex &index)
     if (!index.isValid())
         return;
 
-    QString inn = index.data().toString();
-    // retreive code_subst associated with searched text
+    QString inn = m_AtcProxyModel->index(index.row(), DrugsDB::AtcTreeModel::ATC_Code, index.parent()).data().toString();
+    // retreive molecule_codes associated with searched text
     QString tmp = m_filterModel;
-    QList<int> codes = drugsBase()->getLinkedSubstCode(inn);
+    QList<int> codes = drugsBase()->getAllMoleculeCodeWithAtcStartingWith(inn);
     QString list = "";
     foreach(int i, codes)
         list += QString::number(i) + ", " ;
     list.chop(2);
+    if (WarnSearchFilter)
+        qWarning() << "Search filter" << tmp.replace("__replaceit__", list);
     m_DrugsModel->setFilter(tmp.replace("__replaceit__", list));
 }
 
@@ -396,8 +457,8 @@ void DrugSelector::on_drugsView_doubleClicked(const QModelIndex &index)
     // retreive CIS of drug and emit signal
     if (!index.isValid())
         return;
-    QSqlRecord rec = m_DrugsModel->record(index.row());
-    int selectedCIS = rec.value(0).toInt();
+
+    const QVariant &selectedCIS = m_DrugsModel->index(index.row(), DrugsDB::Constants::DRUGS_UID).data();
 
     // store drug into history
     QStringList hist = settings()->value(Constants::S_DRUGHISTORY).toStringList();
@@ -410,8 +471,8 @@ void DrugSelector::on_drugsView_doubleClicked(const QModelIndex &index)
     // refresh drug history
     createDrugsHistoryActions();
 
-    emit drugSelected(selectedCIS);
-    emit drugSelected(index);
+    Q_EMIT drugSelected(selectedCIS);
+    Q_EMIT drugSelected(index);
 }
 
 /** \brief User asked to add a textual prescription. This member creates a dialog and send the text to the model. */
