@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -86,7 +72,7 @@ DrugsWidgetManager::DrugsWidgetManager(QObject *parent) : DrugsActionHandler(par
     connect(Core::ICore::instance()->contextManager(), SIGNAL(contextChanged(Core::IContext*)),
             this, SLOT(updateContext(Core::IContext*)));
     setObjectName("DrugsWidgetManager");
-    Utils::Log::addMessage(this, "Instance created");
+//    Utils::Log::addMessage(this, "Instance created");
 }
 
 void DrugsWidgetManager::updateContext(Core::IContext *object)
@@ -164,7 +150,7 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
         m_CurrentView(0)
 {
     setObjectName("DrugsActionHandler");
-    Utils::Log::addMessage(this, "Instance created");
+//    Utils::Log::addMessage(this, "Instance created");
 
     Core::UniqueIDManager *uid = Core::ICore::instance()->uniqueIDManager();
     Core::ITheme *th = Core::ICore::instance()->theme();
@@ -177,6 +163,7 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     Core::ActionContainer *menu = actionManager()->actionContainer(DrugsWidget::Constants::M_PLUGINS_DRUGS);
     if (!menu) {
         menu = actionManager()->createMenu(DrugsWidget::Constants::M_PLUGINS_DRUGS);
+        menu->appendGroup(DrugsWidget::Constants::G_PLUGINS_VIEWS);
         menu->appendGroup(DrugsWidget::Constants::G_PLUGINS_MODES);
         menu->appendGroup(DrugsWidget::Constants::G_PLUGINS_SEARCH);
         menu->appendGroup(DrugsWidget::Constants::G_PLUGINS_DRUGS);
@@ -195,8 +182,8 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     a->setObjectName("aToggleDrugSelector");
     a->setIcon(th->icon(Constants::I_TOGGLEDRUGSELECTOR));
     cmd = actionManager()->registerAction(a, Constants::A_TOGGLE_DRUGSELECTOR, ctx);
-    cmd->setTranslations(Constants::TOGGLEDRUGSELECTOR_TEXT);
-    menu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_DRUGS);
+    cmd->setTranslations(Constants::TOGGLEDRUGSELECTOR_TEXT, Constants::TOGGLEDRUGSELECTOR_TEXT, Constants::DRUGCONSTANTS_TR_CONTEXT);
+    menu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_VIEWS);
     connect(a, SIGNAL(triggered()), this, SLOT(toggleDrugSelector()));
 
     a = aClear = new QAction(this);
@@ -254,8 +241,8 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     a->setCheckable(true);
     a->setChecked(true);
     cmd = actionManager()->registerAction(a, DrugsWidget::Constants::A_TOGGLE_TESTINGDRUGS, ctx);
-    cmd->setTranslations(DrugsWidget::Constants::TOGGLETESTINGDRUGS_TEXT);
-    menu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_INTERACTIONS);
+    cmd->setTranslations(DrugsWidget::Constants::TOGGLETESTINGDRUGS_TEXT, Constants::TOGGLETESTINGDRUGS_TEXT, Constants::DRUGCONSTANTS_TR_CONTEXT);
+    menu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_VIEWS);
     connect(a, SIGNAL(triggered()), this, SLOT(toggleTestingDrugs()));
 
     // Search method menu
@@ -275,6 +262,7 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     a->setIcon(th->icon(DrugsDB::Constants::I_SEARCHCOMMERCIAL));
     cmd = actionManager()->registerAction(a, DrugsWidget::Constants::A_SEARCH_COMMERCIAL, ctx);
     cmd->setTranslations(DrugsWidget::Constants::SEARCHCOMMERCIAL_TEXT, "", DRUGCONSTANTS_TR_CONTEXT);
+    cmd->setAttribute(Core::Command::CA_UpdateText);
     searchmenu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_SEARCH);
     gSearchMethod->addAction(a);
 
@@ -284,6 +272,7 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     a->setIcon(th->icon(DrugsDB::Constants::I_SEARCHMOLS));
     cmd = actionManager()->registerAction(a, DrugsWidget::Constants::A_SEARCH_MOLECULES, ctx);
     cmd->setTranslations(DrugsWidget::Constants::SEARCHMOLECULES_TEXT, "", DRUGCONSTANTS_TR_CONTEXT);
+    cmd->setAttribute(Core::Command::CA_UpdateText);
     searchmenu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_SEARCH);
     gSearchMethod->addAction(a);
 
@@ -293,6 +282,7 @@ DrugsActionHandler::DrugsActionHandler(QObject *parent) :
     a->setIcon(th->icon(DrugsDB::Constants::I_SEARCHINN));
     cmd = actionManager()->registerAction(a, DrugsWidget::Constants::A_SEARCH_INN, ctx);
     cmd->setTranslations(DrugsWidget::Constants::SEARCHINN_TEXT, "", DRUGCONSTANTS_TR_CONTEXT);
+    cmd->setAttribute(Core::Command::CA_UpdateText);
     searchmenu->addAction(cmd, DrugsWidget::Constants::G_PLUGINS_SEARCH);
     gSearchMethod->addAction(a);
     connect(gSearchMethod,SIGNAL(triggered(QAction*)),this,SLOT(searchActionChanged(QAction*)));
@@ -447,7 +437,7 @@ void DrugsActionHandler::setCurrentView(DrugsCentralWidget *view)
 {
     Q_ASSERT(view);
     if (!view) { // this should never be the case
-        Utils::Log::addError(this, "setCurrentView : no view");
+        Utils::Log::addError(this, "setCurrentView : no view", __FILE__, __LINE__);
         return;
     }
     //    qWarning() << "DrugsActionHandler::setCurrentView(DrugsCentralWidget *view)";
@@ -576,7 +566,7 @@ void DrugsActionHandler::viewInteractions()
 void DrugsActionHandler::searchTriggered()
 {
     if (m_CurrentView) {
-        m_CurrentView->drugSelector()->setFocus();
+        m_CurrentView->drugSelector()->onSearchShortCutTriggered();
     }
 }
 
