@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -38,7 +24,7 @@
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
 /**
-  * \class ListView
+  * \class Views::ListView
   * \brief This widget shows a QListView with some buttons and a context menu.
   * Actions inside the contextual menu and the toolbar can be setted using
     AvailableActions param and setActions().\n
@@ -48,8 +34,6 @@
     You can reimplement getContextMenu() in order to use your own contextMenu.\n
     Remember that the poped menu will be deleted after execution. \n
   \todo There is a problem when including this widget into a QDataWidgetMapper, when this widget loses focus, datas are not retreived.
-  \ingroup toolkit
-  \ingroup widget_toolkit
 */
 
 #include "listview.h"
@@ -75,6 +59,7 @@
 #include <QListView>
 #include <QStringListModel>
 #include <QToolButton>
+#include <QToolBar>
 
 using namespace Views;
 using namespace Views::Internal;
@@ -217,7 +202,7 @@ void ListViewActionHandler::setCurrentView(ListView *view)
 //        qWarning() << "current view " << view;
     // disconnect old view
     if (m_CurrentView) {
-        disconnect(m_CurrentView->listView()->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
+        disconnect(m_CurrentView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
                    this, SLOT(listViewItemChanged()));
     }
     m_CurrentView = view;
@@ -225,7 +210,7 @@ void ListViewActionHandler::setCurrentView(ListView *view)
         return;
     }
     // reconnect some actions
-    connect(m_CurrentView->listView()->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
+    connect(m_CurrentView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
             this, SLOT(listViewItemChanged()));
     updateActions();
 }
@@ -245,7 +230,7 @@ bool ListViewActionHandler::canMoveUp()
 {
     if (!m_CurrentView)
         return false;
-    QModelIndex idx = m_CurrentView->listView()->currentIndex();
+    QModelIndex idx = m_CurrentView->currentIndex();
     if (!idx.isValid())
         return false;
     if (idx.row() >= 1)
@@ -257,10 +242,10 @@ bool ListViewActionHandler::canMoveDown()
 {
     if (!m_CurrentView)
         return false;
-    QModelIndex idx = m_CurrentView->listView()->currentIndex();
+    QModelIndex idx = m_CurrentView->currentIndex();
     if (!idx.isValid())
         return false;
-    if (idx.row() < (m_CurrentView->listView()->model()->rowCount()-1))
+    if (idx.row() < (m_CurrentView->model()->rowCount()-1))
         return true;
     return false;
 }
@@ -284,7 +269,6 @@ class ListViewPrivate
 public:
     ListViewPrivate(QWidget * parent, ListView::AvailableActions actions) :
             m_Parent(parent),
-            m_ListView(0),
             m_Actions(actions),
             m_Context(0)
     {
@@ -324,7 +308,6 @@ public:
 
 public:
     QWidget *m_Parent;
-    QListView *m_ListView;
     ListView::AvailableActions m_Actions;
     ListViewContext *m_Context;
     QToolBar *m_ToolBar;
@@ -337,7 +320,7 @@ public:
 
 /** \brief Constructor */
 ListView::ListView(QWidget *parent, AvailableActions actions)
-    : QWidget(parent),
+    : QListView(parent),
     d(0)
 {
     static int handler = 0;
@@ -351,24 +334,19 @@ ListView::ListView(QWidget *parent, AvailableActions actions)
     d->calculateContext();
     contextManager()->addContextObject(d->m_Context);
 
-    // Create widget
-    QGridLayout *layout = new QGridLayout(this);
-    layout->setSpacing(3);
-    layout->setMargin(0);
-    d->m_ListView = new QListView(this);
-    d->m_ListView->setContextMenuPolicy(Qt::CustomContextMenu);
+    // Add toolbar to the horizontal scroolbar
+    setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     d->m_ToolBar = new QToolBar(this);
     d->m_ToolBar->setIconSize(QSize(16,16));
     d->m_ToolBar->setFocusPolicy(Qt::ClickFocus);
-    layout->addWidget(d->m_ListView, 0, 0 , 1, 2);
-    layout->addWidget(d->m_ToolBar, 1, 0);
-
-    connect(d->m_ListView, SIGNAL(customContextMenuRequested(const QPoint &)),
-            this, SLOT(contextMenu(const QPoint &)));
-
-    d->m_ListView->setFocusProxy(this);
-
+    d->m_ToolBar->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
     d->populateToolbar();
+    addScrollBarWidget(d->m_ToolBar, Qt::AlignLeft);
+
+    // Manage context menu
+    setContextMenuPolicy(Qt::CustomContextMenu);
+    connect(this, SIGNAL(customContextMenuRequested(const QPoint &)),
+            this, SLOT(contextMenu(const QPoint &)));
 }
 
 ListView::~ListView()
@@ -379,45 +357,8 @@ ListView::~ListView()
 /** \brief Defines the objectName */
 void ListView::setObjectName(const QString &name)
 {
-    d->m_ListView->setObjectName(name+"ListView");
-    QWidget::setObjectName(name);
-}
-
-
-/** \brief Returns the list view. */
-QListView *ListView::listView() const
-{
-    return d->m_ListView;
-}
-
-QAbstractItemModel * ListView::model() const
-{
-    return d->m_ListView->model();
-}
-
-void ListView::setModel(QAbstractItemModel * model)
-{
-    d->m_ListView->setModel(model);
-}
-
-void ListView::setModelColumn(int column)
-{
-    d->m_ListView->setModelColumn(column);
-}
-
-int ListView::modelColumn() const
-{
-    return d->m_ListView->modelColumn();
-}
-
-void ListView::setCurrentIndex(const QModelIndex & item)
-{
-    d->m_ListView->setCurrentIndex(item);
-}
-
-void ListView::setEditTriggers(QAbstractItemView::EditTriggers triggers)
-{
-    d->m_ListView->setEditTriggers(triggers);
+//    setObjectName(name+"ListView");
+//    QListView::setObjectName(name);
 }
 
 void ListView::setActions(AvailableActions actions)
@@ -439,12 +380,12 @@ void ListView::showButtons()
 void ListView::useContextMenu(bool state)
 {
     if (state)
-        d->m_ListView->setContextMenuPolicy(Qt::CustomContextMenu);
+        setContextMenuPolicy(Qt::CustomContextMenu);
     else
-        d->m_ListView->setContextMenuPolicy(Qt::NoContextMenu);
+        setContextMenuPolicy(Qt::NoContextMenu);
 }
 
-QMenu * ListView::getContextMenu()
+QMenu *ListView::getContextMenu()
 {
     QMenu *pop = new QMenu(d->m_Parent);
     pop->addActions(d->m_ToolBar->actions());
@@ -453,43 +394,50 @@ QMenu * ListView::getContextMenu()
 
 void ListView::addItem()
 {
-    if (! d->m_ListView->model())
+    if (!model())
         return;
     
     // insert a row into model
     int row = 0;
-    if (d->m_ListView->currentIndex().isValid()) {
-        row = d->m_ListView->currentIndex().row() + 1;
+    if (currentIndex().isValid()) {
+        row = currentIndex().row() + 1;
     } else {
-        row = d->m_ListView->model()->rowCount();
+        row = model()->rowCount();
         if (row<0)
             row = 0;
     }
-    if (!d->m_ListView->model()->insertRows(row, 1))
-        Utils::Log::addError(this, QString("ListView can not add a row to the model %1").arg(model()->objectName()));
+    if (!model()->insertRows(row, 1))
+        Utils::Log::addError(this, QString("ListView can not add a row to the model %1").arg(model()->objectName()),
+                             __FILE__, __LINE__);
 
     // select inserted row and edit it
-    QModelIndex index = d->m_ListView->model()->index(row, d->m_ListView->modelColumn());
-    d->m_ListView->setCurrentIndex(index);
-    if (d->m_ListView->editTriggers() != QAbstractItemView::NoEditTriggers) {
-        d->m_ListView->edit(index);
+    QModelIndex index = model()->index(row, modelColumn());
+    setCurrentIndex(index);
+    if (editTriggers() != QAbstractItemView::NoEditTriggers) {
+        edit(index);
     }
+    Q_EMIT addRequested();
 }
 
 void ListView::removeItem()
 {
-    if (!d->m_ListView->model())
+    if (!model())
         return;
-    QModelIndex idx = d->m_ListView->currentIndex();
+    const QModelIndex &idx = currentIndex();
     if (idx.isValid()) {
-        d->m_ListView->closePersistentEditor(idx);
+        // Do this to keep QDataWidgetMapper informed of the modification
+        edit(idx);
+        closePersistentEditor(idx);
+        // Now delete row
         int row = idx.row();
-//        qWarning() << idx.data() << idx.row();
-        if (!d->m_ListView->model()->removeRows(row, 1))
+        if (!model()->removeRow(row)) {
             Utils::Log::addError(this, QString("ListView can not remove row %1 to the model %2")
                              .arg(row)
-                             .arg(model()->objectName()));
+                             .arg(model()->objectName()),
+                             __FILE__, __LINE__);
+        }
     }
+    Q_EMIT removeRequested();
 }
 
 void ListView::moveDown()
@@ -497,7 +445,7 @@ void ListView::moveDown()
 //    if (!d->canMoveDown())
 //        return;
 
-    QModelIndex idx = d->m_ListView->currentIndex();
+    QModelIndex idx = currentIndex();
     bool moved = false;
 
     StringListModel *m = qobject_cast<StringListModel*>(model());
@@ -516,13 +464,14 @@ void ListView::moveDown()
     // TODO : else swap the two rows.
 
     if (moved)
-        d->m_ListView->setCurrentIndex(d->m_ListView->model()->index(idx.row()+1,0));
+        setCurrentIndex(model()->index(idx.row()+1,0));
+    Q_EMIT moveDownRequested();
 }
 
 void ListView::moveUp()
 {
-    QModelIndex idx = d->m_ListView->currentIndex();
-//    d->m_ListView->closePersistentEditor(idx);
+    QModelIndex idx = currentIndex();
+//    closePersistentEditor(idx);
     bool moved = false;
 
     StringListModel *m = qobject_cast<StringListModel*>(model());
@@ -541,7 +490,8 @@ void ListView::moveUp()
     // TODO : else swap the two rows.
 
     if (moved)
-        d->m_ListView->setCurrentIndex(d->m_ListView->model()->index(idx.row()-1,0));
+        setCurrentIndex(model()->index(idx.row()-1,0));
+    Q_EMIT moveUpRequested();
 }
 
 void ListView::on_edit_triggered()
