@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                      *
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -88,7 +74,7 @@ public:
             if (query.next())
                 version = query.value(0).toString();
         } else {
-            Utils::Log::addQueryError(q, query);
+            Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
         }
         query.finish();
         bool updateVersionNumber = false;
@@ -108,11 +94,13 @@ public:
                     << "ALTER TABLE `TEMPLATES` RENAME TO `OLD_TEMPLATES`;";
 
             if (!q->executeSQL(reqs, q->database()))
-                Utils::Log::addError(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)");
+                Utils::Log::addError(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)",
+                                     __FILE__, __LINE__);
 
             // 2. Recreate the db schema
             if (!q->createTables())
-                Utils::Log::addError(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)");
+                Utils::Log::addError(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)",
+                                     __FILE__, __LINE__);
 
             reqs.clear();
             reqs << QString("INSERT INTO `CATEGORIES` (%1) SELECT %1 FROM `OLD_CATEGORIES`;")
@@ -146,7 +134,8 @@ public:
 
             // Reinsert datas to new tables
             if (!q->executeSQL(reqs, q->database()))
-                Utils::Log::addError(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)");
+                Utils::Log::addError(q, "Unable to recreate template database during update (0.3.0 to 0.4.0)",
+                                     __FILE__, __LINE__);
 
             // Refresh db version
             version = "0.4.0";
@@ -158,7 +147,7 @@ public:
             query.bindValue(0, Constants::DB_ACTUAL_VERSION);
             query.exec();
             if (!query.isActive()) {
-                Utils::Log::addQueryError(q, query);
+                Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
             }
             query.finish();
         }
@@ -340,14 +329,16 @@ bool TemplateBase::createDatabase(const QString &connectionName , const QString
         DB = QSqlDatabase::addDatabase("QSQLITE", connectionName);
         if (!QDir(pathOrHostName).exists()) {
             if (!QDir().mkpath(pathOrHostName)) {
-                Utils::Log::addError(this, tkTr(Trans::Constants::_1_ISNOT_AVAILABLE_CANNOTBE_CREATED).arg(pathOrHostName));
+                Utils::Log::addError(this, tkTr(Trans::Constants::_1_ISNOT_AVAILABLE_CANNOTBE_CREATED).arg(pathOrHostName),
+                                     __FILE__, __LINE__);
             } else {
                 Utils::Log::addMessage(this, tkTr(Trans::Constants::CREATE_DIR_1).arg(pathOrHostName));
             }
         }
         DB.setDatabaseName(QDir::cleanPath(pathOrHostName + QDir::separator() + dbName));
         if (!DB.open())
-            Utils::Log::addError(this, tkTr(Trans::Constants::DATABASE_1_CANNOT_BE_CREATED_ERROR_2).arg(dbName).arg(DB.lastError().text()));
+            Utils::Log::addError(this, tkTr(Trans::Constants::DATABASE_1_CANNOT_BE_CREATED_ERROR_2).arg(dbName).arg(DB.lastError().text()),
+                                 __FILE__, __LINE__);
         setDriver(Utils::Database::SQLite);
     }
     else if (driver == MySQL) {
@@ -364,7 +355,7 @@ bool TemplateBase::createDatabase(const QString &connectionName , const QString
             }
             QSqlQuery q(QString("CREATE DATABASE `%1`").arg(dbName), d);
             if (!q.isActive()) {
-                Utils::Log::addQueryError("Database", q);
+                Utils::Log::addQueryError("TemplateBase", q, __FILE__, __LINE__);
                 Utils::warningMessageBox(tr("Unable to create the Templates database."),tr("Please contact dev team."));
                 return false;
             }
@@ -388,7 +379,8 @@ bool TemplateBase::createDatabase(const QString &connectionName , const QString
         Utils::Log::addMessage(this, tkTr(Trans::Constants::DATABASE_1_CORRECTLY_CREATED).arg(dbName));
     } else {
         Utils::Log::addError(this, tkTr(Trans::Constants::DATABASE_1_CANNOT_BE_CREATED_ERROR_2)
-                         .arg(dbName, DB.lastError().text()));
+                         .arg(dbName, DB.lastError().text()),
+                         __FILE__, __LINE__);
         return false;
     }
 
