@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   Main Developper : Eric MAEKER, <eric.maeker@free.fr>                  *
@@ -330,9 +316,10 @@ public:
         /** \todo improve this */
         foreach(TemplatesModelPrivate *pr, m_Handles) {
             if (pr->q->isCategoryOnly() == q->isCategoryOnly()) {
-                pr->q->beginInsertRows(parent, first, last);
-                }
+                QModelIndex idx = pr->q->index(parent.row(), parent.column(), parent.parent());
+                pr->q->beginInsertRows(idx, first, last);
             }
+        }
     }
 
     void allInstancesEndInsertRows()
@@ -341,8 +328,8 @@ public:
         foreach(TemplatesModelPrivate *pr, m_Handles) {
             if (pr->q->isCategoryOnly() == q->isCategoryOnly()) {
                 pr->q->endInsertRows();
-                }
             }
+        }
     }
 
     void allInstancesBeginRemoveRows(const QModelIndex &parent, int first, int last)
@@ -351,8 +338,8 @@ public:
         foreach(TemplatesModelPrivate *pr, m_Handles) {
             if (pr->q->isCategoryOnly() == q->isCategoryOnly()) {
                 pr->q->beginRemoveRows(parent,first,last);
-                }
             }
+        }
     }
 
     void allInstancesEndRemoveRows()
@@ -388,7 +375,8 @@ public:
         if (!DB.open()) {
             Utils::Log::addError(q, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
                                  .arg(Constants::DB_TEMPLATES_NAME)
-                                 .arg(DB.lastError().text()));
+                                 .arg(DB.lastError().text()),
+                                 __FILE__, __LINE__);
             return;
         }
 
@@ -411,7 +399,7 @@ public:
                 datas.clear();
             }
         } else {
-            Utils::Log::addQueryError(q, query);
+            Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
         }
         query.finish();
         foreach(TreeItem *item, m_IdToCategory.values()) {
@@ -447,7 +435,7 @@ public:
                 datas.clear();
             }
         } else {
-            Utils::Log::addQueryError(q, query);
+            Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
         }
         query.finish();
         // add templates to categories
@@ -472,7 +460,8 @@ public:
         if (!DB.open()) {
             Utils::Log::addError(q, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
                                  .arg(Constants::DB_TEMPLATES_NAME)
-                                 .arg(DB.lastError().text()));
+                                 .arg(DB.lastError().text()),
+                                 __FILE__, __LINE__);
             return;
         }
 
@@ -502,7 +491,7 @@ public:
                     query.bindValue(Constants::TEMPLATE_TRANSMISSIONDATE, QVariant());
                     query.exec();
                     if (!query.isActive()) {
-                        Utils::Log::addQueryError(q, query);
+                        Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
                     } else {
                         t->setNewlyCreated(false);
                         t->setModified(false);
@@ -524,7 +513,7 @@ public:
                     // save category
                     query.exec();
                     if (!query.isActive()) {
-                        Utils::Log::addQueryError(q, query);
+                        Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
                     } else {
                         t->setNewlyCreated(false);
                         t->setModified(false);
@@ -557,7 +546,7 @@ public:
                     query.bindValue(Constants::TEMPLATE_TRANSMISSIONDATE, QVariant());
                     query.exec();
                     if (!query.isActive()) {
-                        Utils::Log::addQueryError(q, query);
+                        Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
                     }
                     req.clear();
                     query.finish();
@@ -579,7 +568,7 @@ public:
                     query.bindValue(Constants::CATEGORIES_TRANSMISSIONDATE, QVariant());
                     query.exec();
                     if (!query.isActive()) {
-                        Utils::Log::addQueryError(q, query);
+                        Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
                     }
                     req.clear();
                     query.finish();
@@ -602,7 +591,8 @@ public:
         if (!DB.open()) {
             Utils::Log::addError(q, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
                                  .arg(Constants::DB_TEMPLATES_NAME)
-                                 .arg(DB.lastError().text()));
+                                 .arg(DB.lastError().text()),
+                                 __FILE__, __LINE__);
             return toReturn;
         }
         QHash<int, QString> where;
@@ -610,7 +600,7 @@ public:
         req = templateBase()->select(Constants::Table_Categories, Constants::CATEGORIES_ID, where);
         QSqlQuery query(req, DB);
         if (!query.isActive()) {
-            Utils::Log::addQueryError(q, query);
+            Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
         } else {
             while (query.next()) {
                 toReturn << query.value(0).toInt();
@@ -630,7 +620,8 @@ public:
         if (!DB.open()) {
             Utils::Log::addError(q, tkTr(Trans::Constants::UNABLE_TO_OPEN_DATABASE_1_ERROR_2)
                                  .arg(Constants::DB_TEMPLATES_NAME)
-                                 .arg(DB.lastError().text()));
+                                 .arg(DB.lastError().text()),
+                                 __FILE__, __LINE__);
             return;
         }
         QString req;
@@ -656,7 +647,7 @@ public:
 
             QSqlQuery query(req, DB);
             if (!query.isActive())
-                Utils::Log::addQueryError(q, query);
+                Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
             else
                 m_CategoriesToDelete.clear();
         }
@@ -673,7 +664,7 @@ public:
             req = templateBase()->prepareDeleteQuery(Constants::Table_Templates, where);
             QSqlQuery query(req, DB);
             if (!query.isActive())
-                Utils::Log::addQueryError(q, query);
+                Utils::Log::addQueryError(q, query, __FILE__, __LINE__);
             else
                 m_TemplatesToDelete.clear();
         }
