@@ -1,36 +1,22 @@
 /***************************************************************************
- *   FreeMedicalForms                                                      *
- *   (C) 2008-2010 by Eric MAEKER, MD                                     **
- *   eric.maeker@free.fr                                                   *
- *   All rights reserved.                                                  *
+ *  The FreeMedForms project is a set of free, open source medical         *
+ *  applications.                                                          *
+ *  (C) 2008-2010 by Eric MAEKER, MD (France) <eric.maeker@free.fr>        *
+ *  All rights reserved.                                                   *
  *                                                                         *
- *   This program is a free and open source software.                      *
- *   It is released under the terms of the new BSD License.                *
+ *  This program is free software: you can redistribute it and/or modify   *
+ *  it under the terms of the GNU General Public License as published by   *
+ *  the Free Software Foundation, either version 3 of the License, or      *
+ *  (at your option) any later version.                                    *
  *                                                                         *
- *   Redistribution and use in source and binary forms, with or without    *
- *   modification, are permitted provided that the following conditions    *
- *   are met:                                                              *
- *   - Redistributions of source code must retain the above copyright      *
- *   notice, this list of conditions and the following disclaimer.         *
- *   - Redistributions in binary form must reproduce the above copyright   *
- *   notice, this list of conditions and the following disclaimer in the   *
- *   documentation and/or other materials provided with the distribution.  *
- *   - Neither the name of the FreeMedForms' organization nor the names of *
- *   its contributors may be used to endorse or promote products derived   *
- *   from this software without specific prior written permission.         *
+ *  This program is distributed in the hope that it will be useful,        *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *  GNU General Public License for more details.                           *
  *                                                                         *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS   *
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT     *
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS     *
- *   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE        *
- *   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,  *
- *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,  *
- *   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;      *
- *   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER      *
- *   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT    *
- *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN     *
- *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE       *
- *   POSSIBILITY OF SUCH DAMAGE.                                           *
+ *  You should have received a copy of the GNU General Public License      *
+ *  along with this program (COPYING.FREEMEDFORMS file).                   *
+ *  If not, see <http://www.gnu.org/licenses/>.                            *
  ***************************************************************************/
 /***************************************************************************
  *   This code is inspired of the Qt example : Text Edit                   *
@@ -44,10 +30,8 @@
  *       NAME <MAIL@ADRESS>                                                *
  ***************************************************************************/
 /**
-  \class TextEditor
+  \class Editor::TextEditor
   \todo Document code.
-  \ingroup toolkit
-  \ingroup widget_toolkit
 */
 
 #include "texteditor.h"
@@ -95,6 +79,27 @@ using namespace Trans::ConstantTranslations;
 
 namespace Editor {
 namespace Internal {
+
+class TextEditorHtmlPaster : public QTextEdit
+{
+public:
+    TextEditorHtmlPaster(QWidget *parent = 0) : QTextEdit(parent) {}
+    TextEditorHtmlPaster(const QString &text, QWidget *parent = 0) : QTextEdit(text, parent) {}
+    ~TextEditorHtmlPaster() {}
+
+    bool canInsertFromMimeData(const QMimeData *source) const {qWarning() << source; return true;}
+    void insertFromMimeData(const QMimeData *source)
+    {
+        qWarning() << source->formats();
+        qWarning() << "hasHtml" << source->hasHtml();
+        qWarning() << "mime" << source->data(source->formats().at(0));
+        QString h = "html";
+        qWarning() << "clipboard text" << QApplication::clipboard()->text();
+        qWarning() << "clip formats" << QApplication::clipboard()->mimeData()->formats();
+    }
+
+};
+
 class TextEditorPrivate
 {
 public:
@@ -102,6 +107,7 @@ public:
             : m_Type(type), m_Context(0), textEdit(0), m_Parent(parent), m_ToolBarIsVisible(false)
     {
         textEdit = new QTextEdit(m_Parent);
+        //textEdit = new TextEditorHtmlPaster(m_Parent);
         textEdit->setContextMenuPolicy( Qt::CustomContextMenu );
     }
 
@@ -213,6 +219,7 @@ public:
     EditorContext *m_Context;
     QToolBar *m_ToolBar;
     QTextEdit *textEdit;
+    //TextEditorHtmlPaster *textEdit;
     QWidget *m_Parent;
     bool m_ToolBarIsVisible;
 };
